// 22/02/2023
// Authors: Andres Felipe Soto & Gabriela Bojanini
// HILDA 2019 

clear all
set maxvar 30000
set sortseed 1180
set seed 1180

log using "${results}/Logs/Log 1 Australia `c(current_date)'.txt", replace text


/*
///////////////////
/*Change username*/
///////////////////
if c(username) == "afsotog" {
	global rawdata "/Users/afsotog/Dropbox/Andres Soto/New Tech/Python/Andres/Economia/Some productivity notes/PNUD Paper Inequality/Australia/HILDA 2019 (Wave 19) General Release"
	global results "/Users/afsotog/Dropbox/Andres Soto/New Tech/Python/Andres/Economia/Some productivity notes/PNUD Paper Inequality/Australia/Results"
}

if c(username) == "Gabriela" {
	global rawdata "C:\Users\Gabriela\Dropbox\Gabriela y Marcela\PNUD Paper Inequality\Australia\HILDA 2019 (Wave 19) General Release"
	global results "C:\Users\Gabriela\Dropbox\Gabriela y Marcela\undp\Replication Material\Output"
 
}

 *External user

if c(username) == "INSERT COMPUTER USERNAME" {
	global rawdata "INSERT ROUTE TO THE SUBFOLDER WHERE RAW DATA IS STORED" // 
	global results "INSERT ROUTE TO THE SUBFOLDER WHERE RESULTS SHOULD BE EXPORTED TO"

}
*/

{
use "${rawdata}\Combined_s200c.dta", clear

sort xwaveid shhrpid // Organize the database

**# Rename variables for simplicity 
{ 
rename sbifip businessincome //FY, whole dollars, top coded 

rename swscei grosswage // weekly, whole dollars, all jobs top coded

rename sjbmmply sector // 1:private - profit org, 2: private -nonprofit org, 3: government business or commercial statutory authority, 4:other commercial, 5:governmental org, 6: other non-commercial

rename ses status // 1:employee, 2: employer, 3:own-account, 4:contributing family member (ABS)

rename sesempst status2 //1:employee, 2:employee of own business, 3: employer/selfemployed, 4: unpaid family worker

rename sesempdt status3 // 1:employee, 2: employee of own business with other employees, 3: employee of own business without other employees, 4: employer/selfemployed with employees, 5:employer/selfemployed without employees, 6: unpaid family worker

rename sesbrd empst // 1:employed, 2:unemployed, 3:not in labour force

rename sjbmwps workplace // 1: self, 2: 2-4, 3: 5-9, 4:10-19, 5:20-49, 6:50-99, 7:100-199, 8:200-499, 9:500 or more, 10: dont know but fewer than 20, 11: dont know but 20 or more. 

rename sjbmemsz firmsize // 1: Less than 20, 2: 20 to 99, 3: 100 to 499, 4: 500 to 999, 5:1000 to 4999, 6:5000 to 19,999, 7:20,000 or more, 8:Don't know but fewer than 100, 9:Don't know but 100 or more 

rename sjbmmwp operations //[1] Employer / business has more than one location in Australia [2] Employer / business has only one workplace

rename shhwte csweights // cross section population weight for all people who are usual residents of the responding households in the relevant wave. 

rename shgage age
*rename shhwte csweigts_sumsample // cross section population weight rescaled to the sum of the sample size. use this weight when the statistical package requires the weights to sum to the sample size.

}

**# Preparation and creation of interest variables 
{

/*Income variable*/
gen businessincome_month=businessincome/12
gen grosswage_month=grosswage*(52/12)
gen income = grosswage_month+businessincome_month

/*Creating employment status dummy variables*/

// 1:employee, 2: employee of own business with other employees, 3: employee of own business without other employees, 4: employer/selfemployed with employees, 5:employer/selfemployed without employees, 6: unpaid family worker

gen selfemployed = (status3==5 | status3 == 3)
gen employee = (status3==1 )
gen employer = (status3 == 4 | status3 == 2)
replace workplace =. if selfemployed == 1
replace employee = 1 if status3 == 6 & income >0 & income !=. 
gen paidworker = inrange(status3,1,5)
gen occ = status3 
replace occ =. if status3 ==6

}



**# Sample Selection
{
*drop if income<=0 // Delete observations: persons with negative or no income
drop if age<20 // Delete observations: younger than 20 years
drop if sector == 5 // Delete observations: government organization
drop if ((workplace ==. | workplace == 10 | workplace ==11 | workplace <=0) & selfemployed !=1) // Delete observations: Non-responding person, didn't know or refused, or were not asked the Number employed at place of work (sjbmwps/workplace)



}
**# Imputation
{
	gen educgroups = (sedhigh1 == 9)*1 + (sedhigh1==8)*2 + inrange(sedhigh1, 1,5)*3
	gen agegroups = (age<15)*1 + inrange(age,15,25)*2 + inrange(age,26,45)*3 + inrange(age,46,65)*4 + inrange(age,66,1000)*5
	gen rural = (shhsgcc == 19 | shhsgcc == 29 | shhsgcc == 39 | shhsgcc == 49 | shhsgcc ==59 | shhsgcc == 61 | shhsgcc == 71)
	gen urban = (rural == 0)
	gen hours = sjbhruc 
	gen hrs_cat = (hours<20)*1 + inrange(hours,20,39)*2 + inrange(hours,40,100000)*3
	gen agro = inrange(sjbmi62,1,5)
	gen sex = shgsex // Male
	replace sex = 0 if shgsex == 2 //Female
	

	gen income_censurado = income 
	replace income_censurado=. if income <=0
	
	quantiles income_censurado [iw=csweights], gencatvar(pctiles) n(10) stable
	replace income_censurado =. if inlist(pctiles, 1,100)
	
	global covs sex educgroups agegroups occ urban hrs_cat agro 
	foreach var of global covs {
		replace income_censurado =. if `var' ==.
	}
	bys $covs: egen ing_mean_wt =wtmean(income_censurado) if paidworker ==1 & income_censurado>0 & income_censurado!=., weight(csweights)
	bys $covs: egen ing_i_mean_wt = min(ing_mean_wt) if paidworker==1 
	
	gen ing_lab = income
	replace ing_lab = ing_i_mean_wt if paidworker==1 & (income ==. | income<=0)
}

keep if ing_lab >0 & ing_lab !=. & (selfemployed == 1 | employer == 1 | employee == 1)

gen ordering =_n

**# Results tables 
{
	
*	____________________________________________________________________________
*
*	Figure 1 (Table): Distribution across business unit size categories
*	____________________________________________________________________________


***				Panel a				***

preserve 

	gen workplace_1_9 = (workplace >= 1 & workplace <=3 & selfemployed !=1 & ing_lab>0)
	gen workplace_10plus = (workplace>=4 & workplace !=. & selfemployed !=1 & ing_lab>0)
	gen persons_q = (selfemployed==1 | workplace_1_9==1 | workplace_10plus==1)
	collapse (mean) selfemployed workplace_1_9 workplace_10plus (sum) persons_q [pw=csweights]

	gen country = "Australia"
	gen region = "Asia: High Income"
	export excel using "${results}\Results AUS.xlsx", sheetreplace sheet("F1_Pa") firstrow(variables)
restore



***				Panel b				***

preserve
	gen workplace_1_4 = (workplace>=1 & workplace<=2 & selfemployed!=1 & ing_lab>0)
	gen workplace_5_9 = (workplace==3 & selfemployed!=1 & ing_lab>0)
	gen workplace_10_49 = (workplace>=4 & workplace<=5 & selfemployed!=1 & ing_lab>0)
	gen workplace_50plus = (workplace>=6 & workplace<=9 & selfemployed!=1 & ing_lab>0)
	gen persons_q = (selfemployed== 1 | workplace_1_4== 1 | workplace_5_9== 1 | workplace_10_49== 1 | workplace_50plus== 1)
	collapse (mean) selfemployed workplace_1_4 workplace_5_9 workplace_10_49 workplace_50plus (sum) persons_q  [iw=csweights]

	gen country = "Australia"
	gen region = "Asia: High Income"
	export excel using "${results}\Results AUS.xlsx", sheetreplace sheet("F1_Pb") firstrow(variables) 
restore

***				Panel c				***

preserve
	gen workplace_1_4 = (workplace>=1 & workplace<=2 & selfemployed!=1  & ing_lab>0)
	gen workplace_5_9 = (workplace==3 & selfemployed!=1 & ing_lab>0)
	gen workplace_10_49 = (workplace>=4 & workplace<=5 & selfemployed!=1 & ing_lab>0)
	gen workplace_50_99 = (workplace==6 & selfemployed!=1 & ing_lab>0)
	gen workplace_100plus = (workplace>=7 & workplace<=9 & selfemployed!=1 & ing_lab>0)
	gen persons_q = (selfemployed== 1 | workplace_1_4 == 1 | workplace_5_9 == 1 | workplace_10_49 == 1 | workplace_50_99 == 1 | workplace_100plus== 1)
	collapse (mean) selfemployed workplace_1_4 workplace_5_9 workplace_10_49 workplace_50_99 workplace_100plus  (sum) persons_q  [iw=csweights]

	gen country = "Australia"
	gen region = "Asia: High Income"
	export excel using "${results}\Results AUS.xlsx", sheetreplace sheet("F1_Pc") firstrow(variables) 
restore

*	____________________________________________________________________________
*
*	Figure 3 (Table): Distribution across business unit size and worker status 
*	by deciles of income
*	____________________________________________________________________________
/*
matrix a = [0.24,	0.26,	0.06,	0.43,	0.01  \ ///
0.13,	0.28,	0.04,	0.55,	0.01  \ ///
0.07,	0.21,	0.04,	0.67,	0.01 \  ///
0.07,	0.25,	0.04,	0.63,	0.01 \  ///
0.05,	0.21,	0.04,	0.69,	0.01 \  ///
0.07,	0.20,	0.04,	0.68,	0.01 \  ///
0.08,	0.16,	0.06,	0.70,	0.01 \  ///
0.09,	0.12,	0.08,	0.69,	0.02 \  ///
0.09,	0.09,	0.05,	0.72,	0.04 \  ///
0.11,	0.07,	0.06,	0.72,	0.04 ]

mat colnames a = selfemployed1 employee1_91 employer1_91 employee10_more1 employer10_more1

forvalues seed =1/10000{
set sortseed `seed'
*/
cap program drop StableQuantiles
program define StableQuantiles, rclass

    syntax varlist(max=1 numeric) [if] [fweight aweight iweight] [, IDvars(varlist) GENvar(name) BY(varlist) BINS(integer 100) SORT(varlist) SEED(integer 1) display] 

    // This function calculates quantiles in the data, it is meant to be stable
    // across different computers. Other programs such as quantiles are
    // not alwas stable as they run into issues when there are ties at the 
    // cutoffs. 

    // HELP:
    * varlist: variable to be used to calculate the quantiles. REQUIRED
    * idvars:  variable(s) that uniquely identify observations in the the data.
    *          REQUIRED.
    * sort:    These variables will be used to sort the data if they want to 
    *          be used to break ties in varlist.
    *          reproducibility across computers. 
    * genvar:  name of the variable that will be created to store the 
    *          quantiles. REQUIRED
    * by:      variable(s) to calculate quantiles within groups.
    * bins:    number of quantiles to calculate. Default = 100
    * seed:    seed for the random number generator. Default = 1. This will
    *          guarantee reproducibility across computers.
    * display: if specified, will display the distribution of the created
    *          quantiles variable and the min and max values for each quantile. *          The tabulation only make sense if there are no BY() variables. 
    *          Display will only occur if bins<=100.

    // Some info MUST be provided
    if "`idvars'"==""{
        di as err "ERROR: IDvars() variables must be provided."
        exit 198
    }
    if "`genvar'"==""{
        di as err "ERROR: GENvar() variable must be provided."
        exit 198
    }

    confirm new variable `genvar'

    // ID variables must be unique 
    qui unique `idvars'
    if r(unique)!=r(N) {
        di as err "ERROR: IDvars() variables must be unique identifiers."
        exit 111
        ** Could have allowed to include the BY() variables for the unique 
        ** identifiers, but I avoid this issue by requiring the user to
        ** provide unique identifiers in the SORT()
    }
    if `bins' < 2 {
        di as error "ERROR: invalid BINS(); number of quantiles should be at least 2"
        exit 113
    }
    
    
    tempvar totweight weighting markervar ordervar cumulativevar noisevarlist currentorder
    mark `markervar' `if'
    markout `markervar' `varlist'

    if "`weight'"!=""{
        gen `weighting' `exp'
    }
    else{
        gen `weighting'=1
    }

    gen `currentorder'=_n
    sort `by' `idvars'
    set seed `seed' // To guarantee reproducibility across datasets
    gen `ordervar'=rnormal(0,1) // This variable will break ties if there are any.
    sort `currentorder' // Restore order
    //format `varlist' %14.6fc

    // Now order based on the random variable to break ties 
    sort `by' `varlist' `sort'  `ordervar'

    // Calculate the total weight and the cumulative weight
    if "`by'"!=""{
        egen `totweight'=total(`weighting') if `markervar', by(`by')
        bysort `by': gen `cumulativevar'=sum(`weighting') if `markervar'
    }
    else{
        egen `totweight'=total(`weighting') if `markervar'
        gen `cumulativevar'=sum(`weighting') if `markervar'
    }
    // Now calculate the quantiles
    // gen `genvar' =  .
    matrix display_pctiles = J(`bins',2,.)
    sum `cumulativevar' `totweight' if `markervar'
    
    // Potentially faster way 
    gen `genvar' = int(`cumulativevar'/((`totweight'+1)/`bins')) + 1 if `markervar'

    if "`by'"!="" label variable `genvar' "`bins' quantiles of `varlist' by `by'."
    else label variable `genvar' "`bins' quantiles of `varlist'."

    // Display some basic results: distribution across quantiles and cutoffs 
    // for each quantile
    if "`display'"!="" & `bins' <= 100{
        local rownamelist ""
        forvalues x = 1/`bins'{
            replace `genvar' = `x' if `markervar' & (`x'-1)*`totweight'/`bins'< `cumulativevar' & `cumulativevar' <= `x'*`totweight'/`bins'
            * Local of highest value within the quantile
            qui sum `varlist' if `markervar' & `genvar'==`x' 
            matrix display_pctiles[`x',2] = r(max)
            matrix display_pctiles[`x',1] = r(min)
            local rownamelist `rownamelist' `x'
        }
        *dis "`rownamelist'"
        matrix colnames display_pctiles = "Min" "Max" 
        matrix rownames display_pctiles = `rownamelist'
        
    
        if "`by'"!="" | "`weight'"!="" dis "Distribution across quantiles does not need to be balanced if there are weights. And distribution will only be balanced within groups defined by the BY() variables."
        tab `genvar' if `markervar'

    // Display the cutoffs for each quantile (if under 20, otherwise too many)
        matlist display_pctiles, border(rows) rowtitle("`genvar'") left(4) format(%9.3fc) title("Cutoffs for each quantile")
        
    }

    sort `currentorder' // Restore order

end

preserve
	gen employee1_9=(workplace>=1 & workplace<=3 & (employee==1 | status3==6)  & ing_lab>0)
	gen employee10_more=(workplace>=4 & workplace<=9 &(employee==1 | status3==6) & ing_lab>0)
	gen employer1_9=(workplace>=1 & workplace<=3 & employer==1 & ing_lab>0)
	gen employer10_more=(workplace>=4 & workplace<=9 & employer==1 & ing_lab>0)
	StableQuantiles ing_lab [iw=csweights] , idvars(xwaveid shhrpid) genvar(qtiles) bins(10) seed(1180) sort(ordering)
	drop if qtiles == .
	gen persons_q = (selfemployed== 1 | employee1_9 == 1 | employee10_more == 1 | employer1_9 ==1 | employer10_more==1)

	collapse (mean) selfemployed employee1_9 employer1_9 employee10_more employer10_more (sum) persons_q [pw=csweights], by(qtiles)
/*
	svmat a, names(col) 
	local dif = 0
	foreach var in selfemployed employee1_9 employer1_9 employee10_more employer10_more{
		gen `var'2 = (abs(`var'-`var'1)>0.005)
		sum `var'2
		local dif = `dif'+r(mean)
	}

	if `dif'==0{
		dis "correct seed: `seed'"
		exit 111

	}
*/

	gen country = "Australia"
	gen region = "Asia: High Income"
	export excel using "${results}\Results AUS.xlsx", sheetreplace sheet("F3") firstrow(variables) 
restore

}

*	____________________________________________________________________________
*
*	Database : Distribution across business unit size and worker status 
*	by deciles of income, all available categories
*	____________________________________________________________________________
preserve
	
	levelsof workplace, local(categs)
		foreach c of local categs {
			gen cat_`c'= (workplace==`c')
			replace cat_`c'=0 if selfemployed==1
			}
	rename cat_1 w_one
	rename cat_2 w_2to4
	rename cat_3 w_5to9
	rename cat_4 w_10to19
	rename cat_5 w_20to49
	rename cat_6 w_50to99
	rename cat_7 w_100to199
	rename cat_8 w_200to499
	rename cat_9 w_500ormore
	
		StableQuantiles ing_lab [iw=csweights] , idvars(xwaveid shhrpid) genvar(qtiles) bins(10) seed(1180) sort(ordering)
	drop if qtiles == .

	collapse (mean) selfemployed w_* [pw=csweights], by(qtiles)

	gen country = "Australia"
	gen region = "Asia: High Income"
	export excel using "${results}/Results AUS.xlsx", sheetreplace sheet("Database") firstrow(variables) 
restore



}

cap log close
