********************************************************************************
**
**							1. Europe
**
********************************************************************************
**
**		This dofile processes the European EU-SILC data to produce
**		the results that are used in XXXXX for
**		Figures XXXXX.
**		We adapt code produced by Gesis from Leibinz Institute for the Social 
**		Sciences  
**		Author: Gesis from Leibinz Institute for the Social Sciences, Andres 
**		Felipe Soto & Gabriela Bojanini 
**		Date: 22/02/2023
**
********************************************************************************


clear all
set more off
set maxvar 30000

///////////////////
/*Change username*/
///////////////////
if c(username) == "af.soto11" {
	global rawdata "C:\Users\af.soto11\Documents\Eurostat\Cross"
	global results "C:\Users\af.soto11\Downloads"
}

if c(username) == "Gabriela" {
	global rawdata "C:\Users\Gabriela\Dropbox\Gabriela y Marcela\undp\Replication Material\Raw datasets\Cross"
    global public "C:\Users\Gabriela\Dropbox\Gabriela y Marcela\undp\Replication Material\Public datasets"
	global results "C:\Users\Gabriela\Dropbox\Gabriela y Marcela\PNUD Paper Inequality\Europa\EU SILC outputs"
 
}

/* External user

if c(username) == "INSERT COMPUTER USERNAME" {
	global rawdata "INSERT ROUTE TO THE SUBFOLDER WHERE RAW DATA IS STORED" // 
	global results "INSERT ROUTE TO THE SUBFOLDER WHERE RESULTS SHOULD BE EXPORTED TO"

}
*/

**# Loop to convert individual countries' csv files into one dta file based on the Gesis.org, Leibinz Institute for the Social Sciences do file. We exclude UK and Iceland because 2019 data is not available. Also, the Eurostat team asked for the exclusion of Netherlands for confidentiality reasons.
{

cap log close
log using "${results}/Logs/Log 1 Europe `c(current_date)'.txt", replace text


*reported person level data
local stata_file "EuroStata_person"
tempfile `temp'

save "${rawdata}\\`stata_file'.dta", emptyok replace

foreach CC in AT BE BG CH CY CZ DE DK EE EL ES FI FR HR HU IE /*IS*/ IT LT LU LV MT /*NL*/ NO PL PT RO RS SE SI SK /*UK*/   {
	
		import delimited using "${rawdata}\\`CC'\2019\UDB_c`CC'19P.csv", case(upper) clear
        rename PB030 pid
        rename PX030 hhid
        rename PB020 country
		append using "${rawdata}\Eurostata_person.dta", force
        save "${rawdata}\Eurostata_person.dta", replace
}

clear

*reported household level data
local stata_file "EuroStata_household"
tempfile `temp'

save "${rawdata}\\`stata_file'.dta", emptyok replace

foreach CC in AT BE BG CH CY CZ DE DK EE EL ES FI FR HR HU IE /*IS*/ IT LT LU LV MT /*NL*/ NO PL PT RO RS SE SI SK /*UK*/ {
	
		import delimited using "${rawdata}\\`CC'\2019\UDB_c`CC'19H.csv", case(upper) clear
        rename HB030 hhid
        rename HB020 country
		append using "${rawdata}\Eurostata_household.dta", force

	save "${rawdata}\Eurostata_household.dta", replace

}

clear

*registry household level data
local stata_file "EuroStata_householdR"
tempfile `temp'

save "${rawdata}\\`stata_file'.dta", emptyok replace

foreach CC in AT BE BG CH CY CZ DE DK EE EL ES FI FR HR HU IE /*IS*/ IT LT LU LV MT /*NL*/ NO PL PT RO RS SE SI SK /*UK*/ {
	
		import delimited using "${rawdata}\\`CC'\2019\UDB_c`CC'19D.csv", case(upper) clear
        rename DB030 hhid
        rename DB020 country
		append using "${rawdata}\Eurostata_householdR.dta", force

	save "${rawdata}\Eurostata_householdR.dta", replace
}

merge 1:1 hhid country using "${rawdata}\Eurostata_household.dta" , gen(hh)
    merge 1:m hhid country using "${rawdata}\Eurostata_person.dta", gen(p_hh)
save "${rawdata}\Eurostata.dta", replace
*We are left with a person-level dataset with info on the person and his/her hosehold

}


* Open compiled dataset
use "${rawdata}\Eurostata.dta", clear
**#  Rename for simplicity
{

	rename PB010 year // year
	rename PB040 weights // person's weight
	rename PB140 birthyear // person's year of birth
	rename PL031 empst // self-defined economic current status
	rename PL040 status // status in employment
	rename PL130 workplace // Number of persons working at the local unit (categorical)
	rename PX020 age // person's age 
	rename PX010 change_rate // exchange rate
	rename PL060 hours // number of hours usually worked per week in main job
    rename DB100 rural // degree of urbanisation
}

**# Selection of sample 
{
	drop if age <20
	drop if PL111 == "o" // Delete observations: government and education
    drop if PL111 == "p" 
   drop if empst == 5 // Delete observations: unemployed or missing 
   drop if empst ==.  
   
   	drop if country == "NO" | country == "HU" // Delete HU and Norway because no business owners reported

*now delete responses "don't know size of establishment": codes 14 and 15 in every country but Malta, codes 6 and 7 in Malta
    drop if (workplace == 6 | workplace == 7) & country == "MT" 
    drop if workplace == 14 | workplace == 15 

}

**# Construction of variables of interest for imputing income that is missing or non-positive, or those used as income regressors
{
* Age
label var age "Age in years"

*Gender
gen sex = PB150
replace sex = 0 if PB150 == 2
label var sex " Sex (1: Male)"
label define sex 1 "Male" 0 "Female"
label value sex sex

* Rural (only used to impute income in a few observations where no positive income reported)

gen urban = 1 if rural == 1 | rural == 2
replace urban = 0 if rural == 3
replace urban = 1 if rural ==. // Slovenia and Germany don't report values for this variable. We assign urban value = 1.

* Education level

gen educ_level =.
// Primary and secondary 
*************Labor force *************************
	gen employed = (empst ==1 | empst ==2 | empst == 3 |empst == 4) // Employed population
	gen unemployed = (empst == 5) // Unemployed population
	gen inactive = (employed == 0 & unemployed == 0) // People out of the labor force
    label define empst 1 "Employee working full-time" 2 "Employee working part-time" 3 "Self-employed working full-time (including family worker)" 4 "Self-employed working part-time (including family worker)" 5 "Unemployed"
    label value empst empst
    label define status 1 "Employer" 2 "Self employed without employees" 3 "Employee" 4 "Family worker"
    label value status status
************Generation of income variable***************

// Income variables: PY010G: Employee cash or near cash gross income; PY020G: Non-cash employee income; PY050G: Cash profits or losses from self-employment; PY021G: Company car

	foreach var of varlist PY010G PY050G PY020G PY021G {
		replace `var' = 0 if `var' ==.
	}
	
	egen income = rowtotal(PY010G PY050G PY020G PY021G) 
	egen worked_months = rowtotal(PL073 PL074 PL075 PL076) //PL073(PL075) = number of months as full time employee (owner), while PL074 (076) = number of months spent as part time employee (owner)
    drop if worked_months == 0 // Delete observations: Didn't report any months of work 
	
	gen income_month = income/worked_months // Monthly income variable for income reference period

    gen paidworker = (employed == 1 & status == 1 | status == 2 | status == 3 ) //analysis includes paidworkers and those who report themselves as being unpaid but do report labor income


    
// Imputing income 

gen income_censurado = income_month
replace income_censurado =. if income_month <= 0

bys country: quantiles income_censurado [iw=weights], gencatvar(pctiles) n(100) stable
replace income_censurado =. if inlist(pctiles, 1,100)

gen hrs_cat =.
egen total_hours = rowtotal(PL100 PL060) //PL060 (100) = total number of hours usually worked per week in main job (other jobs)
replace hrs_cat = 1 if total_hours <20
replace hrs_cat = 2 if inrange(total_hours,20,39)
replace hrs_cat = 3 if inrange(total_hours,40,1000000)
label define hrs_cat 1 "0-20" 2 "20 - 40" 3 "40+"
label values hrs_cat hrs_cat

gen agegroups = (age<15)*1 + (inrange(age,15,25))*2 + (inrange(age,26,45))*3 + (inrange(age,46,64))*4 + (inrange(age,65,1000))*5
gen educgroups = (PE040 == 000 | PE040 == 100)*1  + (PE040==200 | PE040  == 300)*2 + (PE040 >300)*3
// educgourps=1 if primary or less; =2 if secondary; =3 if tertiary

gen agro = 1 if (PL111 == "a")
replace agro = 0 if PL111 !="a" & PL111!=""


global covs sex educgroups agegroups status urban hrs_cat agro

foreach var of global covs {
    replace income_censurado =. if `var' ==.
}

bys country $covs: egen ing_mean_wt =wtmean(income_censurado) if paidworker == 1 & income_censurado>0 & income_censurado !=., weight(weights)
bys country $covs: egen ing_i_mean_wt=min(ing_mean_wt) if paidworker==1  //assigning values of mean income to people with income_censurado==.

gen ing_lab = income_month
replace ing_lab = ing_i_mean_wt if paidworker==1 & (income_month==. | income_month<=0)




*************Generation of type of worker****************

	gen selfemployed = (employed == 1 & status == 2) // Self-employed without employees 
	gen employer = (employed == 1 & status == 1) // Self-employed with employees
	gen employee = (employed == 1 & status == 3) // Employee
	gen employee_fw = (employed == 1 & status == 4 & income >0 & income !=.) //family worker who reports positive income
	replace employee=1 if employee==1 | employee_fw==1 // grouping employees with income
    
    drop if workplace ==. & selfemployed != 1 // Delete observations: doesn't report local unit size
	replace workplace =. if selfemployed == 1 // If their reported status is selfemployed without employees, their local unit size is changed to missing.



        
*********Generation of higher and lower income groups of countries********

		gen advanced = (country == "AT" | country == "BE" | country == "DK" | country == "FI" | country == "FR" | country == "DE" | country == "IE" | country == "IT" | country == "SE" | country == "CH" | country == "LU" | country == "MT" | country == "CY") // Countries above the median per capita GDP, constant PPP 2017 (2019) of all EU countries and 6 more, based on World Bank's statistics

*********************Sectors************************

gen induscode = 1 if PL111 == "b - e"  //industry
replace induscode = 2 if PL111== "g" | PL111== "i"   //wholesale, retail, restaurants and hotels
replace induscode = 3 if PL111 == "l - n" | PL111 == "r - u" | PL111 == "j" | PL111== "k" | PL111 == "r - u" //other services
replace induscode = 5 if PL111 == "a"   //agriculture
replace induscode = 4 if induscode ==. & PL111 != "" //other

levelsof induscode, local(sectordummy) // Creating dummy variable for sectors
	foreach s of local sectordummy {
		gen sectordummy`s' = (induscode==`s')
	}
}

**# Generation of firm size categories and income deciles
{
	

keep if ing_lab>0 & ing_lab!=. & (selfemployed == 1 | employer==1 | employee==1) // Delimitation of population of interest after imputing income.


***************** Generation of income deciles*******************
/*		bys country: quantiles ing_lab [iw=weights], gencatvar(decile) n(10) stable

*/
cap program drop StableQuantiles
program define StableQuantiles, rclass

    syntax varlist(max=1 numeric) [if] [fweight aweight iweight] [, IDvars(varlist) GENvar(name) BY(varlist) BINS(integer 100) SORT(varlist) SEED(integer 1) display] 

    // This function calculates quantiles in the data, it is meant to be stable
    // across different computers. Other programs such as quantiles are
    // not alwas stable as they run into issues when there are ties at the 
    // cutoffs. 

    // HELP:
    * varlist: variable to be used to calculate the quantiles. REQUIRED
    * idvars:  variable(s) that uniquely identify observations in the the data.
    *          REQUIRED.
    * sort:    These variables will be used to sort the data if they want to 
    *          be used to break ties in varlist.
    *          reproducibility across computers. 
    * genvar:  name of the variable that will be created to store the 
    *          quantiles. REQUIRED
    * by:      variable(s) to calculate quantiles within groups.
    * bins:    number of quantiles to calculate. Default = 100
    * seed:    seed for the random number generator. Default = 1. This will
    *          guarantee reproducibility across computers.
    * display: if specified, will display the distribution of the created
    *          quantiles variable and the min and max values for each quantile. *          The tabulation only make sense if there are no BY() variables. 
    *          Display will only occur if bins<=100.

    // Some info MUST be provided
    if "`idvars'"==""{
        di as err "ERROR: IDvars() variables must be provided."
        exit 198
    }
    if "`genvar'"==""{
        di as err "ERROR: GENvar() variable must be provided."
        exit 198
    }

    confirm new variable `genvar'

    // ID variables must be unique 
    qui unique `idvars'
    if r(unique)!=r(N) {
        di as err "ERROR: IDvars() variables must be unique identifiers."
        exit 111
        ** Could have allowed to include the BY() variables for the unique 
        ** identifiers, but I avoid this issue by requiring the user to
        ** provide unique identifiers in the SORT()
    }
    if `bins' < 2 {
        di as error "ERROR: invalid BINS(); number of quantiles should be at least 2"
        exit 113
    }
    
    
    tempvar totweight weighting markervar ordervar cumulativevar noisevarlist currentorder
    mark `markervar' `if'
    markout `markervar' `varlist'

    if "`weight'"!=""{
        gen `weighting' `exp'
    }
    else{
        gen `weighting'=1
    }

    gen `currentorder'=_n
    sort `by' `idvars'
    set seed `seed' // To guarantee reproducibility across datasets
    gen `ordervar'=rnormal(0,1) // This variable will break ties if there are any.
    sort `currentorder' // Restore order
    //format `varlist' %14.6fc

    // Now order based on the random variable to break ties 
    sort `by' `varlist' `sort'  `ordervar'

    // Calculate the total weight and the cumulative weight
    if "`by'"!=""{
        egen `totweight'=total(`weighting') if `markervar', by(`by')
        bysort `by': gen `cumulativevar'=sum(`weighting') if `markervar'
    }
    else{
        egen `totweight'=total(`weighting') if `markervar'
        gen `cumulativevar'=sum(`weighting') if `markervar'
    }
    // Now calculate the quantiles
    // gen `genvar' =  .
    matrix display_pctiles = J(`bins',2,.)
    sum `cumulativevar' `totweight' if `markervar'
    
    // Potentially faster way 
    gen `genvar' = int(`cumulativevar'/((`totweight'+1)/`bins')) + 1 if `markervar'

    if "`by'"!="" label variable `genvar' "`bins' quantiles of `varlist' by `by'."
    else label variable `genvar' "`bins' quantiles of `varlist'."

    // Display some basic results: distribution across quantiles and cutoffs 
    // for each quantile
    if "`display'"!="" & `bins' <= 100{
        local rownamelist ""
        forvalues x = 1/`bins'{
            replace `genvar' = `x' if `markervar' & (`x'-1)*`totweight'/`bins'< `cumulativevar' & `cumulativevar' <= `x'*`totweight'/`bins'
            * Local of highest value within the quantile
            qui sum `varlist' if `markervar' & `genvar'==`x' 
            matrix display_pctiles[`x',2] = r(max)
            matrix display_pctiles[`x',1] = r(min)
            local rownamelist `rownamelist' `x'
        }
        *dis "`rownamelist'"
        matrix colnames display_pctiles = "Min" "Max" 
        matrix rownames display_pctiles = `rownamelist'
        
    
        if "`by'"!="" | "`weight'"!="" dis "Distribution across quantiles does not need to be balanced if there are weights. And distribution will only be balanced within groups defined by the BY() variables."
        tab `genvar' if `markervar'

    // Display the cutoffs for each quantile (if under 20, otherwise too many)
        matlist display_pctiles, border(rows) rowtitle("`genvar'") left(4) format(%9.3fc) title("Cutoffs for each quantile")
        
    }

    sort `currentorder' // Restore order

end

StableQuantiles ing_lab [iw =weights], bins(10) genvar(decile) seed(100000) idvars(country hhid pid) by(country)
   drop if decile ==. // Delete observations: no decile of income generated  ******************************************************************************************

levelsof workplace if country != "MT", local(categs)   //Malta reports different size categories, added below
	foreach c of local categs {
		gen cat_`c' = (workplace==`c') if country != "MT"
	}
	
	// Generating categories of interest. 
	rename cat_11 cat_11to19 
	rename cat_12 cat_20to49
	rename cat_13 cat_50more

	
	gen workers_1_4 = ((cat_1 == 1 | cat_2 == 1 | cat_3 == 1 | cat_4 == 1) & selfemployed != 1 )
	gen workers_5_10 = ((cat_5 == 1 | cat_6 == 1 | cat_7 == 1 | cat_8 == 1 | cat_9 == 1 | cat_10 == 1) & selfemployed != 1 )
	gen workers_11_19 = (cat_11to19==1 & selfemployed != 1)
	gen workers_20_49 = (cat_20to49==1 & selfemployed != 1 )
	gen workers_50plus = (cat_50more == 1 & selfemployed != 1 )
	
	gen workers_1_10 = ((workers_1_4 == 1 | workers_5_10 == 1) & selfemployed != 1  )
	
	gen workers_11_49 = ((workers_11_19==1 | workers_20_49 == 1) & selfemployed != 1  )

	gen workers_11plus = ((workers_11_49==1 | workers_50plus==1) & selfemployed != 1  ) 
	
    // Adding Malta 
    replace workers_1_4 = 1 if workplace == 1 & country == "MT" & selfemployed != 1 
    replace workers_5_10 = 1 if workplace == 2 & country == "MT" & selfemployed != 1  
    replace workers_1_10 = 1 if workers_1_4 == 1 | workers_5_10 ==1

    replace workers_11_49 = 1 if (workplace == 3 | workplace == 4) & country == "MT" & selfemployed != 1  
    replace workers_50plus = 1 if workplace == 5 & country == "MT" & selfemployed != 1 
    replace workers_11plus = 1 if workers_11_49 == 1 | workers_50plus == 1

}



**# Figures 
{
*	____________________________________________________________________________
*
*	Figure 1 Panel A: Distribution across business unit size categories for all Europe by income groups aggregate categories
*	____________________________________________________________________________

preserve

collapse (mean) selfemployed workers_1_10 workers_11plus [pw=weights] , by(advanced) //mean across all obs is like weighted mean across countries of mean within country)



label define advanced 0 "EU: Lower Income" 1 "EU: Higher Income"
label values advanced advanced 

export excel using "${results}\Results EU.xlsx", sheetreplace sheet("F1_Pa") firstrow(variables)
restore

*	____________________________________________________________________________
*
*	Figure 1 Panel B: Distribution across business unit size categories for all Europe by income groups intermediate categories
*	____________________________________________________________________________

preserve
collapse (mean) selfemployed workers_1_4 workers_5_10 workers_11_49 workers_50plus [pw=weights], by(advanced)



label define advanced 0 "EU: Lower Income" 1 "EU: Higher Income"
label values advanced advanced 

export excel using "${results}\Results EU.xlsx", sheetreplace sheet("F1_Pb") firstrow(variables)
restore


*	____________________________________________________________________________
*
*	Fig 3: Business unit size distribution and worker status by Deciles
*	____________________________________________________________________________

preserve
	gen employer_micro = (employer == 1 & workers_1_10==1)
	gen employer_nonmicro = (employer == 1 & workers_11plus==1)
	gen employee_micro = (employee == 1 & workers_1_10==1)
	gen employee_nonmicro = (employee == 1 & workers_11plus==1)
	
	collapse (mean) selfemployed employee_micro employer_micro employee_nonmicro employer_nonmicro [pw=weights], by(advanced decile)
		
	label define advanced 0 "EU: Lower Income" 1 "EU: Higher Income"
	label values advanced advanced 
	
	
	export excel using "${results}\Results EU.xlsx", sheetreplace sheet("F3") firstrow(variables)
	



restore

*	____________________________________________________________________________
*
*	Appendix: Business unit size distribution and worker status by sectors
*	____________________________________________________________________________


// Panel A
preserve
	drop if PL111 == ""

    collapse (mean) selfemployed workers_1_10 workers_11plus [pw=weights], by(induscode) //  
    
   label define sector 1 "Industry" 2 "Wholesale retail, acommodation and food services" 3 "Other services" 4 "Others" 5 "Agriculture" // labeling
   label val induscode sector

   
    export excel using "${results}\Results EU.xlsx", sheet("Appendix_Pa") sheetreplace firstrow(variables)
    
restore


// Panel B
preserve
    	drop if PL111 == ""

    collapse (mean) selfemployed workers_1_4 workers_5_10 workers_11_49 workers_50plus [pw=weights], by(induscode) //  values by country
    
    label define sector 1 "Industry" 2 "Wholesale retail, acommodation and food services" 3 "Other services" 4 "Others" 5 "Agriculture"
   label val induscode sector 

      
    export excel using "${results}\Results EU.xlsx", sheet("Appendix_Pb") sheetreplace firstrow(variables)
    
restore

// Sector shares

preserve

	drop if PL111 == ""
	collapse (mean) sectordummy* [iw=weights]
	label var sectordummy1 "Industry" 
	label var sectordummy2 "Wholesale retail, acommodation and food services" 
	label var sectordummy3 "Other services" 
	label var sectordummy4 "Others" 
	label var sectordummy5 "Agriculture"
	
	export excel using "${results}\Results EU.xlsx", sheet("Sector Shares") sheetreplace firstrow(varlabels)
restore


*	____________________________________________________________________________
*
*	Appendix: Business unit size distribution and worker status by country
*	____________________________________________________________________________
preserve
collapse (mean) selfemployed workers_1_4 workers_5_10 workers_11_49 workers_50plus (mean) advanced [pw=weights], by(country)

label define advanced 1 "EU: Higher Income" 0 "EU: Lower Income"
label val advanced advanced
label var advanced "Income Group"

export excel using "${results}\Results EU.xlsx", sheetreplace sheet("Appendix_TA2") firstrow(variables)
restore

*	____________________________________________________________________________
*
*	Database: Business unit size distribution and worker status by country
*	____________________________________________________________________________

preserve
set trace off
levelsof workplace, local(categs)   //Malta reports different size categories, added below

    foreach w of local categs {
gen w_`w' = (workplace==`w' & country != "MT")
        replace w_`w'= 0 if selfemployed ==1
}
    rename w_11 w_11_19
    rename w_12 w_20_49
    rename w_13 w_50more
   
    gen w_1_5 = (workplace == 1 & country == "MT")
    gen w_6_10 = (workplace == 2 == 1 & country == "MT")
    replace w_11_19 = 1 if (workplace ==3 & country == "MT")
    replace w_20_49 = 1 if (workplace == 4 & country == "MT")
    replace w_50more = 1 if workplace == 5 & country == "MT"
   
    collapse (mean) selfemployed w_* [pw=weights], by(country decile)
	replace country = "Austria" if country == "AT"
	replace country = "Belgium" if country == "BE"
	replace country = "Bulgaria" if country == "BG"
	replace country = "Switzerland" if country == "CH"
	replace country = "Cyprus" if country == "CY"
	replace country = "Czech Republic" if country == "CZ"
	replace country = "Germany" if country == "DE"
	replace country = "Denmark" if country == "DK"
	replace country = "Estonia" if country == "EE"
	replace country = "Spain" if country == "ES"
	replace country = "Finland" if country == "FI"
	replace country = "France" if country == "FR"
	replace country = "Croatia" if country =="HR"
	replace country = "Greece" if country == "IE"
	replace country = "Italy" if country == "IT"
	replace country = "Lithuania" if country == "LT"
	replace country = "Luxembourg" if country == "LU"
	replace country = "Latvia" if country == "LV"
	replace country = "Malta" if country == "MT"
	replace country = "Poland" if country == "PL"
	replace country = "Portugal" if country == "PT"
	replace country = "Romania" if country == "RO"
	replace country = "Serbia" if country == "RS"
	replace country = "Sweden" if country == "SE"
	replace country = "Slovenia" if country == "SI"
	replace country = "Slovakia" if country == "SK"
	
   
    export excel using "${results}\Results EU.xlsx", sheetreplace sheet("Database") firstrow(variables)
restore
}