********************************************************************************
**
**							1. India
**
********************************************************************************
**
**		This dofile processes the Indian Periodic Labour Force Survey to produce
**		the results that are used in 2. Aggregate South Asia.do for
**		Figures 1, 2, and A2.
**		Author: Nicolas Urdaneta 
**
********************************************************************************

cap log close
log using "${results}/Logs/Log India `c(current_date)'.txt", replace text

# delimit ;
infix 

fileidentification 1-4
schdule 5-7
quarter 9
sector 12
state 13-14
district 15-16
nss 17-19
stratum 20-21
substratum 22-23
subsample 24
fodsubregion 25-28
fsu 29-33
sample_sg 34
secondstagestratum 35 
idhh 36-37
idpers 38-39

status 61-62
industry 63-67
occ 68-70	
worked 71
firmsize 76
typeofcontract 77
earningspt1 287-294
earningspt2 295-302
wage1_7 104-108
wage1_6 130-134
wage1_5 156-160
wage1_4 182-186
wage1_3 208-212
wage1_2 234-238
wage1_1 260-264
wage2_7 115-119
wage2_6 141-145
wage2_5 167-171
wage2_4 193-197
wage2_3 219-223
wage2_2 245-249
wage2_1 271-275
hrs_7 120-121
hrs_6 146-147
hrs_5 172-173
hrs_4 198-199
hrs_3 224-225
hrs_2 250-251
hrs_1 276-277

status2 80-81
industry2 82-86
occ2 87-89
firmsize2 94

curentweekstatus 280-281
industrycws 280-281
occcws 282-283

nss_code 303-305
nsc_code 306-308
mult 309-318

relationtohead 40
sex 41 // 1 for male, 2 female, 3 other
age 42-44
educ 46-47

using "${rawdata}/PerV1.txt" , clear ;
# delimit cr

format mult %14.0fc


sort quarter state fsu sector district nss stratum substratum  subsample fodsubregion sample_sg secondstagestratum idhh idpers



********************************************************************************
**
**		Create weight variable - following procedure in README of PLFS 
**
********************************************************************************

gen final_weight_qt =  mult/100 //if nss_code==nsc_code
replace final_weight_qt = mult/200 if nss_code!=nsc_code
gen final_weight = final_weight_qt/4
tabstat final_weight_qt final_weight , s(sum) by(quarter) format(%14.1fc)


********************************************************************************
**
**		Create variables for analysis
**
********************************************************************************

egen HouseholdID = group( quarter sector state district nss stratum substratum subsample fodsubregion fsu sample_sg secondstagestratum idhh)
egen PersonID = group(quarter sector state district nss stratum substratum subsample fodsubregion fsu sample_sg secondstagestratum  idhh idpers)

// Main person and household variables
gen rural = (sector==1)
tab rural  [iw=final_weight]
gen agegroups = (age<15)*1 + (inrange(age,15,25))*2 + (inrange(age,26,45))*3 + (inrange(age,46,65))*4 + (inrange(age,65,1000))*5
gen educgroups = (educ<=7)*1+(inrange(educ,8,11))*2+(inrange(educ,12,13))*3
egen uhrsworkly=rowtotal(hrs_*)
gen hrsworkgroups = 1*(inrange(uhrsworkly,1,19))+2*(inrange(uhrsworkly,20,39))+3*(inrange(uhrsworkly,40,1000))


gen laborforce = (status <=81 | status2<=81 )
gen works = (status<=51 | status2<=51)
gen paid_worker = inlist(status,11,12,31,41,51)
gen unpaidfamilyworker = (status==21)


// Sectors
gen educ_sec = 1 if inrange(industry,85000,85999) | (inrange(industry2,85000,85999) & industry==.) 
gen gov_wkr = 1 if inrange(industry,84000,84999) | (inrange(industry2,84000,84999) & industry==.)
replace gov_wkr=1 if status==41
gen sector_5dig = industry
replace sector_5dig = industry2 if industry==.
gen sector_4dig = floor(sector_5dig/10)
gen sector_categ = 1*(inrange(sector_5dig,05000,39999))+2*(inrange(sector_5dig,45000,48999) | inrange(sector_5dig,55000,56999))+3*(inrange(sector_5dig,58000,82999) | inrange(sector_5dig,90000,99999)) + 4*(inrange(sector_5dig,0,04999))
cap label drop categs
label define categs 1 "Industry" 2 "Services" 3 "Other services" 4 "Agriculture" 0 "Other sectors"
label values sector_categ categs
gen agro = (sector_categ==4)
// income variable
foreach var of varlist wage*{
	replace `var' = `var'*52/12 
}
egen income0 = rowtotal(earningspt1 earningspt2 wage1* wage2* )

*	____________________________________________________________________________
*
*			Impute income of those that report negative, zero or no income
*					but say they have a work with income
*	____________________________________________________________________________
 
gen income_censor = income0
replace income_censor = . if income0 <= 0

quantiles income_censor [iw=final_weight], gencatvar(pctiles) n(100) stable
replace income_censor = . if inlist(pctiles,1,100)

global covs sex educgroups agegroups status hrsworkgroups agro

foreach var of global covs{
	replace income_censor = . if `var' == .
}

* ybar con factor de expansion
bys $covs: egen ing_mean_wt=wtmean(income_censor) if paid_worker==1 & income_censor>0 & income_censor!=., weight(final_weight)
bys $covs: egen ing_i_mean_wt=min(ing_mean_wt) if paid_worker==1 

gen income_imp = income0
replace income_imp = ing_i_mean_wt if paid_worker == 1 & (income0==. | income0 <= 0) 
// Imputed 5218 observations, kept 814 as missing
drop income_censor pctiles



********************************************************************************
**
**		Check with aggregates reported
**		See here: https://cse.azimpremjiuniversity.edu.in/wp-content/uploads/2019/02/Annual-Report-PLFS-2017-18_31052019.pdf
**
********************************************************************************

tab laborforce if rural==1 & sex==1 [aw=final_weight]
tab laborforce if rural==0 & sex==1 [aw=final_weight]
tab laborforce if rural==1 & sex==2 [aw=final_weight]
tab laborforce if rural==0 & sex==2 [aw=final_weight]

tab works [aw=final_weight]
tab works if rural==1 [aw=final_weight]
tab works if rural==0 [aw=final_weight]

tab status if works==1 & rural==0 [aw=final_weight]


********************************************************************************
**
**		Create our definition of productive unit sizes
**
********************************************************************************

gen size = 1 if status==11 
replace size = 2 if status!=11 & firmsize==1
replace size = 3 if status!=11 & firmsize==2
replace size = 4 if status!=11 & firmsize==3 
replace size = 5 if status!=11 & firmsize==4

cap label drop sizes 
label define sizes 1 "Self-employed" 2 "1-5 workers" 3 "6-9 workers" 4 "10-19 workers" 5 "20+ workers"
label values size sizes

gen Emp1_10 = (inrange(size,2,3) & inrange(status,21,51))
gen Emp11_plus = (inrange(size,4,5) & inrange(status,21,51))
gen Own1_10 = (inrange(size,2,3) & status==12)
gen Own11_plus = (inrange(size,4,5) & status==12) 
gen self_emp = (status==11)
gen firm1to5 = (inrange(size,2,2))
gen firm6to9 = (inrange(size,3,3))
gen firm10to19 = (inrange(size,4,4))
gen firm20plus = (inrange(size,5,5))

// Create variables that will add to shares when collapsed
// Both in total and by sector

sum final_weight if works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & size!=. & rural==0, d 
gen emp_bysize = final_weight/r(sum)*100

gen emp_bysector_size=.
foreach sector in  0 1 2 3 4{
	sum final_weight if works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & size!=. & rural==0 & sector_categ==`sector', d 
	replace emp_bysector_size = final_weight/r(sum)*100 if sector_categ==`sector'

}


********************************************************************************
**
**		Display firm size distribution with both of the distribution categories 
**
********************************************************************************

tabstat emp_bysize if works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & rural==0, s(sum) by(size) format(%12.6fc)

bys sector_categ: tabstat emp_bysector_size if works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & rural==0, s(sum) by(size) format(%12.6fc)


// Checking respose rate to firm size question
tab status [iw=final_weight] if works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 

keep if works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & rural==0 & size!=.

gen ordering = _n
quantiles income_imp [iw=final_weight], gencatvar(Decile) n(10) stable
/*
local difs = 4000
forvalues seed=10000/200000{
	dis `seed'
	cap drop Decilenew
	StableQuantiles income_imp [iw=final_weight] , bins(10) seed(`seed') idvars(quarter sector state district nss stratum substratum subsample fodsubregion fsu sample_sg secondstagestratum  idhh idpers) genvar(Decilenew)
	qui count if Decile!=Decilenew
	local newdif = r(N)
	if `difs'>`newdif' local minseed `seed'
	if `difs'>`newdif'{ 
		local difs = `newdif'
		dis "lowest dif: `difs', with seed `minseed'" 
	}
}
dis "lowest dif: `difs', with seed `minseed'"
*/
********************************************************************************
**
**		Export results for processing in code 2. Aggregate South Asia.do 
**
********************************************************************************

* 0. Total workers 
sum final_weight if  works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & rural==0
global india_pop = r(sum)

* 1. Total

preserve 

collapse (sum) emp_bysize if  works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & rural==0, by(size)

drop if size==.
gen India_pop = $india_pop
mkmat emp_bysize India_pop, matrix(India )

restore

* 2. By sector

preserve 

bys sector_categ: egen pop = sum(final_weight) if works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & rural==0

collapse (sum) emp_bysector_size (mean) pop if works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & rural==0, by(size sector_categ)

drop if size==.

reshape wide emp_bysector_size pop, i(size) j(sector_categ)
rename (emp_bysector_size*) (emp_others emp_industry  emp_wholret emp_othservices emp_agri)
rename (pop*) (pop_others pop_industry pop_wholret pop_othservices pop_agri)
gen pop = $india_pop

gen country = "India"

save "${results}/Temporary files/india_temp.dta", replace


restore

********************************************************************************
**
**					Distribution of size by income deciles 
**
********************************************************************************

preserve

keep if works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & rural==0 & size!=.

cap drop Decile
StableQuantiles income_imp [iw=final_weight] , bins(10) seed(98515) idvars(quarter sector state district nss stratum substratum subsample fodsubregion fsu sample_sg secondstagestratum  idhh idpers) sort(ordering) genvar(Decile)
*quantiles income_imp [iw=final_weight], gencatvar(Decile) n(10) stable
drop if Decile == .

collapse self_emp Emp1_10 Emp11_plus Own1_10 Own11_plus [iw=final_weight], by(Decile)
foreach var in self_emp Emp1_10 Emp11_plus Own1_10 Own11_plus{
	replace `var' = `var'*100
}
egen total = rowtotal(self_emp Emp1_10 Emp11_plus Own1_10 Own11_plus)
sum total
drop total
list

export excel using "${results}/Results India.xlsx", firstrow(variables) sheetreplace sheet("Fig3")

restore


********************************************************************************
**
**		Export results for processing in code 4. Employment shares dataset.do 
**				Distribution of employment by income decile
**
********************************************************************************

preserve

keep if works==1 & age>=20 & educ_sec!=1 & gov_wkr!=1 & income_imp>0 & income_imp!=. & unpaidfamilyworker!=1 & rural==0 & size!=.

set seed 1234
cap drop Decile
StableQuantiles income_imp [iw=final_weight] , bins(10) seed(98515) idvars(quarter sector state district nss stratum substratum subsample fodsubregion fsu sample_sg secondstagestratum  idhh idpers) sort(ordering) genvar(Decile)

*quantiles income_imp [iw=final_weight], gencatvar(Decile) n(10) stable
drop if Decile == .

collapse firmselfemployed=self_emp firm1to5 firm6to9 firm10to19 firm20plus (sum) persons_decile=final_weight [aw=final_weight], by(Decile)

foreach var in firmselfemployed firm1to5 firm6to9 firm10to19 firm20plus{
	replace `var' = `var'*100
}

egen total = rowtotal(firmselfemployed firm1to5 firm6to9 firm10to19 firm20plus)
sum total
drop total
list

export excel using "${results}/Results India.xlsx", firstrow(variables) sheetreplace sheet("Database")


restore