********************************************************************************
**
**								Japan
**
********************************************************************************
**
**		This dofile processes the information for Japan.
**		It uses the tabulation tables downloaded from e-Stat.
**		Authors: Nicolas Urdaneta 
**
********************************************************************************

clear
cap log close
log using "${results}/Logs/Log 1 Japan `c(current_date)'.txt", replace text

// Unfortunately, the main dataset does not allow us to know how many 
// self-employed workers work in the education sector. And there is not any
// information available in the Japanese tabulations that would allow us to
// exclude the education sector properly. We thus limit ourselves to exclude
// only government. However, we find that the category for government includes 
// about 40% of workers in the education sector. 

// We now open our main dataset that has the number of workers in each business
// size and status of employment (self-employment). This dataset contains
// the number of workers in government as a category. 

import excel using "${publicdata}/Japan Table II-1.xlsx", sheet("1") cellrange("G15:BC223") clear

gen category = H +  I +  J +  K +  L +  M +  N +  O

keep category Q AS AU AV AX AY BA BB BC P

rename (Q AS AU AV AX AY BA BB BC P) (total firm1to4 firm5to9 firm10to29 firm30to99 firm100to499 firm500to999 firm1000plus government row)

foreach var in total firm1to4 firm5to9 firm10to29 firm30to99 firm100to499 firm500to999 firm1000plus government{
    replace `var' = "" if `var' == "-"
}

destring total firm1to4 firm5to9 firm10to29 firm30to99 firm100to499 firm500to999 firm1000plus government, replace

// Create variable for self-employed 
sum total if category=="Self-employed worker without employee" & row==4
gen selfemployed = r(mean) if row==7

keep if inlist(row, 3, 7 ) //| category=="Education, learning support"

collapse (sum) selfemployed firm*

*replace selfemployed = `Educ_self_emp' if category=="Education, learning support"

egen total_workers = rowtotal(firm* selfemployed)
foreach var of varlist firm* selfemployed{
    replace `var' = `var'/total_workers
}

// Create cateogories used in the paper. For Japan we have a cutoff for 10-30 and 30-99. We clarify this in the paper, for now we consider the 10-30 as the 10-50 category.

gen workplace_1_9 = firm1to4 + firm5to9 
gen workplace_10plus  = firm10to29 + firm30to99 + firm100to499 + firm500to999 + firm1000plus
gen firm10to49 = firm10to29
gen firm50to99 = firm30to99 
gen firm100plus = firm100to499 + firm500to999 + firm1000plus

gen persons_q = total_workers*10000 // Population came in tens of thousands

gen country = "Japan"
gen region = "Asia: High Income"

// Export results for Figure 1

export excel selfemployed workplace_1_9 workplace_10plus persons_q using "${results}/Results Japan.xlsx", sheet("F1_Pa") firstrow(variables) replace


// Export results for figure 2

export excel selfemployed firm1to4 firm5to9 firm10to49 firm50to99 firm100plus persons_q using "${results}/Results Japan.xlsx", sheet("F2") firstrow(variables) sheetreplace
