//	26/09/2022
// Author: Gabriela Bojanini
// Korean Labour and Income Panel Survey ("Wave 22, 2019")

clear

cap log close
log using "${results}/Logs/Log 1 Korea `c(current_date)'.txt", replace text


/*
///////////////////
/*Change username*/
///////////////////
if c(username) == "afsotog" {
	global rawdata "/Users/afsotog/Dropbox/Andres Soto/New Tech/Python/Andres/Economia/Some productivity notes/PNUD Paper Inequality/Australia/HILDA 2019 (Wave 19) General Release"
	global results "/Users/afsotog/Dropbox/Andres Soto/New Tech/Python/Andres/Economia/Some productivity notes/PNUD Paper Inequality/Australia/Results"
}

if c(username) == "Gabriela" {
	global rawdata "C:\Users\Gabriela\Dropbox\Gabriela y Marcela\PNUD Paper Inequality\Asia\Korea\Data\Klips wave 22 Stata (2019)"
	global results "C:\Users\Gabriela\Dropbox\Gabriela y Marcela\PNUD Paper Inequality\Readme File\Final\Results"
 
}

 External user

if c(username) == "INSERT COMPUTER USERNAME" {
	cd "INSERT PATH TO THE FOLDER WHERE DATA IS STORED" // 
	global results "INSERT PATH TO THE FOLDER WHERE RESULTS SHOULD BE EXPORTED TO"

}
*/
set seed 83195
set sortseed 83195
use "${rawdata}/eklips22w.dta", clear
// Merging side job data based on KLIPS recommendations 
keep if jobwave == 22
keep if mainjob == 0
keep if jobclass == 1 | jobclass == 3 | jobclass == 5 | jobclass == 7

merge m:1 pid using "${rawdata}/eklips22p.dta"
gsort -_merge pid jobseq // making sure data is ordered 

**# Preparation and creation if interest variables
{



* Age
gen age = p220107
label var age "Age in years"

gen agegroups = (age<15)*1 + inrange(age,15,25)*2 + inrange(age,26,45)*3 + inrange(age,46,65)*4 + (age>65)*5

* Sex
gen sex = p220101 // Male
replace sex = 0 if p220101 == 2 // Female

*Education
gen educgroups = inrange(p220110, 1, 3)*1 +  inrange(p220101,4,5)*2 + inrange(p220101,6,9)*3

*Agro
gen agro = inrange(p220342,11,15)*1 + (p220342==20)*1 + inrange(p220342,201,204)*1 + inrange(p220342,111,115)*1 + inrange(p220342,121,123)*1 + (p220342==129)*1 + (p220342==130)*1 + inrange(p220342,141,142)*1 + (p220342==150)*1 + inrange(p220342,31,32)*1 + inrange(p220342,311,312)*1 + inrange(p220342,321,322)*1
replace agro =. if p220342 ==.

* Hours
egen hours = rowtotal(j203 j203 p221004 p221031)
gen hrs_cat = (hours<20)*1 + inrange(hours,20, 39)*2 + inrange(hours,40,100000)*3
*** Employment ***

/* current economic activity status: KLIPS Guide code to construct EAP */ 
gen econst=3 /*not economically active population*/
replace econst=1 if p220201==1 /* the employed */
replace econst=2 if p222801==1 & p222806==1 /* the unemployed (ILO) */


*** Income ****
//side job in monthly basis
gen yr_pay = j303/12
gen month_pay =j304
gen week_pay = j305*52/12
gen daily_pay = j306*365/12
gen hour_pay = j307*j203*52/12
gen performance_pay = j309
egen income = rowtotal(p221642 p221672 j325 yr_pay month_pay week_pay daily_pay hour_pay performance_pay) // Monthly income



*** Status of worker ***


gen empst = p220314 //Main job. Regular work (1), Temporary Work (2), Daily work (3), Employer/Self-employed (4), Non-paid family worker (5)
gen boss = p220409 //Existance of hired employees. Yes (1), No (2), Don't know (3)

gen employee = (empst == 1 | empst == 2 | empst == 3 )  // Employees. Dummy
gen employer = (empst == 4 & boss == 1) // Employers. Dummy
gen selfemployed = (empst == 4 & boss == 2) // Self-employed without employees. Dummy
replace employee = 1 if empst == 5 & income >0 & income !=.
gen status = (employee == 1)*1 + (employer == 1)*2 + (selfemployed==1)*3
gen paidworker = (employee == 1 | employer == 1 | selfemployed == 1)


*** Work place size variable ***

gen workplace = p220406 // categorical variable for work place size

// continuous variable for work place size
replace workplace = 1 if p220405 >=1 & p220405 <=4
replace workplace = 2 if p220405 >=5 & p220405 <=9
replace workplace = 3 if p220405 >=10 & p220405 <=29
replace workplace = 4 if p220405 >=30 & p220405 <=49
replace workplace = 5 if p220405 >=50 & p220405 <=69
replace workplace = 6 if p220405 >=70 & p220405 <=99
replace workplace = 7 if p220405 >=100 & p220405 <=299
replace workplace = 8 if p220405 >=300 & p220405 <=499
replace workplace = 9 if p220405 >=500 & p220405 <=999
replace workplace = 10 if p220405 >=1000 & p220405 <1000000


* Employers don't register work place size, they report firm size. We will procede to construct the firm size variable for employers *


replace workplace = p220403 if employer ==1 // categorical variable for firm size

// continuous variable for firm size
replace workplace = 1 if p220402>=1 & p220402<=4 & employer == 1 // 1-4 workers
replace workplace = 2 if p220402>=5 & p220402<=9 & employer == 1 // 5-9 workers
replace workplace = 3 if p220402>=10 & p220402<=29 & employer == 1 // 10-29 workers
replace workplace = 4 if p220402>=30 & p220402<=49 & employer == 1 // 30-49 workers
replace workplace = 5 if p220402>=50 & p220402<=69 & employer == 1 // 50-69 workers
replace workplace = 6 if p220402>=70 & p220402<=99 & employer == 1 // 70-99 workers
replace workplace = 7 if p220402>=100 & p220402<=299 & employer == 1 // 100-299 workers
replace workplace = 8 if p220402>=300 & p220402<=499 & employer == 1 // 300-499 workers
replace workplace = 9 if p220402>=500 & p220402<=999 & employer == 1 // 500-999 workers
replace workplace = 10 if p220402>=1000 & p220402<=1000000 & employer == 1 // 1000+ workers

replace workplace =. if selfemployed ==1


}
** 1. Sample selection
drop if p220107 <20 // Delete observations: persons under 20 years old
drop if nw22p_c ==. // Delete observations: unweighted observations 
drop if empst == -1 //Delete observations: Don't know-Does not respond 
drop if p220401 ==5 // Delete observations: (5)  government or government branch (civil servants, military personnel, etc.)
drop if boss == 3 // Delete observations: Don't know existance of hired employees
drop if (workplace == 11 & selfemployed!=1) | (workplace ==. & selfemployed!=1) // Delete observations: don't know - doesn't respond about workplace size



*** imputation of income ***
gen income_censurado = income
replace income_censurado =. if income <= 0


quantiles income_censurado [iw=nw22p_c], gencatvar(pctiles) n(100) stable
replace income_censurado =. if inlist(pctiles,1,100)

global covs sex educgroups agegroups status hrs_cat agro 
foreach var of global covs {
	replace income_censurado =. if `var'==.
}

bys $covs: egen ing_mean_wt = wtmean(income_censurado) if paidworker == 1 & income_censurado>0 & income_censurado!=., weight(nw22p_c)
bys $covs: egen ing_i_mean_wt=min(ing_mean_wt) if paidworker == 1

gen ing_lab = income
replace ing_lab = ing_i_mean_wt if paidworker== 1 & (income ==. | income <=0)

* To check the result above, please abstain from deleting observations and run the code. This process should replicate the Economically Active Population Survey statistics. "Employed persons by status of worker"-> 2019 annual data; including unpaid family members, government workers, all types of income, all ages, and all missing value observations.  Source: https://kosis.kr/eng *
gen ordering = _n


**# Results tables

	
*	____________________________________________________________________________
*
*	Figure 1 (Table): Distribution across business unit size categories
*	____________________________________________________________________________

*** 			Panel a				***

preserve
	gen workplace_1_9 = (workplace >= 1 & workplace <= 2 & selfemployed !=1 & ing_lab>0)
	gen workplace_10plus = (workplace >= 3 & workplace <=10 & selfemployed !=1 & ing_lab>0)
	gen persons_q = (selfemployed == 1| workplace_1_9 == 1 | workplace_10plus ==1)
	
	collapse (mean) selfemployed workplace_1_9 workplace_10plus (sum) persons_q [iw=nw22p_c] 

	gen country = "Korea"
	gen region = "Asia: High Income"
	export excel using "${results}\Results KR.xlsx", sheetreplace sheet("F1_Pa") firstrow(variables) 
restore

***				Panel b 			***
preserve
	gen workplace_1_4 = (workplace == 1 & selfemployed!=1 & ing_lab>0)
	gen workplace_5_9 = (workplace == 2 & selfemployed!=1 & ing_lab>0)
	gen workplace_10_49 = (workplace >= 3 & workplace <= 4 & selfemployed!=1 & ing_lab>0)
	gen workplace_50plus = (workplace >=5 & workplace <= 10 & selfemployed!=1 & ing_lab>0)
	gen persons_q = (selfemployed == 1 | workplace_1_4==1 | workplace_5_9== 1 | workplace_10_49==1 | workplace_50plus==1)
	collapse (mean) selfemployed workplace_1_4 workplace_5_9 workplace_10_49 workplace_50plus (sum) persons_q [iw=nw22p_c]

	gen country = "Korea"
	gen region = "Asia: High Income"
	export excel using "${results}\Results KR.xlsx", sheetreplace sheet("F1_Pb") firstrow(variables) 
	
restore

***				Panel c 			***
preserve
	gen workplace_1_4 = (workplace==1 & selfemployed!=1 & ing_lab>0)
	gen workplace_5_9 = (workplace==2 & selfemployed!=1 & ing_lab>0)
	gen workplace_10_49 = (workplace>=3 & workplace<=4 & selfemployed!=1 & ing_lab>0)
	gen workplace_50_99 = (workplace>=5 & workplace<=6 & selfemployed!=1 & ing_lab>0)
	gen workplace_100plus = (workplace>=7 & workplace<=10 & selfemployed!=1 & ing_lab>0)
	gen persons_q = (selfemployed== 1 | workplace_1_4 == 1 | workplace_5_9==1 | workplace_10_49== 1 | workplace_50_99==1 | workplace_100plus==1)
	collapse (mean) selfemployed workplace_1_4 workplace_5_9 workplace_10_49 workplace_50_99 workplace_100plus (sum) persons_q [iw=nw22p_c] 

	gen country = "Korea"
	gen region = "Asia: High Income"
	export excel using "${results}\Results KR.xlsx", sheetreplace sheet("F1_Pc") firstrow(variables) 
restore

*	____________________________________________________________________________
*
*	Figure 3 (Table): Distribution across business unit size and worker status 
*	by deciles of income
*	____________________________________________________________________________



preserve 
	gen employee1_9 = (workplace >= 1 & workplace <= 2 & (employee ==1 | empst == 5))
	gen employee10_more = (workplace >=3 & workplace <= 10 & (employee ==1 | empst == 5))
	gen employer1_9 = (workplace >= 1 & workplace <= 2 & employer ==1 & ing_lab>0)
	gen employer10_more = (workplace >=3 & workplace <= 10 & employer ==1)
	cap drop qtiles
	StableQuantiles ing_lab [iw=nw22p_c] , bins(10) seed(98515) idvars( _merge pid jobseq ) sort(ordering) genvar(qtiles)
	*quantiles ing_lab [iw=nw22p_c], gencatvar(qtiles) n(10) stable
	drop if qtiles ==. 
	gen persons_q = (selfemployed == 1 | employee1_9==1 | employee10_more ==1 | employer1_9 ==1 | employer10_more==1)
	collapse (mean) selfemployed employee1* employer1* (sum) persons_q [pw=nw22p_c]  , by(qtiles)

	foreach var in selfemployed employee1_9 employee10_more employer1_9 employer10_more{
		replace `var'= `var'*100
	}
	list
	gen country = "Korea"
	gen region = "Asia: High Income"
	export excel using "${results}\Results KR.xlsx", sheetreplace sheet("F3") firstrow(variables)  
restore 


*	____________________________________________________________________________
*
*	Database : Distribution across business unit size and worker status 
*	by deciles of income, all available categories
*	____________________________________________________________________________

preserve
	
	levelsof workplace, local(categs)
		foreach c of local categs {
			gen cat_`c'= (workplace==`c')
			replace cat_`c'=. if selfemployed==1
			}
	rename cat_1 w_1to4
	rename cat_2 w_5to9
	rename cat_3 w_10to29
	rename cat_4 w_30to49
	rename cat_5 w_50to69
	rename cat_6 w_70to99
	rename cat_7 w_100to299
	rename cat_8 w_300to499
	rename cat_9 w_500to999
	rename cat_10 w_1000ormore
	
	gen year=2019
	cap drop qtiles
	StableQuantiles ing_lab [iw=nw22p_c] , bins(10) seed(98515) idvars( _merge pid jobseq ) sort(ordering) genvar(qtiles)
	drop if qtiles == .

	collapse (mean) selfemployed w_* [pw=nw22p_c], by(qtiles)

	gen country = "Korea"
	gen region = "Asia: High Income"
	export excel using "${results}\Results KR.xlsx", sheetreplace sheet("Database") firstrow(variables)
restore
