/*  Household Surveys Harmonization
-------------------------------------------------------------------------------
This Do File uses rawdata provided to create variables of interest later used in the paper.
-------------------------------------------------------------------------------
last change:
    25 May 2023
-------------------------------------------------------------------------------
Notes:
- When a variable is not available for a country it is created as missing.
-------------------------------------------------------------------------------
Author:
    Laura Tenjo (lauratenjo@worldbank.org)
-------------------------------------------------------------------------------
*/

cls

cap log close
log using "${results}/Logs/Log 1 LATAM `c(current_date)'.txt", replace text

* 0. Define paths

*cd "C:\Users\wb605268\OneDrive - Universidad de los Andes\5. UNDP 2020 - 2022\09. ENCUESTAS DE HOGARES\5. Proyectos\4. Concentración de mercado\Insights - Replication Folder"
*global rawdata "0. Rawdata"
*global data "1. Data"

**************************************************
**					ARGENTINA 					**
**************************************************

use "$rawdata\ARG_EPH_2019.dta", clear
gsort TRIMESTRE CODUSU NRO_HOGAR -COMPONENTE 
gen ordering = _n
** 1. General information

* 1.0. Household ID
egen hogar = group(CODUSU NRO_HOGAR TRIMESTRE ANO4)

* 1.1. Sampling weight
gen fac_exp=PONDERA
gen fac_exp_yr=fac_exp/4

* 1.2. Age
gen edad=CH06
sum edad
replace edad=0 if CH06==-1
label var edad "Edad en años"
format edad %9.0g

* 1.3. Gender
gen hombre=CH04
recode hombre (2 = 0)
label var hombre "Sexo (1: Hombre)"
label define hombre 1 "Hombre" 0 "Mujer"
label value hombre hombre

* 1.4. Region
gen urbano = 1 // The survey is only urban in Argentina

* 1.5.1. Asiste 
tab CH10
gen asiste=.
replace asiste = 1 if CH10 == 1
replace asiste = 0 if inlist(CH10,2,3)
label var asiste "¿Usted asiste actualmente a un establecimiento educativo?"
label value asiste sino 

* 1.5.2. Education level
gen educ_nivel=.
replace educ_nivel=1 if NIVEL_ED==1 |  NIVEL_ED==2 | NIVEL_ED==3 | NIVEL_ED==7
replace educ_nivel=2 if NIVEL_ED==4 | NIVEL_ED==5
replace educ_nivel=3 if  NIVEL_ED==6
label var educ_nivel "Máximo nivel educativo alcanzado"
format educ_nivel %9.0g

label define educ_nivel 1"Primaria o menos" 2"Secundaria" 3"Terciaria" 4"Sin educación"
label value educ_nivel educ_nivel

* 1.5.3. Years of schooling 
destring CH14, replace force
replace CH14=. if CH14==98 | CH14==99

gen yr_edu=.
replace yr_edu=0 if CH12 == 1  //Igual a cero si es preescolar
replace yr_edu = 0 if CH10 == 3 //Nunca ha asistido a ningun nivel educativo

replace yr_edu = 7 if CH12 == 2 & CH13 == 1 //Primaria completa
replace yr_edu = CH14 if CH12 == 2 & CH13 !=1 //Primaria incompleta

replace yr_edu = 9 if CH12 == 3 & CH13 == 1 //EGB completo
replace yr_edu = CH14 if CH12 == 3 & CH13 !=1 //EGB incompleto

replace yr_edu = 12 if CH12 == 4 & CH13 == 1 //Secundario completo
replace yr_edu = 7 + CH14 if CH12 == 4 & CH13 !=1 //Secundario incompleto

replace yr_edu = 12 if CH12 == 5 & CH13 == 1 //Polimodal completo
replace yr_edu = 9 + CH14 if CH12 == 5 & CH13 !=1 //Polimodal incompleto

replace yr_edu = 15 if CH12 == 6 & CH13 == 1 //Terciario completo
replace yr_edu = 12 + CH14 if CH12 == 6 & CH13 !=1 //Terciario incompleto

replace yr_edu = 17 if CH12 == 7 & CH13 == 1 //Universitario completo
replace yr_edu = 12 + CH14 if CH12 == 7 & CH13 !=1 //Universitario incompleto

replace yr_edu = 19 if CH12 == 8 & CH13 == 1 //Posgrado universitario completo
replace yr_edu = 17 + CH14 if CH12 == 8 & CH13 !=1 //Posgrado universitario incompleto

replace yr_edu = . if CH12 == 9 //Educacion especial 

* Nota: los missing que quedan son de personas con niveles incompletos que no reportan hasta que grado llegaron (CH14 == .)

label var yr_edu "Años de educacion"			


** 2. Labour market

* 2.1. Employed - Dummy
gen cond_actividad=.
replace cond_actividad=1 if ESTADO==4
replace cond_actividad=2 if ESTADO==1
replace cond_actividad=3 if ESTADO==2
replace cond_actividad=4 if ESTADO==3
label define cond_actividad 1"Menores de 10" 2"Ocupados" 3"Desocupados" 4"Inactivos"

gen ocupado=.
replace ocupado=0 if inlist(cond_actividad,2,3,4) 
replace ocupado=1 if cond_actividad==2

gen hr_trabajadas=PP3E_TOT
replace hr_trabajadas = . if hr_trabajadas == 999

* 2.2. Type of employment (Not standard within countries)
gen ocupacion=CAT_OCUP
replace ocupacion=. if CAT_OCUP==0
replace ocupacion=. if CAT_OCUP==9
replace ocupacion=5 if CAT_OCUP==3 & PP04B1==1
label define ocupacion 1"Patrón" 2"Cuenta propia" 3"Obrero o empleado" 4"Trabajador familiar sin remuneración" 5"Empleado doméstico"
label value ocupacion ocupacion

* 2.2.1. Domestic worker - dummy
gen empleada_domestica=.
replace empleada_domestica=0 if ocupacion!=.
replace empleada_domestica=1 if ocupacion==5
label var empleada_domestica "Trabajador doméstico"

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente=.
replace independiente=0 if inlist(ocupacion,3,4,5) & ocupado==1
replace independiente=1 if inlist(ocupacion,1,2) & ocupado==1
label var independiente "Trabajador por cuenta propia"

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 2
replace cuenta_propia = 0 if inlist(ocupacion,1,3,4,5)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,1,2,3,5)
replace trabajador_rem = . if ocupado != 1

* 2.3. Public employment or education sector - Dummy
* 1.1 Variable de empleado público
gen empleo_publico = 0

* Autorreportada
replace empleo_publico = 1 if PP04A == 1 // Reporta trabajar para una empresa estatal

* Por sector de actividad
gen sector2d = string(PP04B_COD)
replace sector2d=substr(sector2d,1,2)	
replace empleo_publico = 1 if sector2d == "84" // 84 CAES admin publica y defensa
replace empleo_publico = . if ocupado != 1

* 1.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | sector2d == "85" // 85 CAES enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
gen size_50_100 = .
replace size_50_100=1 if inlist(PP04C,1,2,3,4) //1-4
replace size_50_100=2 if inlist(PP04C,5,6) //5-10
replace size_50_100=3 if inlist(PP04C,7,8) //11-40
replace size_50_100=4 if inlist(PP04C,9) //41-100
replace size_50_100=5 if inlist(PP04C,10,11,12) //101 o mas
label define size_50_100 1"1-4" 2"5-10" 3"11-40" 4 "41-100" 5 "101 o más" 
label value size_50_100 size_50_100

* 2.5. Economic sector
* Sector de actividad homologado
preserve
use "$publicdata\correlativa_sectores.dta", clear
keep if pais == "Argentina_2019"
keep rama cod_sector_unificado_rev4
destring rama, replace
rename (rama cod_sector_unificado_rev4) (PP04B_COD sector_rev4)
tempfile temp
save `temp', replace
restore

destring PP04B_COD, replace
merge m:1 PP04B_COD using `temp', nogen
replace sector_rev4 = . if PP04B_COD  == 9999

label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

gen sector_desagregado_p = PP04B_COD
	
* 2.6. Informal worker - Dummy	
gen informal=.
notes informal: only defined for salaried workers in Argentina

** 3. Income

* 3.1. Personal earnings 
foreach var in  PP06C PP06D PP08D1 PP08D4 PP08F1 PP08F2  PP08J1  PP08J2 PP08J3 TOT_P12 {
    replace `var'=. if `var'==-7 | `var'==-8 | `var'==-9 
}

* 3.1.1. Create all components of Personal earnings 
* 4.2. Ingresos de la ocupación principal (asalariados/empleados)
gen ing_salario=PP08D1           //Monto total de sueldos
gen ing_tickets=PP08D4           //Monto percibido en tickets
gen ing_comision=PP08F1          //Monto cobrado por comisión
gen ing_propinas=PP08F2          //Monto cobrado por propinas
gen ing_agui=PP08J1/6              //Monto aguinaldo
gen ing_bonf=PP08J2              //Monto otras bonificaciones no habituales
gen ing_retro=PP08J3             //Monto retroactivo

* 4.3. Ingreso de otras ocupaciones
gen ing_ocusec=TOT_P12     //Monto de ingreso de otras ocupaciones (incluye ocupación secundaria, ocupación previa a la semana de referencia, deudas/ retroactivos por ocupaciones anteriores al mes de referencia, etc.) 

* 4.1. Ingresos de la ocupación principal (trabajadores independientes: patrones o cuenta propia)
gen ing_indepss=PP06C   //Monto de ingreso de patrones y cuenta propia sin socios
gen ing_indepcs=PP06D  //Monto de ingreso de patrones y cuenta propia con socios

egen salario = rowtotal(ing_salario ing_ocusec ing_retro), m
egen primas = rowtotal(ing_comision ing_bonf ing_propinas ing_agui), m
egen i_laboral = rowtotal (ing_indepss ing_indepcs), m  
* 6.1.  Ingreso laboral
egen ing_lab_0 = rowtotal(salario primas i_laboral), m
egen ing_labp_0= rowtotal(ing_indepss ing_indepcs ing_salario ing_comision ing_propinas ing_agui ing_bonf), missing

* Income comparable with WID
egen ing_pers_wid = rowtotal(ing_salario ing_ocusec ing_indepss ing_indepcs), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\Argentina_2019.dta", replace

**************************************************
**					BOLIVIA 					**
**************************************************

use "$rawdata\BOL_EH_2019.dta", clear
sort folio nro
gen ordering = _n
** 1. General information

* 1.0. Household ID
egen hogar = group(folio) 
label var hogar "Identificador único de hogar"

* 1.1. Sampling weight
gen fac_exp = factor 
replace fac_exp = subinstr(fac_exp,",",".",1)
destring fac_exp, replace
gen fac_exp_yr = fac_exp
label var fac_exp "Factor de expansión"
label var fac_exp_yr "Factor de expansión anual"

* 1.2. Age
gen edad = s02a_03 
label var edad "¿Cuántos años cumplidos tiene?"

* 1.3. Gender
gen hombre = 1 if s02a_02 == "1.Hombre"
replace hombre = 0 if s02a_02 == "2.Mujer"
label define sx 0 "Mujer" 1 "Hombre"
label val hombre sx	
label var hombre "¿Es hombre o mujer?"

* 1.4. Urban area - dummy
gen urbano = 1 if area == "Urbana"
replace urbano = 0 if area == "Rural"
label define ur 0 "Rural" 1 "Urbano"
label val urbano ur

* 1.5.1. Asiste 
gen asiste = 0
replace asiste = 1 if inlist(s05b_10,"1.ASISTE")
label define sino 0 "No" 1 "Sí"
label val asiste sino	
label var asiste "Actualmente, ¿asiste al nivel y curso al que se matriculó ésta gestión 2019?"
* Nota: se define asistencia como % de personas que asisten al establecimiento educativo en el que están matriculados.

* 1.5.2. Education level
gen educ_nivel = .

* Primaria y secundaria

replace educ_nivel = 1 if s05a_02a == "11.NINGUNO"
replace educ_nivel = 1 if s05a_02a == "12.CURSO DE ALFABETIZACIÓN"
replace educ_nivel = 1 if s05a_02a == "13.EDUCACIÓN INICIAL O PRE-ESCOLAR (PRE KINDER/KINDER)"
replace educ_nivel = 1 if s05a_02a == "21.BÁSICO (1 A 5 AÑOS) - SISTEMA ESCOLAR ANTIGUO"  // Es el equivalente de primero a quinto
replace educ_nivel = 1 if s05a_02a == "22.INTERMEDIO (1 A 3 AÑOS) - SISTEMA ESCOLAR ANTIGUO" // Es el equivalente de sexto a octavo
replace educ_nivel = 1 if s05a_02a == "23.MEDIO (1 A 4 AÑOS) - SISTEMA ESCOLAR ANTIGUO" & inlist(s05a_02c,"1","2","3") //Secundaria incompleta
replace educ_nivel = 2 if s05a_02a == "23.MEDIO (1 A 4 AÑOS) - SISTEMA ESCOLAR ANTIGUO" & inlist(s05a_02c,"4") // Es el último nivel de la educación secundaria
replace educ_nivel = 1 if s05a_02a == "31.PRIMARIA (1 A 8 AÑOS) - SISTEMA ESCOLAR ANTERIOR" //Es el equivalente de primero a octavo
replace educ_nivel = 1 if s05a_02a == "32.SECUNDARIA (1 A 4 AÑOS) - SISTEMA ESCOLAR ANTERIOR" & inlist(s05a_02c,"1","2","3") //Secundaria incompleta
replace educ_nivel = 2 if s05a_02a == "32.SECUNDARIA (1 A 4 AÑOS) - SISTEMA ESCOLAR ANTERIOR" & inlist(s05a_02c,"4") //Secundaria completa
replace educ_nivel = 1 if s05a_02a == "41.PRIMARIA (1 A 6 AÑOS) - SISTEMA ESCOLAR ACTUAL" //Primero a sexto
replace educ_nivel = 1 if s05a_02a == "42.SECUNDARIA (1 A 6 AÑOS) - SISTEMA ESCOLAR ACTUAL" & inlist(s05a_02c,"1","2","3","4","5") //Secundaria incompleta
replace educ_nivel = 2 if s05a_02a == "42.SECUNDARIA (1 A 6 AÑOS) - SISTEMA ESCOLAR ACTUAL" & inlist(s05a_02c,"6") //Secundaria completa
replace educ_nivel = 1 if s05a_02a == "51.EDUCACIÓN BÁSICA  DE   ADULTOS (EBA) - EDUCACIÓN DE ADULTOS (SISTEMA ANTIGUO)" //6 grados de educación básica
replace educ_nivel = 1 if s05a_02a == "52.CENTRO DE EDUCACIÓN MEDIA  DE ADULTOS (CEMA) - EDUCACIÓN DE ADULTOS (SISTEMA" & inlist(s05a_02c,"1","2") //Supletorio de media incompleto
replace educ_nivel = 2 if s05a_02a == "52.CENTRO DE EDUCACIÓN MEDIA  DE ADULTOS (CEMA) - EDUCACIÓN DE ADULTOS (SISTEMA" & inlist(s05a_02c,"3") //Supletorio de bachillerato completo
replace educ_nivel = 1 if s05a_02a == "61.EDUCACIÓN JUVENIL ALTERNATIVA (EJA) - EDUCACIÓN ALTERNATIVA Y ESPECIAL" & s05a_02c != "12"
replace educ_nivel = 2 if s05a_02a == "61.EDUCACIÓN JUVENIL ALTERNATIVA (EJA) - EDUCACIÓN ALTERNATIVA Y ESPECIAL" & inlist(s05a_02c,"12")
replace educ_nivel = 1 if s05a_02a == "62.EDUCACIÓN PRIMARIA DE ADULTOS (EPA) - EDUCACIÓN ALTERNATIVA Y ESPECIAL" 
replace educ_nivel = 1 if s05a_02a == "63.EDUCACIÓN SECUNDARIA DE ADULTOS (ESA) - EDUCACIÓN ALTERNATIVA Y ESPECIAL" & inlist(s05a_02c,"1","2")
replace educ_nivel = 2 if s05a_02a == "63.EDUCACIÓN SECUNDARIA DE ADULTOS (ESA) - EDUCACIÓN ALTERNATIVA Y ESPECIAL" & inlist(s05a_02c,"3")
replace educ_nivel = 1 if s05a_02a == "64.PROGRAMA NACIONAL DE POST ALFABETIZACIÓN - EDUCACIÓN ALTERNATIVA Y ESPECIAL"
replace educ_nivel = 1 if s05a_02a == "65.EDUCACIÓN  ESPECIAL - EDUCACIÓN ALTERNATIVA Y ESPECIAL"

* Terciaria y terciaria incompleta
* El grado 8 en educación terciaria hace referencia a que recibió la titulación
replace educ_nivel = 2 if s05a_02a == "71.NORMAL (ESCUELA SUP. DE FORMACIÒN DE  MAESTROS) - EDUCACIÓN SUPERIOR" & s05a_02c != "8"
replace educ_nivel = 3 if s05a_02a == "71.NORMAL (ESCUELA SUP. DE FORMACIÒN DE  MAESTROS) - EDUCACIÓN SUPERIOR" & s05a_02c == "8"
replace educ_nivel = 2 if s05a_02a == "72.UNIVERSIDAD - EDUCACIÓN SUPERIOR" & s05a_02c != "8"
replace educ_nivel = 3 if s05a_02a == "72.UNIVERSIDAD - EDUCACIÓN SUPERIOR" & s05a_02c == "8"
replace educ_nivel = 3 if s05a_02a == "73.POSTGRADO DIPLOMADO - EDUCACIÓN SUPERIOR"
replace educ_nivel = 3 if s05a_02a == "74.POSTGRADO MAESTRÍA - EDUCACIÓN SUPERIOR"
replace educ_nivel = 3 if s05a_02a == "75.POSTGRADO DOCTORADO - EDUCACIÓN SUPERIOR"
replace educ_nivel = 2 if s05a_02a == "76.TÉCNICO DE UNIVERSIDAD - EDUCACIÓN SUPERIOR" & s05a_02c != "8"
replace educ_nivel = 3 if s05a_02a == "76.TÉCNICO DE UNIVERSIDAD - EDUCACIÓN SUPERIOR" & s05a_02c == "8"
replace educ_nivel = 2 if s05a_02a == "77.TÉCNICO DE INSTITUTO TÉCNICO E INSTITUTO TECNOLOGÓGICO  (Duración mayor o igu" & s05a_02c == "1"
replace educ_nivel = 3 if s05a_02a == "77.TÉCNICO DE INSTITUTO TÉCNICO E INSTITUTO TECNOLOGÓGICO  (Duración mayor o igu" & inlist(s05a_02c,"2","3","4")
replace educ_nivel = 2 if s05a_02a == "78.FORMACION SUPERIOR ARTÍSTICA - EDUCACIÓN SUPERIOR"  & s05a_02c != "8"
replace educ_nivel = 3 if s05a_02a == "78.FORMACION SUPERIOR ARTÍSTICA - EDUCACIÓN SUPERIOR" & s05a_02c == "8"
replace educ_nivel = 2 if s05a_02a == "79. INSTITUTOS DE FORMACIÓN MILITAR Y POLICIAL - EDUCACIÓN SUPERIOR" & s05a_02c != "8"
replace educ_nivel = 3 if s05a_02a == "79. INSTITUTOS DE FORMACIÓN MILITAR Y POLICIAL - EDUCACIÓN SUPERIOR" & s05a_02c == "8"
replace educ_nivel = 2 if s05a_02a == "80. EDUCACIÓN TÉCNICA DE ADULTOS (ETA) - EDUCACIÓN SUPERIOR" & s05a_02c == "1"
replace educ_nivel = 3 if s05a_02a == "80. EDUCACIÓN TÉCNICA DE ADULTOS (ETA) - EDUCACIÓN SUPERIOR" & inlist(s05a_02c,"2","3","4")
replace educ_nivel = 3 if s05a_02a == "81.OTROS CURSOS  (Duración menor a 2 años) - EDUCACIÓN SUPERIOR"

cap label define educ_nivel 1 "Primaria o menos" 2 "Secundaria" 3 "Terciaria" 
label val educ_nivel educ_nivel

* 1.5.3. Years of schooling 
destring aestudio, gen(yr_edu)		


** 2. Labour market

* 2.1. Employed - Dummy
gen pet = cond(edad>=14,1,0)

//Dedico a trabajos agricolas o no remunerados
encode s06a_02, gen(agricolas)

//Ausente de un trabajo
encode s06a_03, gen(ausente)

gen ocupado = 0
replace ocupado = 1 if s06a_01 == "1. Si"     
replace ocupado = 1 if inlist(agricolas,2,3,4,5,6,7,8) 
replace ocupado = 1 if inlist(ausente,2,4,5,6,7,8,9,10,11)  
replace ocupado = . if pet == 0

// Horas trabajadas por día * días a la semana trabajados
destring s06b_22 s06b_23aa, replace force
gen hr_trabajadas = s06b_22 * s06b_23aa 

* 2.2. Type of employment (Not standard within countries)
replace s06b_14 = "" if s06b_14 == " "
encode s06b_14, gen(ocupacion)
replace ocupacion = . if ocupado != 1

* 2.2.1. Domestic worker - dummy
gen empleada_domestica = 0
replace empleada_domestica = 1 if ocupacion == 8
replace empleada_domestica = . if ocupado != 1

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente = cond(inlist(ocupacion,3,4),1,0)
replace independiente = . if ocupacion ==.

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 3
replace cuenta_propia = 0 if inlist(ocupacion,1,2,4,5,6,7,8)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,1,2,3,4,5,8)
replace trabajador_rem = . if ocupado != 1

* 2.3. Public employment or education sector - Dummy
gen empleo_publico = 0

	* Autorreportada
replace empleo_publico = 1 if s06b_18 == "1.¿Administración Pública?"
replace empleo_publico = 1 if s06b_18 == "2.¿Empresa Pública (estratégica)?" // Reporta trabajar para una empresa estatal
	
	* Por sector de actividad
gen sector2d=substr(s06b_12a_cod,1,2)	
replace empleo_publico = 1 if sector2d == "84" // 84 CAEB admin publica y defensa
replace empleo_publico = . if ocupado != 1

* 2.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | sector2d == "85" // 85 CAEB enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
destring s06b_21a, gen(n_per_empresa)
gen size_50_100 = .
replace size_50_100 = 1 if inrange(n_per_empresa,1,4)
replace size_50_100 = 2 if inrange(n_per_empresa,5,10)
replace size_50_100 = 3 if inrange(n_per_empresa,11,50)
replace size_50_100 = 4 if inrange(n_per_empresa,51,100)
replace size_50_100 = 5 if n_per_empresa>=101& n_per_empresa!=.
replace size_50_100 = . if ocupado != 1
label define size_50_100 1"1-4" 2"5-10" 3"11-50" 4 "51-100" 5 "101 o más"
label value size_50_100 size_50_100

* 2.5. Economic sector
* Sector de actividad homologado
replace caeb_op = "" if caeb_op == " "
encode caeb_op, gen(sector_activ)
replace sector_activ = . if ocupado != 1

gen sector_rev4 = sector_activ
recode sector_rev4 (1=11) (2=12) (3=8) (4=6) (5=8) (6=9) (7=1) (8=5) (9=2) (10=3) (11=8) (12=8) (13=11) (14=13) (15=8) (16=10) (17=10) (18=14) (19=4) (20=4) (21=7) (22=6)

label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

encode s06b_12a_cod, gen(sector_desagregado_p)
	
* 2.6. Informal worker - Dummy	
* Nota se define informal personas ocupadas que no aportan a la AFP.
* Pregunta: ¿Actualmente esta usted aportando a la AFP?
gen informal = cond(s06g_55=="1. Si",0,1)
replace informal = . if ocupado != 1


** 3. Income

* 3.1. Personal earnings 

* 3.1.1. Create all components of Personal earnings 
destring s06b_22 s06c_25a s06c_26a s06c_26b s06c_27aa s06c_27ba s06c_30*2 s06d_33a s06f_42a s06f_43*1 s06f_46a, replace force

gen sueldo = .  // Salario líquido
replace sueldo = s06c_25a*s06b_22*4.34524 if s06c_25b == "1. Diario"
replace sueldo = s06c_25a*4.34524 if s06c_25b == "2. Semanal"
replace sueldo = s06c_25a*2.17262 if s06c_25b == "3. Quincenal"
replace sueldo = s06c_25a*1 if s06c_25b == "4. Mensual"
replace sueldo = s06c_25a/2 if s06c_25b == "5. Bimestral"
replace sueldo = s06c_25a/3 if s06c_25b == "6. Trimestral"
replace sueldo = s06c_25a/6 if s06c_25b == "7. Semestral"

gen bono_prima = s06c_26a/12  //Bono o prima en los últimos 12 meses
gen aguinaldo = s06c_26b/12   //Aguinaldo en los últimos 12 meses

gen comisiones = .            //Comisiones, destajo, propinas, bonos de transporte o refrigerio
replace comisiones = s06c_27aa*s06b_22*4.34524 if s06c_27ab == "1. Diario"
replace comisiones = s06c_27aa*4.34524 if s06c_27ab == "2. Semanal"
replace comisiones = s06c_27aa*2.17262 if s06c_27ab == "3. Quincenal"
replace comisiones = s06c_27aa*1 if s06c_27ab == "4. Mensual"
replace comisiones = s06c_27aa/2 if s06c_27ab == "5. Bimestral"
replace comisiones = s06c_27aa/3 if s06c_27ab == "6. Trimestral"
replace comisiones = s06c_27aa/6 if s06c_27ab == "7. Semestral"
replace comisiones = s06c_27aa/12 if s06c_27ab == "8. Anual"

gen horas_extra = .           //Horas Extras
replace horas_extra = s06c_27ba*s06b_22*4.34524 if s06c_27bb == "1. Diario"
replace horas_extra = s06c_27ba*4.34524 if s06c_27bb == "2. Semanal"
replace horas_extra = s06c_27ba*2.17262 if s06c_27bb == "3. Quincenal"
replace horas_extra = s06c_27ba*1 if s06c_27bb == "4. Mensual"
replace horas_extra = s06c_27ba/2 if s06c_27bb == "5. Bimestral"
replace horas_extra = s06c_27ba/3 if s06c_27bb == "6. Trimestral"
replace horas_extra = s06c_27ba/6 if s06c_27bb == "7. Semestral"
replace horas_extra = s06c_27ba/12 if s06c_27bb == "8. Anual"

* Pagos en especie

foreach p in alimentacion transporte vestido vivienda servicios{
	
	local alimentacion a
	local transporte b 
	local vestido c 
	local vivienda d 
	local servicios e 
	
	gen `p' = .   //Alimentos y bebidas         
	replace `p' = s06c_30``p''2*s06b_22*4.34524 if s06c_30``p''1  == "1. Diario"
	replace `p' = s06c_30``p''2*4.34524 if s06c_30``p''1  == "2.Semanal"
	replace `p' = s06c_30``p''2*2.17262 if s06c_30``p''1  == "3.Quincenal"
	replace `p' = s06c_30``p''2*1 if s06c_30``p''1  == "4.Mensual"
	replace `p' = s06c_30``p''2/2 if s06c_30``p''1  == "5.Bimestral"
	replace `p' = s06c_30``p''2/3 if s06c_30``p''1  == "6.Trimestral"
	replace `p' = s06c_30``p''2/6 if s06c_30``p''1  == "7.Semestral"
	replace `p' = s06c_30``p''2/12 if s06c_30``p''1  == "8.Anual"
}

egen especie = rowtotal(alimentacion transporte vestido vivienda servicios), m


* Ingreso del trabajador independiente en la ocupación principal

gen ganancia = .           //Ingreso que le queda después de gastos
replace ganancia = s06d_33a*s06b_22*4.34524 if s06d_33b == "1. Diario"
replace ganancia = s06d_33a*4.34524 if s06d_33b == "2.Semanal"
replace ganancia = s06d_33a*2.17262 if s06d_33b == "3.Quincenal"
replace ganancia = s06d_33a*1 if s06d_33b == "4.Mensual"
replace ganancia = s06d_33a/2 if s06d_33b == "5.Bimestral"
replace ganancia = s06d_33a/3 if s06d_33b == "6.Trimestral"
replace ganancia = s06d_33a/6 if s06d_33b == "7.Semestral"
replace ganancia = s06d_33a/12 if s06d_33b == "8.Anual"

egen ing_labp_0 = rowtotal(sueldo bono_prima aguinaldo comisiones horas_extra especie ganancia), m

* Ingresos laborales en la ocupación secundaria
gen sueldo_sec = .           //Salario en la ocupación secundaria
replace sueldo_sec = s06f_42a *s06b_22*4.34524 if s06f_42b  == "1. Diario"
replace sueldo_sec = s06f_42a *4.34524 if s06f_42b  == "2.Semanal"
replace sueldo_sec = s06f_42a *2.17262 if s06f_42b  == "3.Quincenal"
replace sueldo_sec = s06f_42a *1 if s06f_42b  == "4.Mensual"
replace sueldo_sec = s06f_42a /2 if s06f_42b  == "5.Bimestral"
replace sueldo_sec = s06f_42a /3 if s06f_42b  == "6.Trimestral"
replace sueldo_sec = s06f_42a /6 if s06f_42b  == "7.Semestral"
replace sueldo_sec = s06f_42a /12 if s06f_42b  == "8.Anual"

gen horas_exta_sec = s06f_43a1 /12      // Horas extra, primas
gen especie_sec = s06f_43b1/12          // Pagos en especie
gen vivienda_sec =  s06f_43c1/12        // Vivenda

gen ganancia_sec = .           //Ganancia en la educación secundaria
replace ganancia_sec = s06f_46a *s06b_22*4.34524 if s06f_46b  == "1. Diario"
replace ganancia_sec = s06f_46a *4.34524 if s06f_46b == "2.Semanal"
replace ganancia_sec = s06f_46a *2.17262 if s06f_46b == "3.Quincenal"
replace ganancia_sec = s06f_46a *1 if s06f_46b == "4.Mensual"
replace ganancia_sec = s06f_46a /2 if s06f_46b == "5.Bimestral"
replace ganancia_sec = s06f_46a /3 if s06f_46b == "6.Trimestral"
replace ganancia_sec = s06f_46a /6 if s06f_46b == "7.Semestral"
replace ganancia_sec = s06f_46a /12 if s06f_46b == "8.Anual"

* Ingreso total de la ocupación secundaria
egen ing_lab_sec = rowtotal(sueldo_sec horas_exta_sec especie_sec vivienda_sec ganancia_sec), m

egen ing_lab_0 = rowtotal(ing_labp_0 ing_lab_sec), m

* 4.0.5 Ingreso personal comparable con WID (incluye salario, ganancia, vivienda, alimentos, salario/ganancia segunda ocupacion)
egen ing_pers_wid = rowtotal(sueldo alimentacion vivienda ganancia sueldo_sec ganancia_sec), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\Bolivia_2019.dta", replace

**************************************************
**					 BRAZIL 					**
**************************************************

use "$rawdata\BRA_PNADC_2019.dta", clear
sort UPA Trimestre Strata V1008 V1014 V1022 V2003 V2007 V2009 V3013
gen ordering = _n
** 1. General information

* 1.0. Household ID
egen hogar = group(Trimestre UPA Strata V1008 V1014)

* 1.1. Sampling weight
gen fac_exp_yr=V1032
label var fac_exp "Factor de expansión"	 

* 1.2. Age
gen edad=V2009

* 1.3. Gender
gen hombre=V2007
recode hombre (2 = 0)
label var hombre "Sexo (1: Hombre)"
label define hombre 1 "Hombre" 0 "Mujer"
label value hombre hombre

* 1.4. Urban area - dummy
destring V1022, replace
gen urbano=V1022
replace urbano=0 if V1022==2
label define urbano 1"Urbano" 0"Rural"
label value urbano urbano

* 1.5.1. Asiste 
tab V3002
recode V3002 (2 = 0)
gen asiste=V3002
label var asiste "¿Usted asiste actualmente a un establecimiento educativo?"
label value asiste sino

* 1.5.2. Education level
destring V3009A, replace
gen educ_nivel=.
replace educ_nivel= 1 if V3009A>=2 & V3009A<=8 //Primaria o menos
replace educ_nivel= 1 if V3009A==9 & inlist(V3013,1,2) //Secundaria incompleta
replace educ_nivel= 2 if V3009A==9 & inlist(V3013,3,4) //Secundaria completa
replace educ_nivel= 2 if V3009A>=10 & V3009A<=11 
replace educ_nivel= 3 if V3009A>=12 & V3009A<=15

label var educ_nivel "Máximo nivel educativo alcanzado"
format educ_nivel %9.0g

label define educ_nivel 1"Primaria o menos" 2"Secundaria" 3"Terciaria" 
label value educ_nivel educ_nivel

* 1.5.3. Years of schooling 
gen yr_edu = VD3005


** 2. Labour market

* 2.1. Employed - Dummy
gen       ocupado = .
replace   ocupado = 0 if VD4002 == 1 | VD4002 == 2 | VD4001 ==2
replace   ocupado = 1 if VD4002 == 1
label var ocupado "Empleados==1"

* 2.2. Type of employment (Not standard within countries)
gen ocupacion= VD4008
label var ocupacion "Posición ocupacional"
label define ocupacion 1"Empleado sector privado" 2"Trabajador doméstico" 3"Empleado sector público" 4"Empleador" 5"Cuenta propia" 6"Trabajador familiar sin remuneración" 
label value ocupacion ocupacion	

* 3.11. Horas de trabajo
* 3.11.1. Regulares
gen hr_trabajadas=V4039C
label var hr_trabajadas "Horas a la semana que trabaja regularmente"

* 2.2.1. Domestic worker - dummy
gen empleada_domestica=.
replace empleada_domestica=0 if ocupacion!=.
replace empleada_domestica=1 if ocupacion==2
label var empleada_domestica "Trabajador doméstico"

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente=.
replace independiente=0 if ocupacion!=.
replace independiente=1 if ocupacion==4 | ocupacion==5
label var independiente "Trabajador por cuenta propia"

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 5
replace cuenta_propia = 0 if inlist(ocupacion,1,2,3,4,6)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,1,2,3,4,5)
replace trabajador_rem = . if ocupado != 1

* 2.3. Public employment or education sector - Dummy
gen empleo_publico = 0

	* Autorreportada
replace empleo_publico = 1 if ocupacion == 3 // Reporta trabajar para una empresa estatal
	
	* Por sector de actividad
gen sector2d = string(V4013)
replace sector2d=substr(sector2d,1,2)	
replace empleo_publico = 1 if sector2d == "84" // 84 CNAE 2.0 admin publica y defensa
replace empleo_publico = . if ocupado != 1

* 3.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | sector2d == "85" // 85 CNAE 2.0 enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
gen size_50_100 = .
replace size_50_100=1 if V4018==1 
replace size_50_100=2 if V4018==2
replace size_50_100=3 if V4018==3
replace size_50_100=4 if V4018==4
label define size_50_100 1"1-5" 2"6-10" 3"11-50" 4"51 o más"
label value size_50_100 size_50_100

* 2.5. Economic sector
gen sector_rev4 = VD4010
recode sector_rev4 (2=3) (3=5) (4=6) (5=7) (7=8) (8=9) (9=10) (10=11) (11=12) (12=14)
replace sector_rev4 = 2 if V4013>3000 & V4013<3003
label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

gen sector_desagregado_p = VD4010
		
* 2.6. Informal worker - Dummy	
gen informal=.
replace informal=1 if VD4012==2
replace informal=0 if VD4012==1
replace informal=. if ocupado!=1
label var informal "Empleados informales de acuerdo a su afiliación a pensiones"

** 3. Income

* 3.1. Personal earnings 

* 3.1.1. Create all components of Personal earnings 

gen ing_brutoaux= V403412   //Ingreso bruto auxiliar
gen ing_secunaux= V405112     //Ingreso bruto auxiliar segundo trabajo
gen ing_ottaux= V405912 //Variable auxiliar
egen salario = rowtotal(ing_brutoaux ing_secunaux ing_ottaux),m 

gen ing_especieaux= V403422  //Ingreso en especie auxiliar
gen ing_especieaux2= V405122   //Ingreso en especie auxiliar segundo trabajo
gen ing_espaux= V405922 //Variable auxiliar
egen ing_especie = rowtotal(ing_especieaux ing_especieaux2 ing_espaux), m

egen ing_lab_0 =rowtotal(salario ing_especie), m
egen ing_labp_0= rowtotal(ing_brutoaux ing_especieaux), missing

* 6.7 Ingreso personal comparable con WID (incluye salario, ganancia, vivienda, alimentos, salario/ganancia segunda ocupacion)
egen ing_pers_wid = rowtotal(ing_brutoaux ing_secunaux ing_especieaux ing_especieaux2), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\Brazil_2019.dta", replace

**************************************************
**					  CHILE 					**
**************************************************

use "$rawdata\CHL_CASEN_2017.dta", clear
sort folio o 
gen ordering = _n
** 1. General information

* 1.0. Household ID
egen hogar=group(folio)

* 1.1. Sampling weight
gen fac_exp=expr
gen fac_exp_yr = fac_exp
label var fac_exp "Factor de expansión"	 

* 1.2. Age
label var edad "Edad en años"
format edad %9.0g

* 1.3. Gender
gen hombre=sexo
recode hombre (2 = 0)
label var hombre "Sexo (1 = Hombre)"
label define hombre 1 "Hombre" 0 "Mujer"
label values hombre hombre

* 1.4. Urban area - dummy
gen urbano=zona
replace urbano=0 if zona==2
label define ur 0 "Rural" 1 "Urbano"
label val urbano ur

* 1.5.1. Asiste 
recode asiste (2=0)
label var asiste "¿Usted asiste actualmente a un establecimiento educativo?"
label values asiste sino

* 1.5.2. Education level
gen educ_nivel = .
replace educ_nivel=1 if inlist(e6a,1,2,3,4,5,6,7)
replace educ_nivel=1 if e6a == 8 & inlist(e6b,1,2,3,4,5)  // Secundaria incompleta
replace educ_nivel=2 if e6a == 8 & inlist(e6b,6)          // Secundaria completa
replace educ_nivel=1 if e6a == 9 & inlist(e6b,1,2,3)      // Secundaria incompleta
replace educ_nivel=2 if e6a == 9 & inlist(e6b,4)          // Secundaria completa
replace educ_nivel=1 if e6a == 10 & inlist(e6b,1,2,3,4,5) // Secundaria incompleta
replace educ_nivel=2 if e6a == 10 & inlist(e6b,6)         // Secundaria completa
replace educ_nivel=1 if e6a == 11 & inlist(e6b,1,2,3)     // Secundaria incompleta
replace educ_nivel=2 if e6a == 11 & inlist(e6b,4,5)       // Secundaria completa
replace educ_nivel=2 if inlist(e6a,12,14)                 //Terciaria incompleta
replace educ_nivel=3 if inlist(e6a,13,15,16,17)           // Terciaria completa
replace educ_nivel = . if e6b == 99

label var educ_nivel "Máximo nivel educativo alcanzado"
label define educ_nivel 1 "Primaria o menos" 2 "Secundaria" 3 "Terciaria"
label values educ_nivel educ_nivel

* 1.5.3. Years of schooling 
gen yr_edu=esc


** 2. Labour market

* 2.1. Employed - Dummy
gen pet=.
replace pet=1 if edad>=15
replace pet=0 if edad<15

gen ocupado=1 if (o1==1|o2==1|o3==1)&edad>=15
replace ocupado=0 if ocupado==.
replace ocupado = . if pet == 0
label values ocupado sino

* 2.2. Type of employment (Not standard within countries)
gen ocupacion=. 
replace ocupacion=1 if o15==5
replace ocupacion=2 if o15==3|o15==4|o15==8
replace ocupacion=3 if o15==6|o15==7
replace ocupacion=4 if o15==2
replace ocupacion=5 if o15==1
replace ocupacion=6 if o15==9

*Nota: En la construcción de la variable "ocupación", se asume que ser empleado de empresas públicas (o15=4) equivale a ser empleado del gobierno, así como lo es ser empleado del sector público (o15=3). La misma decisión aplica para miembros de las Fuerzas Armadas y del Orden (o15=8).

label define ocupacion 1"Obrero o empleado de empresa particular" 2"Obrero o empleado del gobierno" 3"Empleado doméstico" 4"Trabajador por cuenta propia" 5"Patrón o empleador" 6"Trabajador familiar sin remuneración" 
label value ocupacion ocupacion

* 3.8. Horas trabajadas
gen hr_trabajadas=o10
replace hr_trabajadas = 168 if hr_trabajadas > 168 & hr_trabajadas != .

* 2.2.1. Domestic worker - dummy
gen empleada_domestica = 0
replace empleada_domestica = 1 if ocupacion == 3
replace empleada_domestica = . if ocupado != 1

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente=1 if inlist(ocupacion,4,5)
replace independiente=0 if independiente==.
label var independiente "Trabajador por cuenta propia"
replace independiente = . if ocupado != 1

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 4
replace cuenta_propia = 0 if inlist(ocupacion,1,2,3,5,6)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,1,2,3,4,5)
replace trabajador_rem = . if ocupado != 1

* 2.3. Public employment or education sector - Dummy
gen empleo_publico = 0

	* Autorreportada
replace empleo_publico = 1 if ocupacion == 2 // Reporta trabajar para una empresa estatal
	
	* Por sector de actividad	
replace empleo_publico = 1 if rama1 == 12 | rama1_sub == 12 // admin publica y defensa
replace empleo_publico = . if ocupado != 1

* 4.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | rama1 == 13 | rama1_sub == 13 // enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
gen n_per_empresa=o23
replace n_per_empresa="Sólo 1 persona (entrevistado)" if o23=="A"
replace n_per_empresa="De 2 a 5 personas" if o23=="B"
replace n_per_empresa="De 6 a 9 personas" if o23=="C"
replace n_per_empresa="De 10 a 49 personas" if o23=="D"
replace n_per_empresa="De 50 a 199 personas" if o23=="E"
replace n_per_empresa="De 200 o más personas" if o23=="F"
replace n_per_empresa=" " if o23=="X"	

gen size_50_100 = .
replace size_50_100 = 1 if inlist(n_per_empresa,"Sólo 1 persona (entrevistado)","De 2 a 5 personas")
			replace size_50_100 = 2 if n_per_empresa=="De 6 a 9 personas"
			replace size_50_100 = 3 if inlist(n_per_empresa,"De 10 a 49 personas") 
			replace size_50_100 = 4 if inlist(n_per_empresa,"De 50 a 199 personas","De 200 o más personas") 
			replace size_50_100 = . if ocupado != 1
			label define size_50_100 1 "1-5" 2 "6-9" 3 "10-49" 4 "50 o más"
label value size_50_100 size_50_100

* 2.5. Economic sector
gen sector_rev4 = rama1
recode sector_rev4 (2=1) (3=2) (4=3) (5=4) (6=5) (7=6) (8=6) (9=7) (10=8) (11=8) (12=9) (13=10) (14=10) (15=10) (16=12) (17=13) (999=14)
label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

gen sector_desagregado_p = rama4

* 2.6. Informal worker - Dummy	
gen informal = 1
replace informal = 0 if inlist(o29,1,2,3,4,5,6)
replace informal = . if o29 == 9 | o28 == 9
replace informal = . if ocupado != 1

** 3. Income

* 3.1. Personal earnings 

* 3.1.1. Create all components of Personal earnings 

foreach var of varlist y1 y3a y3b y3c y3d y3e y3f y4a y4b y4c y4d y5a y5b y5c y5d y5e y5f y5g y5h y5i y5j y5k y5l y6 y7 y8 y9 y10 y11 y12a y12b y13a y13b y13c y14a y14b y14c y15a y15b y15c y16a y16b y17 y18a y18b y18c y18d y19n y23a y24 y25e y25f y25g y26_2bm1 y26_2bm2 y26_2c y26_2em1 y26_2em2 y26_2f y26_2g y26_2h y26_2i y26_2j{
    replace `var' = . if `var' == 99
}

*Transformación de ingresos monetarios de asalariados según periodicidad*
*Nota: la siguiente transformación asume que si el individuo reporta un ingreso pero su respuesta sobre la periodicidad del mismo es "NS/NR", su ingreso para la categoría es missing. Esto corresponde a 2% de los asalariados y se mandan a missing por lo que la frecuencia no está disponible.

local monasal "y3a y3b y3c y3d y3e y3f"
foreach a of local monasal {
	gen ma_`a'=.
	replace ma_`a'=0 if `a'==0
	replace ma_`a'=`a'*y2_dias if `a'p==1&y2_dias<99 //Diario cuando dias pactados son reportados
	replace ma_`a'=`a'*30.42 if `a'p==1&y2_dias==99 //Diario cuando dias pactados no son reportados
	replace ma_`a'=`a'*4.35 if `a'p==2 //Semanal
	replace ma_`a'=`a'*2.17 if `a'p==3 //Quincenal
	replace ma_`a'=`a' if `a'p==4 //Mensual
	replace ma_`a'=`a'/2 if `a'p==5 //Bimestral
	replace ma_`a'=`a'/3 if `a'p==6 //Trimestral
	replace ma_`a'=`a'/4 if `a'p==7 //Cuatrimestral
	replace ma_`a'=`a'/6 if `a'p==8 //Semestral
	replace ma_`a'=`a'/12 if `a'p==9 //Anual
}

*Transformación de otros ingresos anuales relacionados al a ocupación principal del asalariado
gen ma_y4a=y4a/12
gen ma_y4b=y4b/12
gen ma_y4c=y4c/12
gen ma_y4d=y4d/12

gen sueldo=y1                			//Salario Líquido
gen horas_extras=ma_y3a        			//Horas Extras
gen comisiones=ma_y3b           		//Comisiones
gen propinas=ma_y3c						//Propinas
gen asignaciones=ma_y3d 				//Asignaciones por transporte, vivienda y educación
gen viaticos=ma_y3e          			//Viáticos No Sujetos A Rendición	
gen otros_mon_ocup1=ma_y3f 				//Otros ingresos monetarios ocupación principal asalariados
gen bonif_aguinaldo=ma_y4a   			//Bonificaciones o aguinaldos (anual mensualizado)
gen gratificaciones=ma_y4b				//Gratificaciones (anual mensualizado)
gen mesesadic=ma_y4c		  			//Décimo tercer mes o meses adicionales (anual mensualizado)
gen otros_mon_anual=ma_y4d     			//Otros ingresos de los asalariados (anual mensualizado)

egen ing_sal_mon=rowtotal(sueldo horas_extras comisiones propinas asignaciones viaticos otros_mon_ocup1 bonif_aguinaldo gratificaciones mesesadic otros_mon_anual), m

* 4.1.1.2. Ingresos en especie
gen y_alimentos=y5a       				//Alimentos o bebidas
gen y_tiquetes_alimentacion=y5b 		//Tiquetes de alimentación
gen y_vivienda=y5c            			//Vivienda o alojamiento
gen y_otro_especie=y5l        			//Otro tipo de redistribución en especie
gen y_vehiculo_usopriv=y5d       		//Vehículo para uso privado
gen y_servicio_transporte=y5e    		//Servicio de transporte
gen y_estacionamiento_grauito=y5f 		// estacionamiento gratuito
gen y_telef=y5g							//Teléfono
gen y_vestimenta=y5h					//Vestimenta
gen y_serv_guarderia=y5i				//Servicios de guardería o sala cuna
gen y_lena=y5j							//Leña
gen y_bienes_servicios_prodemple=y5k	//Bienes o servicios producidos por el empleador	

egen ing_sal_espec=rowtotal(y_alimentos y_tiquetes_alimentacion y_vivienda y_otro_especie y_vehiculo_usopriv y_servicio_transporte y_estacionamiento_grauito y_telef y_vestimenta y_serv_guarderia y_lena y_bienes_servicios_prodemple), m

gen ing_no_ocupados = y11

egen ing_salarial=rowtotal(ing_sal_mon ing_sal_espec ing_no_ocupados), m

gen retiro_gastoshogar=y7    			//Retiro para gastos del hogar de negocios
gen consumo_propio=y8  					//Retiro de productos de su negocio para consumo propio
gen ganancias_prodagrop=y9/12 		//Ganancias por venta de productos silvoagropecuarios
	
egen ing_indep_prin=rowtotal(retiro_gastoshogar consumo_propio ganancias_prodagrop), m
egen ing_indep=rowtotal(ing_indep_prin), m

* 4.3. Ocupación(es) Secundaria(s) (Aplica para asalariados e independientes) 
gen sueldo_ocu2_1=y6    	//Ingreso líquido total por otros trabajos u ocupaciones (grupo 1) 
gen sueldo_ocu2_2=y10		//Ingreso líquido total por otros trabajos u ocupaciones (grupo 2)	

egen ing_ocuotras= rowtotal(sueldo_ocu2_1 sueldo_ocu2_2), m
gen consumo_agrop=y17/12 					//consumo productos agropecuarios producidos por el hogar (anual mensualizado)

egen ing_lab_0 =rowtotal(ing_salarial ing_indep ing_ocuotras consumo_agrop), m
egen ing_labp_0 =rowtotal(ing_salarial ing_indep), m

* 6.0 Ingreso personal comparable con WID (incluye salario, ganancia, vivienda, alimentos, salario/ganancia segunda ocupacion)
egen ing_pers_wid = rowtotal(sueldo y_alimentos y_tiquetes_alimentacion y_vivienda retiro_gastoshogar ganancias_prodagrop sueldo_ocu2_1 sueldo_ocu2_2), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\Chile_2017.dta", replace

**************************************************
**					COLOMBIA 					**
**************************************************

use "$rawdata\COL_GEIH_2019.dta", clear
sort DIRECTORIO SECUENCIA_P ORDEN
gen ordering = _n
** 1. General information

* 1.0. Household ID
egen hogar = group(DIRECTORIO SECUENCIA_P)

* 1.1. Sampling weight
gen fac_exp=FEX_C_2011
label var fac_exp "Factor de expansión"	 
gen fac_exp_yr=fac_exp/12

* 1.2. Age
gen edad=P6040
sum edad
label var edad "Edad en años"
format edad %9.0g

* 1.3. Gender
gen hombre=P6020
recode hombre (2 = 0)
label var hombre "Sexo (1: Hombre)"
label define hombre 1 "Hombre" 0 "Mujer"
label value hombre hombre

* 1.4. Urban area - dummy
destring CLASE, replace
gen urbano=CLASE
replace urbano=0 if CLASE==2
label define urbano 1"Urbano" 0"Rural"
label value urbano urbano

* 1.5.1. Asiste 
destring P6170, replace
gen asiste=P6170
recode asiste (2=0)
label var asiste "¿Usted asiste actualmente a un establecimiento educativo?"
label value asiste sino

* 1.5.2. Education level

destring P6210S1, replace
gen educ_grado=P6210S1
label var educ_grado "Último grado aprobado en máximo nivel educativo alcanzado"

destring P6210, replace

gen educ_nivel=.

*Primaria o menos
replace educ_nivel=1 if P6210==1 | P6210==2 | P6210==3 //Ninguno, preescolar o primaria
replace educ_nivel=1 if P6210==4 //Básica secundaria completa (hasta 9)
replace educ_nivel=1 if P6210==5 & educ_grado<11 //Secundaria incompleta (menos de 11)

*Secundaria
replace educ_nivel=2 if P6210==5 & inlist(educ_grado,11,12,13)
replace educ_nivel=2 if P6210==6 & inlist(P6220,1,2)

*Terciaria
replace educ_nivel=3 if P6210==6 & P6220>2
label var educ_nivel "Máximo nivel educativo alcanzado"
format educ_nivel %9.0g

label define educ_nivel 1"Primaria o menos" 2"Secundaria" 3"Terciaria" 4"Otro"
label value educ_nivel educ_nivel


* 1.5.3. Years of schooling 
gen yr_edu=.
			
* Igual a cero si es no tiene estudios o preescolar
replace yr_edu=0 if P6210==1| P6210==2
* Igual a los grados aprobados para los que tienen básica primaria, básica secundaria o secundaria
replace yr_edu=P6210S1 if P6210==3|P6210==4|P6210==5
* Igual a cinco si están cursando el primer año de básica secundaria pero ya completaron primaria
replace yr_edu=5 if P6210S1==0 & P6210==4
* Educacion terciaria
replace yr_edu=11+P6210S1 if P6210==6
label var yr_edu "Años de educacion"	


** 2. Labour market

* 2.1. Employed - Dummy
* Indicador de participación en la fuerza de trabajo (ocupado + desocupado + inactivo)
destring P6250 P6260 P6270 P6351, replace

gen inlf = .

* Inactivos: todos los no trabajadores 
replace inlf = 3 if P6240 >=2 & P6240 <=6

* 3.1 Ocupados (OC)

* Son las personas que durante el período de referencia se encontraban en una de las siguientes situaciones:

    * 1. Trabajó por lo menos una hora remunerada en dinero o en especie en la semana de referencia.
    replace inlf = 1 if P6240 == 1
    replace inlf = 1 if P6250 == 1
	
    * 2. Los que no trabajaron la semana de referencia, pero tenían un trabajo.
    replace inlf = 1 if P6260 == 1
	
    * 3. Trabajadores familiares sin remuneración que trabajaron en la semana de referencia por lo menos 1 hora
    replace inlf = 1 if P6270 == 1
	

* 3.2. Desocupados (D): Son las personas que en la semana de referencia se encontraban en una de las siguientes situaciones:
destring P6280 P6340 P6351 P6310, replace

    * 1. Desempleo abierto:
    *   a. Sin empleo en la semana de referencia.
    *   b. Hicieron diligencias en el último mes.
    *   c. Disponibilidad.
    replace inlf = 2 if P6240 == 2              & P6250 == 2 & P6351 == 1
    replace inlf = 2 if P6240 == 3              & P6250 == 2 & P6351 == 1
    replace inlf = 2 if P6240 == 4              & P6250 == 2 & P6351 == 1
    replace inlf = 2 if P6240 == 6              & P6250 == 2 & P6351 == 1
    replace inlf = 2 if P6280 == 1 				& P6250 == 2 & P6351 == 1
	
* 3.3 Desempleo oculto:
    *   a. Sin empleo en la semana de referencia.
    *   b. No hicieron diligencias en el último mes, pero sí en los últimos 12 meses y tienen una razón válida de desaliento.
    *   c. Disponibilidad.
	
    * Razones válidas de desempleo:
    *  a. No hay trabajo disponible en la ciudad.
    replace inlf = 2 if P6280 == 2 & P6340 == 1 & P6351 == 1 & P6310 == 2 
	
    *  b. Estuvo esperando que lo llamen.
    replace inlf = 2 if P6280 == 2 & P6340 == 1 & P6351 == 1 & P6310 == 3
	
    *  f. Estuvo esperando la temporada alta.
    replace inlf = 2 if P6280 == 2 & P6340 == 1 & P6351 == 1 & P6310 == 3
	
    *  c. No sabe cómo buscar trabajo.
    replace inlf = 2 if P6280 == 2 & P6340 == 1 & P6351 == 1 & P6310 == 4
	
    *  d. Estuvo cansado de buscar trabajo.
    replace inlf = 2 if P6280 == 2 & P6340 == 1 & P6351 == 1 & P6310 == 5
	
    *  e. No encuentra trabajo apropiado en su oficio o profesión.
    replace inlf = 2 if P6280 == 2 & P6340 == 1 & P6351 == 1 & P6310 == 2
	
    *  g. Carece de la experiencia necesaria.
    replace inlf = 2 if P6280 == 2 & P6340 == 1 & P6351 == 1 & P6310 == 6
	
    *  h. No tiene recursos para instalar un negocio.
    replace inlf = 2 if P6280 == 2 & P6340 == 1 & P6351 == 1 & P6310 == 7
	
    *  i. Los empleadores lo consideran muy joven o muy viejo.
    replace inlf = 2 if P6280 == 2 & P6340 == 1 & P6351 == 1 & P6310 == 8
	
    label define inlf 1  "Employed"   ///
                      2  "Unemployed"   ///
                      3  "Inactive"   ///		

						
* 3.7. Empleados (E)
gen       ocupado = .
replace   ocupado = 0 if inlf == 1 | inlf == 2 | inlf==3
replace   ocupado = 1 if inlf == 1
label var ocupado "Empleados==1"

* 2.2. Type of employment (Not standard within countries)
gen ocupacion=P6430
label var ocupacion "Posición ocupacional"
label define ocupacion 1"Obrero o empleado de empresa particular" 2"Obrero o empleado del gobierno" 3"Empleado doméstico" 4"Trabajador por cuenta propia" 5"Patrón o empleador" 6"Trabajador familiar sin remuneración" 7"Trabajador sin remuneración en empresas o negocios de otros hogares" 8"Jornalero o peón" 9"Otro", modify
label value ocupacion ocupacion		

* 3.13. Horas de trabajo
* 3.13.1. Regulares
gen hr_trabajadas=P6800

* 2.2.1. Domestic worker - dummy
gen empleada_domestica=.
replace empleada_domestica=0 if ocupacion!=.
replace empleada_domestica=1 if ocupacion==3
label var empleada_domestica "Trabajador doméstico"

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente=.
replace independiente=0 if ocupacion!=.
replace independiente=1 if ocupacion==4 | ocupacion==5

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 4
replace cuenta_propia = 0 if inlist(ocupacion,1,2,3,5,6,7,8,9)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,1,2,3,4,5,8)
replace trabajador_rem = . if ocupado != 1

* 2.3. Public employment or education sector - Dummy
gen empleo_publico = 0

	* Autorreportada
replace empleo_publico = 1 if ocupacion == 2 // Reporta trabajar para una empresa estatal
	
	* Por sector de actividad
replace empleo_publico = 1 if RAMA2D == "75" // CIIU REV3 admin publica y defensa
replace empleo_publico = . if ocupado != 1

* 5.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | RAMA2D == "80" // CIIU REV3 enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
gen n_per_empresa=P6870
gen size_50_100 = .
replace size_50_100=1 if inlist(n_per_empresa,1,2,3) //1-5
			replace size_50_100=2 if inlist(n_per_empresa,4) //6-10
			replace size_50_100=3 if inlist(n_per_empresa,5,6,7) //11-50
			replace size_50_100=4 if inlist(n_per_empresa,8) //51-100
			replace size_50_100=5 if n_per_empresa==9 //101 o mas
			label define size_50_100 1"1-5" 2"6-10" 3"11-50" 4 "51-100" 5"101 o más" 
label value size_50_100 size_50_100

* 2.5. Economic sector
gen sector_2d = RAMA2D
destring sector_2d, replace

gen sector_rev4 = 1 if inrange(sector_2d,1,5)
replace sector_rev4 = 2 if inrange(sector_2d,10,14)
replace sector_rev4 = 3 if inrange(sector_2d,15,36)
replace sector_rev4 = 4 if inlist(sector_2d,37,40,41,90)
replace sector_rev4 = 5 if sector_2d == 45
replace sector_rev4 = 6 if inrange(sector_2d,50,55)
replace sector_rev4 = 7 if inrange(sector_2d,60,62)
replace sector_rev4 = 8 if inrange(sector_2d,63,74)
replace sector_rev4 = 9 if sector_2d == 75
replace sector_rev4 = 10 if inrange(sector_2d,80,85)
replace sector_rev4 = 11 if inrange(sector_2d,91,93)
replace sector_rev4 = 12 if sector_2d == 95
replace sector_rev4 = 13 if inlist(sector_2d,99,00)

label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

gen sector_desagregado_p = RAMA4D

* 2.6. Informal worker - Dummy	
destring P6920 P6980S1, replace

*	A. Cotiza en fondo de pensiones			
gen informal_pension=.
replace informal_pension=1 if P6920==2 & P6980S1==. & P6980S2==.
replace informal_pension=0 if P6920==1 | P6980S1==1 | P6980S2==1

gen informal=.
replace informal=1 if informal_pension==1
replace informal=0 if informal_pension==0 
replace informal=. if ocupado!=1
label var informal "Empleados en el sector informal de acuerdo a su afiliación a pensiones"

** 3. Income

* 3.1. Personal earnings 

* 3.1.1. Create all components of Personal earnings 
foreach var in  P6500 P6510S1 P7070 P7422S1 P7472S1  P6750 P550 P6590S1 P6600S1 P6610S1 P6620S1 P6585S1A1 P6585S2A1 P6585S3A1 P6585S4A1 P6545S1 P6580S1 P6630S1A1 P6630S2A1 P6630S3A1 P6630S4A1 P6630S6A1 P7500S1A1 P7500S2A1 P7500S3A1 P7510S1A1 P7510S2A1 P7510S3A1 P750S1A1 P750S2A1 P1661S1A1 P1661S2A1 P1661S3A1 P1661S4A2 P750S3A1 P7510S5A1 P7510S6A1 P7510S7A1 {
    replace `var'=. if `var'==98 | `var'==99 | `var'==999 | `var'==9999 | `var'==99999
}

* 4. Ingresos laborales	
* Ocupación principal	
gen       w_m_gross = P6500    //Ingreso laboral bruto
gen       ing_hrext = P6510S1 //Ingreso por concepto de horas extra

// ing_ocu1 es el ingreso laboral neto despues de quitarle horas extra y bonificaciones para las personas que ya habian incluido ingresos por esos conceptos en w_m_gross
gen ing_ocu1 = w_m_gross
replace ing_ocu1 = ing_ocu1-ing_hrext if P6510S2==1 & ing_hrext!=.

gen cesantias     = P7510S6A1/12      //Ingresos por concepto de cesantías y/o intereses a las cesantías


*Ocupación secundaria
gen       ing_ocu2  = P7070   //Ingreso laboral del segundo trabajo
gen       ing_desp  = P7422S1 //Ingresos del mes pasado por conceptos de trabajo (desocupados)
gen       ing_inac  = P7472S1   //Ingresos del mes pasado por conceptos de trabajo (inactivos)

* 4.1. Ganancia neta 
destring P6750 P550 P6510S2, replace
gen       i_laboral = P6750   //Ganancias del mes pasado

forvalues i=2/12{
    replace i_laboral = i_laboral/`i' if P6760 == `i'
}

replace i_laboral=. if i_laboral==30
replace i_laboral=. if i_laboral==40

* 4.2. Utilidad negocio (12 meses)
gen      utilidades =      P550/12
label var utilidades "12m profit from crop RURA"


* 4.3. Salario laboral nominal
gen ing_laboral_nominal = w_m_gross
replace ing_laboral_nominal=i_laboral if ing_laboral==.
label var ing_laboral_nominal "Ingreso laboral mensual por ocupación principal"	

	
* 5. Ingresos en especie	
destring P6590S1, replace
gen ing_alimentos=P6590S1  //Alimentos como parte de pago

destring P6600S1, replace
gen ing_viv=P6600S1  //Vivienda como parte de pago

destring P6610S1, replace
gen ing_transporte=P6610S1  //Transporte como parte de pago

destring P6620S1, replace
gen ing_otros=P6620S1  //Otros como parte de pago:electrodomésticos, ropa..

*Total ingresos en especie
egen ing_especie=rowtotal(ing_alimentos ing_viv ing_transporte ing_otros), m
label var ing_especie "Ingresos en especie como parte de pago"

* 6. Subsidios- Primas
gen sub_alim =  P6585S1A1    //Subsidio de alimentación
replace ing_ocu1 = ing_ocu1-sub_alim if P6585S1A2==1 & sub_alim!=.

gen sub_trans = P6585S2A1      //Subsidio de transporte
replace ing_ocu1 = ing_ocu1-sub_trans if P6585S2A2==1 & sub_trans!=.

gen sub_fam = P6585S3A1        //Subsidio familiar
replace ing_ocu1 = ing_ocu1-sub_fam if P6585S3A2==1 & sub_fam!=.

gen sub_educ = P6585S4A1  //Subsidio educativo
replace ing_ocu1 = ing_ocu1-sub_educ if P6585S4A2==1 & sub_educ!=.

gen primas_0 = P6545S1            //Primas(técnica, de antigüedad, clima, orden público, otras , etc)
replace ing_ocu1 = ing_ocu1-primas_0 if P6545S2==1 & primas!=.

gen bonif = P6580S1         //Bonificaciones mensuales
replace ing_ocu1 = ing_ocu1-bonif if P6580S2==1 & bonif!=.

gen prima_serv = P6630S1A1/12  if  P6630S1A1!=100 //Primas de servicios

gen prima_nav = P6630S2A1/12  //Prima de navidad

gen prima_vac = P6630S3A1/12   //Prima de vacaciones

gen bonif_an = P6630S4A1/12     //Bonificaciones anuales

gen acc_lab = P6630S6A1/12      //Pagos por accidentes de trabajo

egen salario =rowtotal(ing_ocu1 ing_hrext ing_ocu2 ing_desp ing_inac), m
egen primas = rowtotal (sub_alim sub_trans sub_fam sub_educ primas bonif prima_serv prima_nav prima_vac bonif_an cesantias), m

egen ing_lab_0 =rowtotal(salario i_laboral ing_especie utilidades primas), m
egen ing_labp_0 =rowtotal(ing_ocu1 i_laboral utilidades ing_especie), missing

* 9.8 Ingreso personal comparable con WID (incluye salario, ganancia, vivienda, alimentos, salario/ganancia segunda ocupacion)
egen ing_pers_wid = rowtotal(ing_ocu1 ing_ocu2 i_laboral ing_alimentos ing_viv), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\Colombia_2019.dta", replace

**************************************************
**					COSTA RICA 					**
**************************************************

// Must download Costa Rica data as registration ir required.
// It comes in sav format

if fileexists("${rawdata}/CRI_ENAHO_2019.dta")==0 {
	if fileexists("${rawdata}/ENAHO 2019.sav")==0 {
		dis as error "ENAHO 2019.sav not found. Please register and download it from the Costa Rican Statistics Agency. See Readme."
		exit 
	}
	else{
		import spss using "${rawdata}/ENAHO 2019.sav", clear
		save "${rawdata}/CRI_ENAHO_2019.dta", replace
	}
}

use "$rawdata\CRI_ENAHO_2019.dta", clear
sort UPM CUESTIONARIO HOGAR LINEA
gen ordering = _n
** 1. General information

* 1.0. Household ID
egen hogar = group(UPM CUESTIONARIO HOGAR)

* 1.1. Sampling weight
gen fac_exp = FACTOR 
label var fac_exp "Factor de expansión"
gen fac_exp_yr=fac_exp

* 1.2. Age
gen edad=A5
label var edad "Edad en Años"

* 1.3. Gender
gen hombre=.
replace hombre=1 if A4==1
replace hombre=0 if A4==2
label define hombre 0 "Mujer" 1 "Hombre"
label values hombre hombre	

* 1.4. Urban area - dummy
gen urbano=.
replace urbano=1 if ZONA==1
replace urbano=0 if ZONA==2
label var urbano "Urbano/Rural"
label define urbano 0"Rural" 1"Urbano"
label value urbano urbano

* 1.5.1. Asiste 
gen asiste=cond(A13==0,0,1)
replace asiste=. if A13==.
label var asiste "¿Usted asiste actualmente a un establecimiento educativo?"
label define asiste 1"Sí" 0"No"
label values asiste asiste


* 1.5.2. Education level
gen educ_nivel=.
replace educ_nivel=1 if inlist(NivInst,0,1,2,3)
*Secundaria
replace educ_nivel=2 if inlist(NivInst,4,5,6)
replace educ_nivel=2 if NivInst==7 & inlist(A16B,0,3)
*Terciaria 
replace educ_nivel=3 if NivInst==7 & inlist(A16B,1,2,4,7,8)
replace educ_nivel=3 if NivInst==8
label define educ_nivel 1"Primaria o menos" 2"Secundaria" 3"Terciaria" 
label value educ_nivel educ_nivel

* 1.5.3. Years of schooling 
gen yr_edu=Escolari
replace yr_edu=. if yr_edu==99
label var yr_edu "Años de educación"


** 2. Labour market

* 2.1. Employed - Dummy
gen pet=.
replace pet=1 if edad>=15
replace pet=0 if edad<15

gen cond_act=.

* 3.1.2. Ocupados
replace cond_act=1 if  B1==1 & pet==1
replace cond_act=1 if  B2==1 | B2==2 | B2==3 | B2==4 | B2==5 | B2==6 | B2==7 | B2==8 & pet==1
replace cond_act=1 if  B3==1 & pet==1
replace cond_act=1 if  B5==1 | B5==2 | B5==3 | B5==4 | B5==5 & pet==1

* 3.1.3. Desocupados
replace cond_act=2 if  (B6==8 | B6==9) & pet==1
replace cond_act=2 if ( B7A==1 | B7B==2 | B7C==3 | B7D==4 | B7E==5 | B7F==6 | B7G==7 | B7H==8 | B7I==9 | B7J==10 | B7K==11) & pet==1
replace cond_act=2 if  B8==1 | B8==2 | B8==3 & pet==1

* 3.1.4. Inactivos
replace cond_act=3 if (B6==1 | B6==2 | B6==3 | B6==4 | B6==5 | B6==6 | B6==7) & pet==1
replace cond_act=3 if ((B6==8 | B6==9) & (B8==4 | B8==5 | B8==6 | B8==7 | B8==8 | B8==9 | B8==10 | B8==11 | B8==12 | B8==13 | B8==14 | B8==15)) & pet==1

label define cond_act 1  "Ocupado"   ///
                      2  "Desempleado"   ///
                      3  "Inactivo"   ///		
					 
						
* 3.3. Ocupados (O)
gen       ocupado = .
replace   ocupado = 0 if cond_act == 1 | cond_act == 2 | cond_act==3
replace   ocupado = 1 if cond_act == 1
label var ocupado "Empleados==1"

* 2.2. Type of employment (Not standard within countries)
gen ocupacion=PosiEmpPri
label var ocupacion "Posición ocupacional"
label define ocupacion 11"Asalariada de hogar privado" 12"Asalariada de empresa o institución" 13"Auxiliar no remunerado" 21"Empleadora" 22"Cuenta Propia"
label value ocupacion ocupacion			

* 3.9. Horas de trabajo
* 3.9.1. Regulares
gen hr_trabajadas=HorNorPri
replace hr_trabajadas = . if hr_trabajadas == 999

* 2.2.1. Domestic worker - dummy
gen empleada_domestica=.
replace empleada_domestica=0 if ocupacion!=.
replace empleada_domestica=1 if ocupacion==11
label var empleada_domestica "Trabajador doméstico"

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente=.
replace independiente=0 if ocupacion!=.
replace independiente=1 if ocupacion==21 | ocupacion==22
label var independiente "Trabajador por cuenta propia"

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 22
replace cuenta_propia = 0 if inlist(ocupacion,11,12,13,21)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,11,12,21,22)
replace trabajador_rem = . if ocupado != 1

* 2.3. Public employment or education sector - Dummy
gen empleo_publico = 0

	* Autorreportada
replace empleo_publico = 1 if inlist(SecInsPri,1,2) // Reporta trabajar para una empresa estatal
	
	* Por sector de actividad
replace empleo_publico = 1 if RamaEmpPri == 15 // admin publica y defensa
replace empleo_publico = . if ocupado != 1

* 6.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | RamaEmpPri == 16 // enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
gen size_50_100 = .
replace size_50_100=1 if inlist(C10,1,2,3,4) //1-4
			replace size_50_100=2 if inlist(C10,5,6,7,8,9) //5-9
			replace size_50_100=3 if inlist(C10,10,11) //10-29
			replace size_50_100=4 if inlist(C10,12) //30-99
			replace size_50_100=5 if C10==13 //100 o mas
			replace size_50_100=. if C10==99
			
			label define size_50_100 1"1-4" 2"5-9" 3"10-29" 4 "30-99" 5"100 o más"
label value size_50_100 size_50_100

* 2.5. Economic sector
gen sector_rev4 = RamaEmpPri
recode sector_rev4 (5=4) (6=5) (7=6) (8=7) (9=6) (10=8) (11=8) (12=8) (13=8) (14=8) (15=9) (16=10) (17=10) (18=11) (19=11) (20=12) (21=13) (99=14)
label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

gen sector_desagregado_p = RamaEmpPri

* 2.6. Informal worker - Dummy	
gen informal = .
notes informal: variable not comparable to our definition

** 3. Income

* 3.1. Personal earnings 

* 3.1.1. Create all components of Personal earnings 
* Ocupación principal

* 4.1. Asalariados
*Monetarios
gen sal_br= spmb       //Salario principal monetario bruto
gen propinas= ipsp     //Propinas ocu. principal
gen aguinaldo= asp     //Aguinaldo ocupación principal
gen sal_esco= sesp     //Salario escolar ocu. principal
gen bonif= bsp         //Bonificaciones
gen otros= oisp         //Otros ingresos

*No monetarios
gen sal_nma= spnma      //Salario no monetario alimentación
gen sal_nmv= spnmv      //Salario no monetario vivienda
gen sal_nmt= spnmt      //Salario principal no monetario transporte
gen sal_nmvh= spnmvh      //Salario principal no monetario vehículo
gen sal_nmo= spnmo      //Salario principal no monetario otros

* Ocupación secundaria
* 4.3. Asalariados
gen sal_soc= ssmb     //Salario secundario monetario bruto
gen sal_nmsoc= ssnm   //Salario secundario no monetario

* 4.4. Independientes
gen sal_ind2= ssif    //Salario secundario independiente
gen agu_ind2= asif    //Aguinaldo secundario 
gen div_inp2= dsif    //Dividendos secundario
gen gan_ind2= gsi     //Ganancia secundario 
gen ing_nm2= inmsi    //Ingreso no monetario secundario

* 4.2. Independientes

*Monetarios
gen sal_ind= spif      //Salario principal independiete formal
gen agu_ind= aif       //Aguinaldo principal independiente formal
gen div_ind= dif       //Dividendos principal independiente formal
gen gan_ind= gpina     //Ganancia principal indep. no agro
gen gan_soc= gpsfi     //Ganancia princial socio fam
gen gan_agro= gpia     //Ganancia principal independiente agro

*No monetarios
gen ing_nom= inmpina   //Ingreso no monterario indep. no agro
gen ing_nma= inmpia    //Ingreso no monetario indep. agro

egen salario = rowtotal(sal_br sal_soc), m

egen ing_especie = rowtotal (sal_nma sal_nmv sal_nmt sal_nmvh sal_nmo  sal_nmsoc ing_nm2 ing_nom ing_nma), m 

egen primas = rowtotal (propinas aguinaldo sal_esco bonif otros agu_ind agu_ind2), m

egen i_laboral = rowtotal (sal_ind gan_ind gan_soc gan_agro sal_ind2 gan_ind2), m

egen utilidades = rowtotal(div_ind  div_inp2),m 

egen ing_lab_0 = rowtotal (salario ing_especie primas i_laboral utilidades), m
egen ing_labp_0= rowtotal(sal_ind agu_ind div_ind gan_ind gan_soc gan_agro ing_nom ing_nma sal_br propinas aguinaldo sal_esco bonif otros sal_nma sal_nmv sal_nmt sal_nmvh sal_nmo), missing

* Ingreso personal comparable con WID (incluye salario, ganancia, vivienda, alimentos, salario/ganancia segunda ocupacion)
egen ing_pers_wid = rowtotal(sal_br sal_soc sal_nma sal_nmv sal_ind gan_ind gan_soc gan_agro sal_ind2 gan_ind2), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\CostaRica_2019.dta", replace

**************************************************
**				DOMINICAN REPUBLIC 				**
**************************************************

// Must download Dominican Republic data. Access has to be requested. See Readme.
// Test if file DOM_ENCFT_2019.dta exists
if fileexists("$rawdata\DOM_ENCFT_2019.dta") == 0 {
	if fileexists("${rawdata}/Base ENCFT 20181 - 20194.xlsx")==0{
		display as error "File DOM_ENCFT_2019.dta does not exist. Please request access to the data from the Dominican Republic Central Bank and save it in the folder $rawdata." 
		exit 
	}
	else{
		** Open modules and save in temp folder
		local bases `""Vivienda" "Hogar" "Miembros""'

		* 1.2 20181 - 20194
		foreach x of local bases{
			import excel using "${rawdata}/Base ENCFT 20181 - 20194.xlsx", sheet("`x'") firstrow clear
			compress
			save "${rawdata}/`x'_20181_20194.dta", replace
		}

		** Merge modules
		local periodos "20181_20194"

		foreach x of local periodos{
			use "${rawdata}/Miembros_`x'.dta", clear
			merge m:1 HOGAR VIVIENDA TRIMESTRE using "${rawdata}/Hogar_`x'.dta", nogen
			merge m:1 VIVIENDA TRIMESTRE using "${rawdata}/Vivienda_`x'.dta", nogen
			erase "${rawdata}/Miembros_`x'.dta"
			erase "${rawdata}/Hogar_`x'.dta"
			erase "${rawdata}/Vivienda_`x'.dta"
		}

		keep if ANO == 2019

		** Save 
		save "${rawdata}/DOM_ENCFT_2019.dta", replace


	}
	
	
}

use "$rawdata\DOM_ENCFT_2019.dta", clear
sort VIVIENDA TRIMESTRE HOGAR MIEMBRO 
gen ordering = _n
** 1. General information
gen yr = 2019

* 1.0. Household ID
egen hogar = group(HOGAR VIVIENDA TRIMESTRE)
gen mes = MES

* 1.1. Sampling weight
gen fac_exp = FACTOR_EXPANSION 
gen fac_exp_yr = fac_exp/4

* 1.2. Age
gen edad = EDAD 
notes edad: Edad está truncada en 99

* 1.3. Gender
gen hombre = SEXO 
recode hombre (2 = 0)
label define sx 0 "Mujer" 1 "Hombre"
label val hombre sx	

* 1.4. Urban area - dummy
gen urbano = ZONA
recode urbano (2 = 0)
label define ur 0 "Rural" 1 "Urbano"
label val urbano ur

* 1.5.1. Asiste 
gen asiste = ASISTE_CENTRO_EDUCATIVO
recode asiste (2 = 0)
label val asiste sino	
* Nota: ¿ Está asistiendo a la escuela , colegio o universidad? Se pregunta a mayores de 3 años

* 1.5.2. Education level
gen educ_grado = ULTIMO_ANO_APROBADO

* 1.14 Nivel educativo
* ¿Cuál es el título o diploma de mayor nivel que ... ha recibido?
label define educ1 1 "Bachiller" 2 "Técnico o tecnológico" 3 "Universitario" 4 "Post grado" 5 "Maestría" 6 "Doctorado" 7 "Ninguno" 8 "Primaria", modify
label val MAYOR_NIVEL_OBTENIDO educ1

label define educ0 1 "Pre-escolar" 2 "Primario" 3 "Secundario" 4 "Secundario - tecnico" 5 "Universitario" 6 "Post-grado" 7 "Maestria" 8 "Doctorado" 9 "Ninguno" 10 "QUISQUEYA APRENTE CONTIGO" 99 "Otro", modify
label val NIVEL_ULTIMO_ANO_APROBADO educ0

** Nota: La variable MAYOR_NIVEL_OBTENIDO presenta inconsistencias como personas menores de 10 años con posgrado y otras. Se escoge usar NIVEL_ULTIMO_ANO_APROBADO para ser consistente

gen educ_nivel = . 
replace educ_nivel = 1 if inlist(NIVEL_ULTIMO_ANO_APROBADO,1,2,9,10)
replace educ_nivel = 1 if NIVEL_ULTIMO_ANO_APROBADO == 3 & inlist(educ_grado,1,2,3) // Secundaria incompleta
replace educ_nivel = 2 if NIVEL_ULTIMO_ANO_APROBADO == 3 & educ_grado == 4 // Secundaria completa
replace educ_nivel = 1 if NIVEL_ULTIMO_ANO_APROBADO == 4 & inlist(educ_grado,1,2,3) // Secundaria técnica incompleta
replace educ_nivel = 2 if NIVEL_ULTIMO_ANO_APROBADO == 4 & educ_grado == 4 // Secundaria técnica completa
replace educ_nivel = 2 if NIVEL_ULTIMO_ANO_APROBADO == 5 & inlist(MAYOR_NIVEL_OBTENIDO,1,7,8) // Universitario incompleto
replace educ_nivel = 3 if NIVEL_ULTIMO_ANO_APROBADO == 5 & inlist(MAYOR_NIVEL_OBTENIDO,2,3,4,5,6) // Universitario completo
replace educ_nivel = 3 if inlist(NIVEL_ULTIMO_ANO_APROBADO,6,7,8) // Posgrados

replace educ_nivel = 3 if NIVEL_ULTIMO_ANO_APROBADO == 99 & inlist(MAYOR_NIVEL_OBTENIDO,7,8) // Otro con título primaria o menos
replace educ_nivel = 3 if NIVEL_ULTIMO_ANO_APROBADO == 99 & inlist(MAYOR_NIVEL_OBTENIDO,1) // Otro con título terciario
replace educ_nivel = 3 if NIVEL_ULTIMO_ANO_APROBADO == 99 & inlist(MAYOR_NIVEL_OBTENIDO,2,3,4,5,6) // Otro con título terciario

cap label define educ 1 "Primaria o menos" 2 "Secundaria" 3 "Terciaria" 
label val educ_nivel educ

* 1.5.3. Years of schooling 
gen yr_edu = .
replace yr_edu = 0 if inlist(NIVEL_ULTIMO_ANO_APROBADO,1,9,10,99)
replace yr_edu = educ_grado if NIVEL_ULTIMO_ANO_APROBADO == 2
replace yr_edu = educ_grado+8 if inlist(NIVEL_ULTIMO_ANO_APROBADO,3,4)
replace yr_edu = educ_grado+12 if inlist(NIVEL_ULTIMO_ANO_APROBADO,5)
replace yr_edu = educ_grado+8 if inlist(NIVEL_ULTIMO_ANO_APROBADO,3,4)
replace yr_edu = educ_grado+16 if inlist(NIVEL_ULTIMO_ANO_APROBADO,6,7)
replace yr_edu = educ_grado+18 if inlist(NIVEL_ULTIMO_ANO_APROBADO,8)


** 2. Labour market

* 2.1. Employed - Dummy
gen pet = cond(edad>=15,1,0)
gen ocupado = OCUPADO 
replace ocupado = . if pet == 0

* 2.2. Type of employment (Not standard within countries)
gen ocupacion = GRUPO_CATEGORIA 
tab ocupacion
*Arreglar ocupación
gen ocup = .
replace ocup = . if ocupacion == "Población sin categoría"
replace ocup = 1 if ocupacion == "Cuenta propia"
replace ocup = 2 if ocupacion == "Empleado del estado"
replace ocup = 3 if ocupacion == "Empleado privado"
replace ocup = 4 if ocupacion == "Familiar no remunerado"
replace ocup = 5 if ocupacion == "Patrono o socio activo"
drop ocupacion
rename ocup ocupacion
label define ocupacion 1 "Cuenta propia" 2 "Empleado del estado" 3 "Empleado privado" 4 "Familiar no remunerado" 5 "Patrono o socio activo"
label val ocupacion ocupacion

gen hr_trabajadas = HORAS_TRABAJA_SEMANA_PRINCIPAL

* 2.2.1. Domestic worker - dummy
gen empleada_domestica = .
notes empleada_domestica: not available in DOM

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente = cond(inlist(ocupacion,1,5),1,0)
replace independiente=. if ocupado!=1

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 1
replace cuenta_propia = 0 if inlist(ocupacion,2,3,4,5)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,1,2,3,5)
replace trabajador_rem = . if ocupado != 1

* 2.5. Economic sector
gen sector_activ = GRUPO_RAMA
replace sector_activ = "" if sector_activ == "Población sin rama de actividad"

gen sector_rev4 = . 
replace sector_rev4 = 1 if sector_activ == "Agrícultura y ganadería" 
replace sector_rev4 = 2 if inrange(RAMA_PRINCIPAL_COD,111,240) 
replace sector_rev4 = 3 if sector_activ == "Industrias"
replace sector_rev4 = 4 if sector_activ == "Electricidad y agua"
replace sector_rev4 = 5 if sector_activ == "Construcción"
replace sector_rev4 = 6 if sector_activ == "Comercio" | sector_activ == "Hoteles, bares y restaurantes"
replace sector_rev4 = 7 if sector_activ == "Transporte y comunicaciones"
replace sector_rev4 = 8 if sector_activ == "Intermediarios y financieras"
replace sector_rev4 = 9 if sector_activ == "Administración pública y defensa"
replace sector_rev4 = 10 if sector_activ == "Enseñanza" | sector_activ == "Salud y asistencia social"
replace sector_rev4 = 11 if sector_activ == "Otros servicios"

label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

gen sector_desagregado_p = RAMA_PRINCIPAL_COD

* 2.3. Public employment or education sector - Dummy
gen empleo_publico = 0

	* Autorreportada
replace empleo_publico = 1 if ocupacion == 2 // Reporta trabajar para una empresa estatal
	
	* Por sector de actividad
replace empleo_publico = 1 if sector_activ == "Administración pública y defensa" // admin publica y defensa
replace empleo_publico = . if ocupado != 1

* 7.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | sector_activ == "Enseñanza" // enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
replace TOTAL_PERSONAS_TRABAJAN_EMP = . if TOTAL_PERSONAS_TRABAJAN_EMP==98

* La variable CANTIDAD_PERSONAS_TRABAJAN_EMP es numérica para empresas que tienen entre 1 y 10 trabajadores
replace CANTIDAD_PERSONAS_TRABAJAN_EMP = . if CANTIDAD_PERSONAS_TRABAJAN_EMP == 98
gen n_per_empresa = TOTAL_PERSONAS_TRABAJAN_EMP

gen size_50_100 = .
replace size_50_100 = 1 if inrange(CANTIDAD_PERSONAS_TRABAJAN_EMP,1,4) //1-4
			replace size_50_100 = 2 if inrange(CANTIDAD_PERSONAS_TRABAJAN_EMP,5,10) //5-10
			replace size_50_100 = 1 if n_per_empresa == 1 & CANTIDAD_PERSONAS_TRABAJAN_EMP == . //reportan categoria agregada pero no continua
			replace size_50_100 = 3 if inlist(n_per_empresa,2,3,4) //11-50
			replace size_50_100 = 4 if inlist(n_per_empresa,5) //51-99
			replace size_50_100 = 5 if n_per_empresa==6 //100 o mas
			replace size_50_100 = . if ocupado != 1
			label define size_50_100 1 "1-4" 2 "5-10" 3 "11-50" 4 "51-99" 5 "100 o más"
label value size_50_100 size_50_100

* 2.6. Informal worker - Dummy	
gen informal = 1
replace informal = 0 if GRUPO_EMPLEO ==  "Empleo Formal"
replace informal = . if ocupado != 1

** 3. Income

* 3.1. Personal earnings 

* 3.1.1. Create all components of Personal earnings 

* 3.1.1 Ingreso asalariados ocupación principal

gen sueldo = SUELDO_BRUTO_AP_MONTO

* Convertir a mensual
replace sueldo = sueldo*TIEMPO_RECIBE_PAGO_DIAS_AP*4.33 if TIEMPO_RECIBE_PAGO_AP == 1 
replace sueldo = sueldo*4.33 if TIEMPO_RECIBE_PAGO_AP == 2
replace sueldo = sueldo*2.165 if TIEMPO_RECIBE_PAGO_AP == 3

* Convertir a DOP si reportan en USD 
//NOTA: Estos son los meses que tenían observaciones con USD en estos años. Se debe ajustar dependiendo del año que se corra.
replace sueldo = sueldo*50.15 if yr==2019 & mes==1 & SUELDO_BRUTO_AP_MONEDA=="USD"
replace sueldo = sueldo*50.29 if yr==2019 & mes==2 & SUELDO_BRUTO_AP_MONEDA=="USD"
replace sueldo = sueldo*50.09 if yr==2019 & mes==3 & SUELDO_BRUTO_AP_MONEDA=="USD"
replace sueldo = sueldo*50.4 if yr==2019 & mes==5 & SUELDO_BRUTO_AP_MONEDA=="USD"
replace sueldo = sueldo*50.47 if yr==2019 & mes==6 & SUELDO_BRUTO_AP_MONEDA=="USD"
replace sueldo = sueldo*49.75 if yr==2018 & mes==10 & SUELDO_BRUTO_AP_MONEDA=="USD"

* 3.1.2 Comisiones y pagos extra 
gen comisiones = COMISIONES_AP_MONTO     //Comisiones ocupación principal
gen propinas = PROPINAS_AP_MONTO         //Propinas ocupación principal
gen horas_extra = HORAS_EXTRA_AP_MONTO   //Horas extra ocupación principal
gen otros_pagos = OTROS_PAGOS_AP_MONTO   //Otros pagos extra
* 3.1.3 Otros pagos que son anuales
gen vacaciones = VACACIONES_AP_MONTO/12           //Vacaciones bonificadas
gen bonificacion = BONIFICACION_AP_MONTO/12       //Bonificación
gen regalias = REGALIA_AP_MONTO/12                //Regalias
gen incentivo = INCENTIVO_ANTIGUEDAD_AP_MONTO/12  //Incentivo antigüedad
gen dividendos = DIVIDENDOS_AP_MONTO/12           //Dividendos
gen beneficios = BENEFICIOS_MARGINALES_AP_MONTO/12 //Beneficios marginales
gen utilidades = UTILIDAD_EMPRESARIAL_AP_MONTO/12   //Utilidades empresariales
gen otros_beneficios = OTROS_BENEFICIOS_AP_MONTO/12  //Otros beneficios 

* 3.1.3 Pagos mensuales en especie
gen alimentacion = ALIMENTACION_ESPECIE_AP_MONTO   //Especie: alimentación
gen vivienda = VIVIENDA_ESPECIE_AP_MONTO           //Especie: vivienda
gen transporte = TRANSPORTE_ESPECIE_AP_MONTO       //Especie: transporte
gen gasolina = GASOLINA_ESPECIE_AP_MONTO           //Especie: gasolina
gen otros_especie = OTROS_ESPECIE_AP_MONTO         //Especie: otros pagos

* 3.2 Ingreso en la ocupación principal de independientes

* 3.2.1 Para agropecuarios o consultores
gen ganancia = GANANCIA_IN_PRODUCTOR_MONTO       //Ganancia de la producción o negocio

* 3.2.2 Para cuenta propia
gen ingreso_indep = INGRESO_ACTIVIDAD_IN_MONTO  //Ingresos de producción o negocio

* Convertir a mensual
replace ingreso_indep = ingreso_indep*INGRESO_ACTIVIDAD_IN_DIAS*4.33 if INGRESO_ACTIVIDAD_IN_PERIODO == 1 
replace ingreso_indep = ingreso_indep*4.33 if INGRESO_ACTIVIDAD_IN_PERIODO == 2
replace ingreso_indep = ingreso_indep*2.165 if INGRESO_ACTIVIDAD_IN_PERIODO == 3

* Convertir a DOP si reportan en USD
replace ingreso_indep = ingreso_indep*50.15 if yr==2019 & mes==1 & INGRESO_ACTIVIDAD_IN_MONEDA=="USD"
replace ingreso_indep = ingreso_indep*50.29 if yr==2019 & mes==2 & INGRESO_ACTIVIDAD_IN_MONEDA=="USD"
replace ingreso_indep = ingreso_indep*50.46 if yr==2019 & mes==5 & INGRESO_ACTIVIDAD_IN_MONEDA=="USD"
replace ingreso_indep = ingreso_indep*49.29 if yr==2018 & mes==5 & INGRESO_ACTIVIDAD_IN_MONEDA=="USD"

* 3.2.3 Pagos en especie
gen autoconsumo = CONSUMIO_BIENES_IN_MONTO    //Autoconsumo de su producción
gen especie_indep = PAGO_ESPECIES_IN_MONTO	  //Pagos en especie

* 3.3 Ingresos en la ocupación secundaria (asalariados)

* 3.3.1 Sueldo
gen sueldo_sec = SUELDO_BRUTO_AS_MONTO        //Sueldo actividad secundaria

* 3.3.2 Otros pagos mensuales
gen otros_pagos_sec = OTROS_PAGO_AS_MONTO     //Otros pagos actividad secundaria

* 3.3.3 Otros pagos anuales
gen otros_beneficios_sec = OTROS_BENEFICIOS_AS_MONTO/12  //Beneficios actividad secundaria

* 3.3.4 Pagos en especie
gen especie_sec = PAGO_EN_ESPECIE_AS_MONTO    //Pagos en especie actividad secundaria
* 3.4 Ingresos en la ocupación secundaria (independientes)

* 3.4.1 Para agropecuarios o consultores
gen ganancia_sec = GANANCIA_IS_PRODUCTOR_MONTO       //Ganancia del negocio secundario

* 3.4.2 Para cuenta propia
gen ingreso_indep_sec = INGRESO_ACTIVIDAD_IS_MONTO //Ingresos de producción secundaria
//// HERE WE ELIMINATE INCOMES ABOVE 900,000. THIS DOES NOT HAPPEN IN OUR DATA
//// BUT DATA SENT MAY HAVE VARIED WITH RESPECT TO OURS. WE DO NOT WANT TO 
//// INCLUDE SUCH VALUES, NOTING THAT THIS ADJUSTMENT HAS ALMOST NO EFFECT ON 
//// OUR RESULTS
replace ingreso_indep_sec = . if ingreso_indep_sec > 900000

* Convertir a mensual
replace ingreso_indep_sec = ingreso_indep_sec*INGRESO_ACTIVIDAD_IS_DIAS*4.33 if INGRESO_ACTIVIDAD_IS_PERIODO == 1 
replace ingreso_indep_sec = ingreso_indep_sec*4.33 if INGRESO_ACTIVIDAD_IS_PERIODO == 2
replace ingreso_indep_sec = ingreso_indep_sec*2.165 if INGRESO_ACTIVIDAD_IS_PERIODO == 3

* Convertir a DOP si reportan en USD
replace ingreso_indep_sec = ingreso_indep_sec*48.11 if yr==2018 & mes==3 & INGRESO_ACTIVIDAD_IS_MONEDA=="USD"

* 3.4.3 Pagos en especie
gen autoconsumo_sec = CONSUMIO_BIENES_IS_MONTO    //Autoconsumo de su producción (sec)
gen especie_indep_sec = PAGO_ESPECIES_IS_MONTO	  //Pagos en especie (secundaria)

egen ing_labp_0 = rowtotal(sueldo comisiones propinas horas_extra otros_pagos vacaciones bonificacion regalias incentivo dividendos beneficios utilidades otros_beneficios alimentacion vivienda transporte gasolina otros_especie ganancia ingreso_indep autoconsumo especie_indep),m
replace ing_labp_0 = . if ing_labp == 0 & pet == 0
egen ing_ocup_sec = rowtotal(sueldo_sec otros_pagos_sec otros_beneficios_sec especie_sec ganancia_sec ingreso_indep_sec autoconsumo_sec especie_indep_sec),m
gen ingreso_otras_ocup = INGRESOS_OTROS_TRABAJOS_MONTO //Ingresos de otras ocupaciones

egen ing_lab_0 = rowtotal(ing_labp_0 ing_ocup_sec ingreso_otras_ocup), m

* 4.0.6 Ingreso personal comparable con WID (incluye salario, ganancia, vivienda, alimentos, salario/ganancia segunda ocupacion)
egen ing_pers_wid = rowtotal(sueldo alimentacion vivienda ganancia ingreso_indep especie_indep sueldo_sec ganancia_sec ingreso_indep_sec), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\RepDom_2019.dta", replace

**************************************************
**						MEXICO 					**
**************************************************

use "$rawdata\MEX_ENIGH_2018.dta", clear
sort folioviv foliohog numren 
gen ordering = _n
** 1. General information

* 1.0. Household ID
egen hogar = group(folioviv foliohog)

* 1.1. Sampling weight
gen fac_exp = factor
gen fac_exp_yr = fac_exp

* 1.2. Age
sum edad

* 1.3. Gender
gen hombre = sexo 
destring hombre, force replace
recode hombre (2 = 0)
label define sx 0 "Mujer" 1 "Hombre"
label val hombre sx	

* 1.4. Urban area - dummy
gen urbano=substr(folioviv,3,1)
destring urbano, force replace
replace urbano = 1 if urbano != 6
replace urbano = 0 if urbano == 6

label define ur 0 "Rural" 1 "Urbano"
label val urbano ur
	
* 1.5.1. Asiste 
gen asiste = asis_esc 
destring asiste, force replace
recode asiste (2 = 0)
label val asiste sino	

* 1.5.2. Education level

destring nivelaprob, force replace
destring gradoaprob, gen(educ_grado)
gen educ_nivel = . 
replace educ_nivel = 1 if inlist(nivelaprob,0,1,2,3) //Ninguo, preescolar, primaria y secundaria
replace educ_nivel = 1 if nivelaprob==4 & inlist(educ_grado,1,2) // Bachillerato incompleto
replace educ_nivel = 2 if nivelaprob==4 & educ_grado == 3 //Bachillerato completo

*** Terciaria ------
replace educ_nivel = 2 if nivelaprob==5 & inlist(educ_grado,1,2,3) // Terciaria incompleta
replace educ_nivel = 3 if nivelaprob==5 & inlist(educ_grado,4,5) // Terciaria completa
replace educ_nivel = 2 if nivelaprob==6 & inlist(educ_grado,1) // Terciaria incompleta
replace educ_nivel = 3 if nivelaprob==6 & inlist(educ_grado,2,3,4) // Terciaria completa
replace educ_nivel = 2 if nivelaprob==7 & inlist(educ_grado,1,2,3) // Terciaria incompleta
replace educ_nivel = 3 if nivelaprob==7 & inlist(educ_grado,4,5) // Terciaria completa
replace educ_nivel = 3 if inlist(nivelaprob,8,9) // Terciaria completa

cap label define educ 1 "Primaria o menos" 2 "Secundaria" 3 "Terciaria" 4 "Otro"
label val educ_nivel educ

* 1.5.3. Years of schooling 
gen yr_edu = 0 if inlist(nivelaprob,0,1)
forvalues j = 1/6{
    replace yr_edu = `j' if nivelaprob == 2 & educ_grado == `j'
}
forvalues j = 1/3{
    replace yr_edu = 6+`j' if nivelaprob == 3 & educ_grado == `j'
}
forvalues j = 1/3{
    replace yr_edu = 9+`j' if nivelaprob == 4 & educ_grado == `j'
}
forvalues j = 1/5{
    replace yr_edu = 12+`j' if nivelaprob == 5 & educ_grado == `j'
}
forvalues j = 1/4{
    replace yr_edu = 12+`j' if nivelaprob == 6 & educ_grado == `j'
}
forvalues j = 1/5{
    replace yr_edu = 12+`j' if nivelaprob == 7 & educ_grado == `j'
}
forvalues j = 1/6{
    replace yr_edu = 17+`j' if nivelaprob == 8 & educ_grado == `j'
}
forvalues j = 1/5{
    replace yr_edu = 17+`j' if nivelaprob == 9 & educ_grado == `j'
}


** 2. Labour market

* 2.1. Employed - Dummy
gen pet = cond(edad>=12,1,0)

gen ocupado = 0
replace ocupado = 1 if trabajo_mp == "1"
replace ocupado = 1 if trabajo_mp != "13" & motivo_aus != " "
replace ocupado = 1 if num_trabaj != " "
replace ocupado = . if pet == 0

* 2.2. Type of employment (Not standard within countries)
gen ocupacion = 0
replace ocupacion = 1 if suborprinc == "1" & pagoprinc == "1"
replace ocupacion = 3 if indepprinc == "1"
replace ocupacion = 2 if personalprinc == "1"
replace ocupacion = 4 if inlist(pagoprinc,"2","3")
replace ocupacion = 1 if pagoprinc == "1" & ocupacion == 0

replace ocupacion = . if ocupado != 1

label define ocupacion 1 "Trabajadores subordinados y remunerados" 2 "Empleadores" 3 "Trabajadores por cuenta propia" 4 "Trabajadores sin pago"
label val ocupacion ocupacion

gen hr_trabajadas = htrabprinc

* 2.2.1. Domestic worker - dummy
gen empleada_domestica = .

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente = cond(ocupacion ==2|ocupacion==3,1,0)
replace independiente = . if ocupacion ==.

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 3
replace cuenta_propia = 0 if inlist(ocupacion,1,2,4)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,1,2,3)
replace trabajador_rem = . if ocupado != 1

* 2.3. Public employment or education sector - Dummy
gen empleo_publico = 0

	* Autorreportada
replace empleo_publico = 1 if clas_empprinc == "3" // Reporta trabajar para una empresa estatal
	
	* Por sector de actividad
replace empleo_publico = 1 if inlist(scianprinc,"5401","5411","5412","5413") // fuerza armada
replace empleo_publico = 1 if inlist(scianprinc,"9313","9314","9319") // administración pública
replace empleo_publico = . if ocupado != 1

* 7.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | inlist(scianprinc,"6132","6139","6141","6142","6150","6199") // enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
gen size_50_100 = .
replace size_50_100 = 1 if inlist(tam_empprinc,"01","02") //1-5
			replace size_50_100 = 2 if inlist(tam_empprinc,"03") //6-10
			replace size_50_100 = 3 if inlist(tam_empprinc,"04","05","06","07") //11-50
			replace size_50_100 = 4 if inlist(tam_empprinc,"08") //51-100
			replace size_50_100 = 5 if inlist(tam_empprinc,"09","10","11") //101 o mas
			replace size_50_100 = . if ocupado != 1
			label define size_50_100 1 "1-5" 2 "6-10" 3 "11-50" 4 "51-100" 5 "101 o más"
label value size_50_100 size_50_100

* 2.5. Economic sector
gen sector_activ = scianprinc

gen sector_2d=substr(sector_activ,1,2)
destring sector_2d, replace
gen sector_rev4 = 1 if sector_2d == 11
replace sector_rev4 = 2 if sector_2d == 21
replace sector_rev4 = 3 if inlist(sector_2d,31,32,33) | inlist(sector_activ,"8112","8119","8123")
replace sector_rev4 = 4 if inlist(sector_2d,22,56)
replace sector_rev4 = 5 if sector_2d == 23
replace sector_rev4 = 6 if inlist(sector_2d,43,46,72) | inlist(sector_activ,"8111")
replace sector_rev4 = 7 if inlist(sector_2d,48,49) | inlist(sector_activ,"8122")
replace sector_rev4 = 8 if inrange(sector_2d,51,56) | inlist(sector_activ,"8124")
replace sector_rev4 = 9 if sector_2d == 93
replace sector_rev4 = 10 if inrange(sector_2d,61,62)
replace sector_rev4 = 11 if sector_2d == 71 | inlist(sector_activ,"8121","8125","8130")
replace sector_rev4 = 12 if inlist(sector_activ,"8140","1003")
replace sector_rev4 = 13 if inlist(sector_activ,"9320","0980")
replace sector_rev4 = 14 if sector_2d == 99

label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

gen sector_desagregado_p = scianprinc
destring sector_desagregado_p, replace

* 2.6. Informal worker - Dummy	
gen informal = .
note: pres_8 has low response rate among self-employed so it is not used

** 3. Income

* 3.1. Personal earnings 

* 3.1.1. Create all components of Personal earnings 
* 3.1.1 Ingreso asalariados ocupación principal
gen ing_mensualP008_m = ing_mensualP008/12
gen ing_mensualP009_m = ing_mensualP009/12
egen ing_ocuprin = rowtotal(ing_mensualP001 ing_mensualP002 ing_mensualP003 ing_mensualP004 ing_mensualP005 ing_mensualP006 ing_mensualP007 ing_mensualP008_m ing_mensualP009_m), m

egen ing_indep1 = rowtotal (ing_mensualP011 ing_mensualP012 ing_mensualP013), m
egen ing_nego1 = rowtotal(ing_mensualP068 ing_mensualP069 ing_mensualP070 ing_mensualP071), m
egen ing_agri1 = rowtotal(ing_mensualP072 ing_mensualP073 ing_mensualP074), m

egen ing_labp_0 = rowtotal(ing_ocuprin ing_indep1 ing_nego1 ing_agri1),m

gen ing_mensualP015_m = ing_mensualP015/12
gen ing_mensualP016_m = ing_mensualP016/12
egen ing_ocusec = rowtotal(ing_mensualP014 ing_mensualP015_m ing_mensualP016_m), m

egen ing_indep2 = rowtotal(ing_mensualP018 ing_mensualP019),m
egen ing_nego2 = rowtotal(ing_mensualP075 ing_mensualP076 ing_mensualP077 ing_mensualP078), m
egen ing_agri2= rowtotal(ing_mensualP079 ing_mensualP080 ing_mensualP081), m

egen ing_ocup_sec = rowtotal(ing_ocusec ing_indep2 ing_nego2 ing_agri2),m
egen ing_lab_0 = rowtotal(ing_labp_0 ing_ocup_sec), m

* 4.0.6 Ingreso personal comparable con WID (incluye salario, ganancia, vivienda, alimentos, salario/ganancia segunda ocupacion)
egen ing_pers_wid = rowtotal(ing_mensualP001 ing_mensualP011 ing_mensualP012 ing_mensualP068 ing_mensualP069 ing_mensualP070 ing_mensualP071 ing_mensualP072 ing_mensualP073 ing_mensualP074 ing_mensualP014 ing_mensualP018 ing_mensualP019 ing_mensualP075 ing_mensualP076 ing_mensualP077 ing_mensualP078 ing_mensualP079 ing_mensualP080 ing_mensualP081), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\Mexico_2018.dta", replace

**************************************************
**					PARAGUAY 					**
**************************************************

use "$rawdata\PRY_EPHC_2019.dta", clear
sort UPM NVIVI NHOGA L02
gen ordering = _n
** 1. General information

* 1.0. Household ID
egen hogar = group(UPM NVIV NHOGA)

* 1.1. Sampling weight
gen fac_exp = FEX 
gen fac_exp_yr = fac_exp

* 1.2. Age
gen edad = P02
* Nota: Edad está truncada en 99

* 1.3. Gender
gen hombre = P06 
recode hombre (6 = 0)
label define sx 0 "Mujer" 1 "Hombre"
label val hombre sx	

* 1.4. Urban area - dummy
gen urbano = AREA
recode urbano (6 = 0)
label define ur 0 "Rural" 1 "Urbano"
label val urbano ur

* 1.5.1. Asiste 
gen asiste = 1 if inrange(ED08,1,18)
replace asiste = 0 if ED08 == 19
label val asiste sino

* 1.5.2. Education level
gen educ_nivel = .

* Primaria y otros
replace educ_nivel = 1 if inlist(ED0504,0,101,103,106,109,1801,1900) // Sin instrucción y educación especial, programa de alfabetización, educación especial
replace educ_nivel = 1 if inlist(ED0504,210,211,212) // Educación inicial
replace educ_nivel = 1 if inlist(ED0504,301,302,303,304,305,306,407,408,409) // Escolar básica 
replace educ_nivel = 1 if inlist(ED0504,501,502,503) // Secundaria básica

* Bachillerato y media
replace educ_nivel = 1 if inlist(ED0504,604,605) // Bachillerato incompleto
replace educ_nivel = 2 if inlist(ED0504,606,607) // Bachillerato completo
replace educ_nivel = 1 if inlist(ED0504,704,705) // Bachillerato incompleto
replace educ_nivel = 2 if inlist(ED0504,706) // Bachillerato completo
replace educ_nivel = 1 if inlist(ED0504,901,902) // Bachillerato incompleto
replace educ_nivel = 2 if inlist(ED0504,903) // Bachillerato completo
replace educ_nivel = 1 if inlist(ED0504,1001,1002) // Bachillerato incompleto
replace educ_nivel = 2 if inlist(ED0504,1003) // Bachillerato completo
replace educ_nivel = 1 if inlist(ED0504,1001,1002) // Bachillerato incompleto
replace educ_nivel = 2 if inlist(ED0504,1103) // Bachillerato completo
replace educ_nivel = 1 if inlist(ED0504,1201,1202,1203,1204) // Secundaria básica bilingue
replace educ_nivel = 1 if inlist(ED0504,1301,1302) // Educación media incompleta
replace educ_nivel = 2 if inlist(ED0504,1303,1304) // Educación media completa
replace educ_nivel = 1 if inlist(ED0504,1402,1403) // Educación básica alternativa
replace educ_nivel = 1 if inlist(ED0504,1501,1502) // Educación media alternativa incompleta
replace educ_nivel = 2 if inlist(ED0504,1503,1504) // Educación media alternativa completa
replace educ_nivel = 1 if inlist(ED0504,1601,1602) // Educación media para jovenes y adultos incompleta
replace educ_nivel = 2 if inlist(ED0504,1603,1604) // Educación media para jovenes y adultos completa
replace educ_nivel = 2 if ED0504 == 1703 // Formación Profesional no Bachillerato de la media 3º

* Terciaria incompleta
replace educ_nivel = 2 if inlist(ED0504,2001,2002,2003) & ED06C == 14 // Tecnica superior
replace educ_nivel = 2 if inlist(ED0504,2101,2102,2103,2104) & ED06C == 14 // Formación docente 
replace educ_nivel = 2 if inlist(ED0504,2202,2204,2206) & ED06C == 14 // Profesionalización docente 
replace educ_nivel = 2 if inlist(ED0504,2301,2302,2303,2304) & ED06C == 14 // Militar / policial 
replace educ_nivel = 2 if inlist(ED0504,2401,2402,2403,2404,2405,2406) & ED06C == 14 // Superior universitaria 

* Terciaria completa
replace educ_nivel = 3 if inlist(ED0504,2001,2002,2003) & ED06C != 14 & ED06C != 99 & ED06C != . // Tecnica superior
replace educ_nivel = 3 if inlist(ED0504,2101,2102,2103,2104) & ED06C != 14 & ED06C != 99 & ED06C != . // Formación docente 
replace educ_nivel = 3 if inlist(ED0504,2202,2204,2206) & ED06C != 14 & ED06C != 99 & ED06C != . // Profesionalización docente 
replace educ_nivel = 3 if inlist(ED0504,2301,2302,2303,2304) & ED06C != 14 & ED06C != 99 & ED06C != . // Militar / policial 
replace educ_nivel = 3 if inlist(ED0504,2401,2402,2403,2404,2405,2406) & ED06C != 14 & ED06C != 99 & ED06C != . // Superior universitaria 

cap label define educ 1 "Primaria o menos" 2 "Secundaria" 3 "Terciaria" 4 "Otro"
label val educ_nivel educ

* 1.5.3. Years of schooling 
gen yr_edu = 0 if inlist(ED0504,0,101,103,106,109,1801,1900,210,211,212)
replace yr_edu = 1 if ED0504 == 301
replace yr_edu = 2 if ED0504 == 302
replace yr_edu = 3 if ED0504 == 303
replace yr_edu = 4 if ED0504 == 304
replace yr_edu = 5 if ED0504 == 305
replace yr_edu = 6 if ED0504 == 306
replace yr_edu = 7 if ED0504 == 407
replace yr_edu = 8 if ED0504 == 408
replace yr_edu = 9 if ED0504 == 409
replace yr_edu = 10 if ED0504 == 501
replace yr_edu = 11 if ED0504 == 502
replace yr_edu = 12 if ED0504 == 503
replace yr_edu = 13 if ED0504 == 604
replace yr_edu = 14 if ED0504 == 605
replace yr_edu = 15 if ED0504 == 606
replace yr_edu = 16 if ED0504 == 607
replace yr_edu = 13 if ED0504 == 704
replace yr_edu = 14 if ED0504 == 705
replace yr_edu = 15 if ED0504 == 706
replace yr_edu = 13 if ED0504 == 901
replace yr_edu = 14 if ED0504 == 902
replace yr_edu = 15 if ED0504 == 903
replace yr_edu = 13 if ED0504 == 1001
replace yr_edu = 14 if ED0504 == 1002
replace yr_edu = 15 if ED0504 == 1003
replace yr_edu = 13 if ED0504 == 1101
replace yr_edu = 14 if ED0504 == 1102
replace yr_edu = 15 if ED0504 == 1103
replace yr_edu = 13 if ED0504 == 1201
replace yr_edu = 14 if ED0504 == 1202
replace yr_edu = 15 if ED0504 == 1203
replace yr_edu = 16 if ED0504 == 1204
replace yr_edu = 13 if ED0504 == 1301
replace yr_edu = 14 if ED0504 == 1302
replace yr_edu = 15 if ED0504 == 1303
replace yr_edu = 16 if ED0504 == 1304
replace yr_edu = 13 if ED0504 == 1401
replace yr_edu = 14 if ED0504 == 1402
replace yr_edu = 15 if ED0504 == 1503
replace yr_edu = 13 if ED0504 == 1501
replace yr_edu = 14 if ED0504 == 1502
replace yr_edu = 15 if ED0504 == 1503
replace yr_edu = 16 if ED0504 == 1504
replace yr_edu = 13 if ED0504 == 1601
replace yr_edu = 14 if ED0504 == 1602
replace yr_edu = 15 if ED0504 == 1603
replace yr_edu = 16 if ED0504 == 1604
replace yr_edu = 13 if ED0504 == 1701
replace yr_edu = 14 if ED0504 == 1702
replace yr_edu = 15 if ED0504 == 1703
replace yr_edu = 16 if ED0504 == 1704
replace yr_edu = 17 if ED0504 == 2001
replace yr_edu = 18 if ED0504 == 2002
replace yr_edu = 19 if ED0504 == 2003
replace yr_edu = 17 if ED0504 == 2101
replace yr_edu = 18 if ED0504 == 2102
replace yr_edu = 19 if ED0504 == 2103
replace yr_edu = 20 if ED0504 == 2104
replace yr_edu = 17 if ED0504 == 2201
replace yr_edu = 18 if ED0504 == 2202
replace yr_edu = 19 if ED0504 == 2203
replace yr_edu = 20 if ED0504 == 2204
replace yr_edu = 21 if ED0504 == 2205
replace yr_edu = 22 if ED0504 == 2206
replace yr_edu = 17 if ED0504 == 2301
replace yr_edu = 18 if ED0504 == 2302
replace yr_edu = 19 if ED0504 == 2303
replace yr_edu = 20 if ED0504 == 2304
replace yr_edu = 17 if ED0504 == 2401
replace yr_edu = 18 if ED0504 == 2402
replace yr_edu = 19 if ED0504 == 2403
replace yr_edu = 20 if ED0504 == 2404
replace yr_edu = 21 if ED0504 == 2405
replace yr_edu = 22 if ED0504 == 2406


** 2. Labour market

* 2.1. Employed - Dummy
gen pet = cond(edad>=15,1,0)

gen ocupado = cond(PEAA==1,1,0)
replace ocupado = . if pet == 0
replace ocupado = . if PEAA == 9

* 2.2. Type of employment (Not standard within countries)
gen ocupacion = CATE_PEA
replace ocupacion = . if CATE_PEA == 9
replace ocupacion = . if ocupado != 1
label define ocup 1 "Empleado / obrero público" 2 "Empleado / obrero privado" 3 "Empleador o patrón" 4 "Trabajador por cuenta propia" 5 "Trabajador familiar no remunerado" 6 "Empleado doméstico"
label val ocupacion ocup

gen hr_trabajadas = HORAB
replace hr_trabajadas = . if ocupado != 1
replace hr_trabajadas = . if hr_trabajadas == 999

* 2.2.1. Domestic worker - dummy
gen empleada_domestica = 0
replace empleada_domestica = 1 if ocupacion == 6
replace empleada_domestica = . if ocupado != 1

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente = cond(inlist(ocupacion,3,4),1,0)
replace independiente = . if ocupado != 1

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 4
replace cuenta_propia = 0 if inlist(ocupacion,1,2,3,5,6)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,1,2,3,4,6)
replace trabajador_rem = . if ocupado != 1


* 2.3. Public employment or education sector - Dummy
gen empleo_publico = 0

	* Autorreportada
replace empleo_publico = 1 if ocupacion == 1 // Reporta trabajar para una empresa estatal
	
	* Por sector de actividad
replace empleo_publico = 1 if inlist(B01REC,1,10) // admin publica y defensa
replace empleo_publico = . if ocupado != 1

* 7.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | B01REC == 2 // enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
gen n_per_empresa = B08
replace n_per_empresa = . if inlist(B08,10,11,99) 

gen size_50_100 = .
replace size_50_100 = 1 if inlist(n_per_empresa,1,2) //1-5
			replace size_50_100 = 2 if inlist(n_per_empresa,3) //6-10
			replace size_50_100 = 3 if inlist(n_per_empresa,4,5,6) //1-50
			replace size_50_100 = 4 if n_per_empresa == 7 //51-100
			replace size_50_100 = 5 if inlist(n_per_empresa,8,9) //101 o mas
			replace size_50_100 = . if ocupado != 1
			label define size_50_100 1 "1-5" 2 "6-10" 3 "11-50" 4 "51-100" 5 "101 o más"
label value size_50_100 size_50_100

* 2.5. Economic sector
gen sector_activ = RAMA_PEA
replace sector_activ = . if sector_activ == 99 

gen sector_rev4 = sector_activ
recode sector_rev4 (2=3) (3=4) (4=5) (5=6) (6=7) (7=8) (8=10)
label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

gen sector_desagregado_p = sector_activ

* 2.6. Informal worker - Dummy	
gen informal = cond(B10==6,1,0)
replace informal = 0 if C07 == 1
replace informal = . if B10 == 9 
replace informal = . if ocupado != 1

** 3. Income

* 3.1. Personal earnings 

foreach var of varlist E01A E01B E01C{
	dis in red "`var'"
	replace `var'=. if `var'==99999999999
}

* 3.1.1. Create all components of Personal earnings
gen ing_labp_0 = E01A
replace ing_labp_0 = . if E01A == 0 & ocupado != 1

gen ing_ocup_sec = E01B 
replace ing_ocup_sec = . if E01B == 0 & ocupado != 1

gen ingreso_otras_ocup = E01C 
replace ingreso_otras_ocup = . if E01C == 0 & ocupado != 1
 
egen ing_lab_0 = rowtotal(ing_labp_0 ing_ocup_sec ingreso_otras_ocup), m

* 4.0.6 Ingreso personal comparable con WID (incluye salario, ganancia, vivienda, alimentos, salario/ganancia segunda ocupacion)
egen ing_pers_wid = rowtotal(ing_labp_0 ing_ocup_sec), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\Paraguay_2019.dta", replace

**************************************************
**					  PERU  					**
**************************************************

use "$rawdata\PER_ENAHO_2019.dta", clear
sort conglome vivienda hogar codperso
gen ordering = _n
** 1. General information

* Peru only uses usual household residents in official labor market statistics 
keep if ((p204==1 & p205==2) | (p204==2 & p206==1))
drop if ocu500==0 

* 1.0. Household ID
rename hogar nhogar
egen hogar = group(conglome vivienda nhogar)
egen person =group(conglome vivienda nhogar codperso)

label var mes "mes"
destring mes, replace force

* 1.1. Sampling weight
gen fac_exp_yr = fac500a
notes fac_exp_yr: This weight is used for labor market and income results

* 1.2. Age
gen edad=p208a
sum edad
label var edad "Edad en años"
format edad %9.0g

* 1.3. Gender
gen hombre=.
replace hombre=1 if p207==1
replace hombre=0 if p207==2
label var hombre "Sexo"
label define hombre 1 "Hombre" 0 "Mujer"
label value hombre hombre

* 1.4. Urban area not asked in Peru
* Urbano-rural 
gen	urbano = 1 if estrato<=5
replace urbano = 0 if estrato>=6 & estrato<=8

* 1.5.1. Asiste 
gen asiste=cond(p306==2,0,1) // Preguntan si está matriculado
replace asiste=. if p306==.
label var asiste "¿Usted asiste actualmente a un establecimiento educativo?"
label define asiste 1"Sí" 0"No"
label values asiste asiste

* 1.5.2. Education level
gen educ_nivel=.
replace educ_nivel=1 if inlist(p301a,1,2,3,4,5,12) 
replace educ_nivel=2 if inlist(p301a,6,7,9) 
replace educ_nivel=3 if inlist(p301a,8,10,11) 

label var educ_nivel "Máximo nivel educativo alcanzado"
label define educ 1 "Primaria o menos" 2 "Secundaria" 3 "Terciaria"
label val educ_nivel educ

* 1.5.3. Years of schooling 
gen yr_edu = 0 if inlist(p301a,1,2) // sin nivel y educacion inicial
forvalues j = 0/4{
    replace yr_edu = `j' if p301a == 3 & p301b == `j'
}
forvalues j = 0/6{
    replace yr_edu = `j' if p301a == 4 & p301b == `j'
}
forvalues j = 1/4{
    replace yr_edu = 6+`j' if p301a == 5 & p301b == `j'
}
forvalues j = 5/6{
    replace yr_edu = 6+`j' if p301a == 6 & p301b == `j'
}
forvalues j = 0/4{
    replace yr_edu = 6+`j' if p301a == 12 & p301b == `j'
}
forvalues j = 1/4{
    replace yr_edu = 9+`j' if p301a == 7 & p301b == `j'
}
forvalues j = 3/5{
    replace yr_edu = 9+`j' if p301a == 8 & p301b == `j'
}
forvalues j = 1/6{
    replace yr_edu = 9+`j' if p301a == 9 & p301b == `j'
}
forvalues j = 4/7{
    replace yr_edu = 9+`j' if p301a == 10 & p301b == `j'
}
forvalues j = 1/2{
    replace yr_edu = 15+`j' if p301a == 11 & p301b == `j'
}


** 2. Labour market

* 2.1. Employed - Dummy
gen pet = cond(edad>=14,1,0)

gen ocupado=.
replace ocupado=1 if ocu500==1
replace ocupado=0 if inlist(ocu500,2,3,4)
replace ocupado = . if pet == 0 

* 2.2. Type of employment (Not standard within countries)
gen ocupacion = p507
label define ocup 1 "empleador o patrono" 2 "trabajador independiente" 3 "empleado" 4  "obrero" 5 "Trabajador familiar no remunerado" 6 "trabajador del hogar" 7 "Otro"
label val ocupacion ocup

gen hr_trabajadas=p513t
replace hr_trabajadas = . if ocupado != 1

* 2.2.1. Domestic worker - dummy
gen empleada_domestica = 0
replace empleada_domestica = 1 if ocupacion == 6
replace empleada_domestica = . if ocupado != 1

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente=0
replace independiente=1 if inlist(p507,1,2)
replace independiente=. if p507==. 
replace independiente=. if ocupado != 1

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 2
replace cuenta_propia = 0 if inlist(ocupacion,1,3,4,5)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,1,2,3,4,6)
replace trabajador_rem = . if ocupado != 1

* 2.3. Public employment or education sector - Dummy
gen empleo_publico = 0

	* Autorreportada
replace empleo_publico = 1 if inlist(p510,1,2,3) // Reporta trabajar para una empresa estatal
	
	* Por sector de actividad
gen sector2d = string(p506)
replace sector2d=substr(sector2d,1,2)	
replace empleo_publico = 1 if sector2d == "75" // CIIU REV3 admin publica y defensa
replace empleo_publico = . if ocupado != 1

* 7.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | sector2d == "80" // CIIU REV3 enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
gen size_50_100 = .
replace size_50_100 = 1 if p512b>=1 & p512b<=4 //1-4
			replace size_50_100 = 2 if p512b>=5 & p512b<=10 //5-10
			replace size_50_100 = 3 if (p512b>=11 & p512b<=50) | inlist(p512a,2) //11-50
			replace size_50_100 = 4 if (p512b>=51 & p512b<=100) | inlist(p512a,3) //51-100
			replace size_50_100 = 5 if (p512b>=101& p512b!=.) | inlist(p512a,4,5)
			replace size_50_100 = . if ocupado != 1
			label define size_50_100 1 "1-4" 2 "5-10" 3 "11-50" 4 "51-100" 5 "101 o más"
label value size_50_100 size_50_100

* 2.5. Economic sector
preserve
use "$publicdata\correlativa_sectores.dta", clear
keep if pais == "Peru_2019"
keep rama cod_sector_unificado_rev4
destring rama, replace
rename (rama cod_sector_unificado_rev4) (p506r4 sector_rev4)
tempfile temp
save `temp', replace
restore

merge m:1 p506r4 using `temp', nogen
drop if hogar == .
label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

gen sector_desagregado_p = p506r4

* 2.6. Informal worker - Dummy	
* ¿Cuál fue el último mes que aporto al sistema de pensiones? p558b1
gen informal = 1
replace informal = 0 if p558b1 == mes & p558b2 == 2019
replace informal = 0 if p558b1 == mes-1 & p558b2 == 2019
replace informal = . if ocupado != 1

** 3. Income

* 3.1. Personal earnings 

* 3.1.1. Create all components of Personal earnings
* Variable de días trabajados a la semana
foreach d in a b c d e f g{
	gen d_`d' = 1 if inrange(p513`d',1,24)
	replace d_`d' = 0 if p513`d' == 0
}
egen dias_lab = rowtotal(d_*), m
drop d_*
replace dias_lab = 5 if dias_lab == 0

foreach var of varlist p524a1 p5291b p5292b p5293b p5294b p5295b p5296b p530a p536 p538a1 p538d1 p5401b p5402b p5403b p5404b p5405b p5406b p541a p543 p5441b p5442b p5443b p5444b p5446b p5447b p5448b p5587b p5571c p5572c p5573c p5574c p5575c p5576c p5577c p5578c{
    dis in red "`var'"
	replace `var' = . if `var' == 999999
}

*Ocupación principal
*ingreso mensual monetario para dependientes, solo aplica para empleado, obrero, trabajador del hogar y otro en la P507
gen ing_mon_empleados=.
replace ing_mon_empleados=p524a1*dias_lab*4.34524 if p523==1
replace ing_mon_empleados=p524a1*4.34524 if p523==2
replace ing_mon_empleados=p524a1*2.17262 if p523==3
replace ing_mon_empleados=p524a1 if p523==4

*Ingreso mensual en especie dependientes
local especie "p5291 p5292 p5293 p5294 p5295 p5296"
foreach a of local especie {
	gen ing_especie_`a'=.
	replace ing_especie_`a'=`a'b*dias_lab*4.34524 if `a'a==1 
	replace ing_especie_`a'=`a'b*4.34524 if `a'a==2 
	replace ing_especie_`a'=`a'b*2.17262 if `a'a==3
	replace ing_especie_`a'=`a'b if `a'a==4 
	replace ing_especie_`a'=`a'b/2 if `a'a==5 
	replace ing_especie_`a'=`a'b/3 if `a'a==6
	replace ing_especie_`a'=`a'b/6 if `a'a==7
	replace ing_especie_`a'=`a'b/12 if `a'a==8  
}
egen ing_especie=rsum(ing_especie_*), m

*Ingreso independientes
gen ing_ind=p530a

*Autoconsumo de bienes producidos por el hogar 
gen autoconsumo=p536

*Ocupación secundaria ingreso en especie
local especie "p5401 p5402 p5403 p5404 p5405 p5406"
foreach a of local especie {
	gen ing_especie_sec_`a'=.
	replace ing_especie_sec_`a'=`a'b*dias_lab*4.34524 if `a'a==1 
	replace ing_especie_sec_`a'=`a'b*4.34524 if `a'a==2 
	replace ing_especie_sec_`a'=`a'b*2.17262 if `a'a==3
	replace ing_especie_sec_`a'=`a'b if `a'a==4 
	replace ing_especie_sec_`a'=`a'b/2 if `a'a==5 
	replace ing_especie_sec_`a'=`a'b/3 if `a'a==6
	replace ing_especie_sec_`a'=`a'b/6 if `a'a==7
	replace ing_especie_sec_`a'=`a'b/12 if `a'a==8  
}
egen ing_secu_esp=rsum(ing_especie_sec_*),m

*Ocupación secundaria 
gen ing_secu_mon=p538a1

* Ganancia en la ocupación secundaria 
gen ing_secu_ind = p541a

* Autconsumo en la ocupación secundaria
gen autoconsumo_secu = p543

*Ingreso extraordinario por:
*Gratificación de navidad
gen ing_nav=p5441b/12
*Gratificación de fiestas patrias
gen ing_fie=p5442b/12
*bonificación por sus últimas vacaciones
gen ing_vac=p5443b/12
*bonificación por escolaridad
gen ing_esc=p5444b/12
*Bonificación por otro concepto
gen ing_bon=p5446b/12
*Compensación por tiempo de servicios (CTS)
gen ing_cts=p5447b/12
*Otro ingreso por trabajo
gen ing_otr=p5448b/12
*participación de utilidades de la empresa donde labora 
gen ing_utl=p5445b/12

egen ing_lab_0 = rowtotal(ing_mon_empleados ing_especie ing_ind autoconsumo ing_secu_esp ing_secu_mon ing_nav ing_fie ing_vac ing_esc ing_bon ing_cts ing_otr ing_secu_ind autoconsumo_secu ing_utl), m
egen ing_labp_0 =rowtotal(ing_mon_empleados ing_especie ing_ind autoconsumo ing_utl), missing

* 4.0.6 Ingreso personal comparable con WID (incluye salario, ganancia, vivienda, alimentos, salario/ganancia segunda ocupacion)
egen ing_pers_wid = rowtotal(ing_mon_empleados ing_especie_p5291 ing_especie_p5294 ing_ind ing_secu_mon ing_secu_ind), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\Peru_2019.dta", replace

**************************************************
**					URUGUAY 					**
**************************************************

use "$rawdata\URY_ECH_2019.dta", clear
sort NUMERO NPER
gen ordering = _n
** 1. General information

* 1.0. Household ID
egen hogar = group(NUMERO)

* 1.1. Sampling weight
gen fac_exp=PESOANO
label var fac_exp "Factor de expansión"	 
gen fac_exp_yr=fac_exp

* 1.2. Age
gen edad=E27
sum edad
label var edad "Edad en años"
format edad %9.0g

* 1.3. Gender
gen hombre=E26
recode hombre (2 = 0)
label var hombre "Sexo (1: Hombre)"
label define hombre 1 "Hombre" 0 "Mujer"
label value hombre hombre

* 1.4. Urban area - dummy
destring REGION_4, replace
gen urbano=.
replace urbano=1 if REGION_4<4
replace urbano=0 if REGION_4==4
label var urbano "Urbano/Rural"
label define urbano 0"Rural" 1"Urbano"
label value urbano urbano

* 1.5.1. Asiste 
gen asiste = 0
replace asiste = 1 if E238 == 1 //Educacion inicial
replace asiste = 1 if E193 == 1 //Educacion preescolar
replace asiste = 1 if E197 == 1 //Educacion primaria
replace asiste = 1 if E201 == 1 //Educacion media
replace asiste = 1 if E212 == 1 //Educacion tecnica
replace asiste = 1 if E215 == 1 //Magisterio o profesorado
replace asiste = 1 if E218 == 1 //Universidad
replace asiste = 1 if E221 == 1 //Terciaria no universitaria
replace asiste = 1 if E224 == 1 //Posgrado
label var asiste "¿Usted asiste actualmente a un establecimiento educativo?"
label value asiste sino

* 1.5.2. Education level
gen nivele=.
replace nivele=6 if E224_1==1 | E224_1==2 
replace nivele=5 if (E218_1==1 | E215_1==1 | E221_1==1) & nivele==.
replace nivele=4 if E201_1==1 & (E218_1!=1 | E215_1!=1 | E221_1!=1) & nivele==.
replace nivele=3 if (E201_1==2 & E51_4==3) & nivele==. //Básica completa
replace nivele=2 if ((E197_1==1 & E51_2==6) | (E197_1==1 & E51_3==6) | (E201_1==2 & inlist(E51_4,1,2)) | (E212_1==2 & inlist(E51_4,1,2))) & nivele==.

replace nivele=1 if E197_1==2 | (E197_1==1 & inlist(E51_2,1,2,3,4,5)) | (E197_1==1 & inlist(E51_3,1,2,3))

*drop educ_nivel
gen educ_nivel=.
replace educ_nivel=1 if inlist(nivele,1,2,3)
replace educ_nivel=2 if nivele==4
replace educ_nivel=3 if inlist(nivele,5,6)
label define educ_nivel 1"Primaria o menos" 2"Secundaria" 3"Terciaria" 
label value educ_nivel educ_nivel

* 1.5.3. Years of schooling 
gen yr_edu = .

replace yr_edu = 0 if E49 == 0 // Nunca asistio a un establecimiento
replace yr_edu = 0 if inlist(E238,1,2) // Educacion inicial (de 0 a 2 anhos)
replace yr_edu = 0 if inlist(E193,1,2,3) // Educacion preescolar

replace yr_edu = yr_edu + E51_2 if E51_2 != 9 & E51_2 != . // Primaria comun
replace yr_edu = yr_edu + E51_3 if E51_3 != 9 & E51_3 != . // Primaria especial

replace yr_edu = yr_edu + E51_4 if E51_4 != 9 & E51_4 != . // Ciclo basico educacion media

replace yr_edu = yr_edu + E51_5 if E51_5 != 9 & E51_5 != . // Bachillerato
replace yr_edu = yr_edu + E51_6 if E51_6 != 9 & E51_6 != . // Bachillerato tecnologico

replace yr_edu = yr_edu + E51_7 if E51_7 != 9 & E51_7 != . // Educacion tecnica
replace yr_edu = yr_edu + E51_8 if E51_8 != 9 & E51_8 != . // Magisterio o profesorado
replace yr_edu = yr_edu + E51_9 if E51_9 != 9 & E51_9 != . // Universidad
replace yr_edu = yr_edu + E51_10 if E51_10 != 9 & E51_10 != . // Terciaria no universitaria
replace yr_edu = yr_edu + E51_11 if E51_11 != 9 & E51_11 != . // Posgrado 

label var yr_edu "Años de educacion"	

** 2. Labour market

* 2.1. Employed - Dummy
gen cond_actividad=.
replace cond_actividad=1 if POBPCOAC==1
replace cond_actividad=2 if POBPCOAC==2
replace cond_actividad=3 if POBPCOAC==3 | POBPCOAC==4 | POBPCOAC==5
replace cond_actividad=4 if POBPCOAC==6 | POBPCOAC==7 | POBPCOAC==8 |POBPCOAC==9 | POBPCOAC==10 | POBPCOAC==11
label define cond_actividad 1"Menores de 14" 2"Ocupados" 3"Desocupados" 4"Inactivos"

gen ocupado=.
replace ocupado=0 if inlist(cond_actividad,2,3,4) 
replace ocupado=1 if cond_actividad==2

* 2.2. Type of employment (Not standard within countries)
gen ocupacion=.
replace ocupacion=1 if F73==1
replace ocupacion=2 if F73==2
replace ocupacion=3 if F73==3
replace ocupacion=4 if F73==5 | F73==6
replace ocupacion=5 if F73==4
replace ocupacion=6 if F73==7
replace ocupacion=8 if F73==3
replace ocupacion=9 if F73==8
label define ocupacion 1"Obrero o empleado de empresa particular" 2"Obrero o empleado del gobierno" 3"Cooperativista" 4"Trabajador por cuenta propia" 5"Patrón o empleador" 6"Trabajador familiar sin remuneración" 8"Jornalero o peón" 9"Otro"
label value ocupacion ocupacion

gen hr_trabajadas=F85 //Horas trabajadas por semana

gen ocup_sec = 1 if inrange(F70,2,9) // Cantidad de trabajos que tiene
replace ocup_sec = 0 if F70 == 1
replace ocup_sec = . if ocupado != 1 

* 2.2.1. Domestic worker - dummy
gen empleada_domestica = .

* 2.2.2. Self-employed (with or without employees) - dummy
gen independiente=.
replace independiente=0 if ocupacion!=.
replace independiente=1 if ocupacion==4 | ocupacion==5 

* 2.2.3. Self-employed without employees - dummy
gen cuenta_propia = .
replace cuenta_propia = 1 if ocupacion == 4
replace cuenta_propia = 0 if inlist(ocupacion,1,2,3,5,6,8,9)
replace cuenta_propia = . if ocupado != 1

* 2.2.4. Paid worker - Dummy 
gen trabajador_rem = 0
replace trabajador_rem = 1 if ocupado == 1 & inlist(ocupacion,1,2,8,4,5)
replace trabajador_rem = . if ocupado != 1

* 2.3. Public employment or education sector - Dummy
gen empleo_publico = 0

	* Autorreportada
replace empleo_publico = 1 if ocupacion == 2 // Reporta trabajar para una empresa estatal
	
	* Por sector de actividad
gen sector2d=substr(F72_2,1,2)	
replace empleo_publico = 1 if sector2d == "84" // CIIU REV4 admin publica y defensa
replace empleo_publico = . if ocupado != 1

* 7.2 Variable de empleado público o de educación
gen publico_educ = 0
replace publico_educ = 1 if empleo_publico == 1 | sector2d == "85" // enseñanza
replace publico_educ = . if ocupado != 1

* 2.4. Business size
gen size_50_100 = .
replace size_50_100=1 if inlist(F77,1,2)
			replace size_50_100=2 if F77==3
			replace size_50_100=3 if inlist(F77,6,7)
			replace size_50_100=4 if F77==5
			label define size_50_100 1"1-4" 2"5-9" 3"10-49" 4"50 o más" 
label value size_50_100 size_50_100

* 2.5. Economic sector
preserve
use "$publicdata\correlativa_sectores.dta", clear
keep if pais == "Uruguay_2019"
keep rama cod_sector_unificado_rev4
destring rama, replace
rename (rama cod_sector_unificado_rev4) (sector sector_rev4)
tempfile temp
save `temp', replace
restore

gen sector = F72_2
destring sector, replace
merge m:1 sector using `temp', nogen

label define sector_rev4 1 "AGRICULTURA, GANADERÍA, CAZA, SILVICULTURA Y PESCA" 2 "MINERIA" 3 "INDUSTRIAS MANUFACTURERAS" 4 "SUMINISTRO DE ELECTRICIDAD, GAS, VAPOR Y AIRE ACONDICIONADO" 5 "CONSTRUCCIÓN" 6 "COMERCIO Y ALOJAMIENTO" 7 "TRANSPORTE Y ALMACENAMIENTO" 8 "INFORMACIÓN Y COMUNICACIONES" 9 "ADMINISTRACIÓN PÚBLICA Y DEFENSA" 10 "EDUCACION Y SALUD" 11 "OTRAS ACTIVIDADES DE SERVICIOS" 12 "ACTIVIDADES DE LOS HOGARES" 13 "ONGS Y EXTRATERRITORIALES" 14 "NO CLASIFICADAS"
label val sector_rev4 sector_rev4

gen sector_desagregado_p = sector

* 2.6. Informal worker - Dummy	
gen informal=.
replace informal=1 if F82==2
replace informal=0 if F82==1
replace informal=. if ocupado==0
label var informal "Empleados en el sector informal de acuerdo a su afiliación a pensiones"

** 3. Income

* 3.1. Personal earnings 

* 3.1.1. Create all components of Personal earnings 

* 4.1. Ingresos trabajadores dependientes (Empleados)
* 4.1.1. Ocupación principal (mayores ingresos) para todos los trabajadores
gen sueldo=G126_1              //Sueldo o jornales líquidos
gen comisiones=G126_2          //Comisiones, Incentivos, Horas Extras, Habilitaciones	
gen viaticos=G126_3            //Viáticos No Sujetos A Rendición	
gen propinas=G126_4            //Propinas
gen aguinaldo=G126_5           //Aguinaldo	
gen salario_vacacional=G126_6  //Salario vacacional	
gen pagos_atrasados=G126_7     //Pagos atrasados	
gen transporte=G126_8          //Boletos de transporte

* 4.1.1.2. Ingresos en especie
gen alimentos=G127_3           //Alimentos o bebidas
gen tiques_alimentacion=G128_1 //Tiques de alimentación
gen vivienda=G129_2            //Vivienda o alojamiento
gen otro_especie=G130_1        //Otro tipo de redistribución en especie
gen complemento=G131_1         //Algún otro tipo de complemento pagado por el empleador

* 4.1.1.3. Ingresos trabajador agropecuario (Derecho a cultivo para consumo propio)
gen der_cultivo1=G133_1         //Monto que habría tenido que pagar por esos productos
gen der_cultivo2=G133_2         //Monto percibido por la venta de esos productos

* 4.1.2. Otras ocupaciones en relación de dependencia 
gen sueldo_ocu2=G134_1         //Sueldo o jornales líquidos
gen comisiones_ocu2=G134_2     //Comisiones, Incentivos, Horas Extras, Habilitaciones	
gen viaticos_ocu2=G134_3       //Viáticos No Sujetos A Rendición	
gen propinas_ocu2=G134_4       //Propinas
gen aguinaldo_ocu2=G134_5      //Aguinaldo
gen salario_vacacionalocu2=G134_6  //Salario vacacional
gen pagos_atrasadosocu2=G134_7    //Pagos atrasados	
gen transporte_ocu2=G134_8     //Boletos de transporte

* 4.1.2.1. Ingresos en especie
gen alimentos_ocu2=G135_3           //Alimentos o bebidas
gen tiques_alimentacionocu2=G136_1  //Tiques de alimentación
gen vivienda_ocu2=G137_2            //Vivienda o alojamiento
gen otro_especieocu2=G138_1         //Otro tipo de redistribución en especie
gen complemento_ocu2=G139_1         //Algún otro tipo de complemento pgado por el empleador//

* 4.1.2.2. Ingresos trabajador agropecuario (Derecho a cultivo para consumo propio)
gen der_cultivoocu1=G141_1         //Monto que habría tenido que pagar por esos productos
gen der_cultivoocu2=G141_2         //Monto percibido por la venta de esos productos

* 4.2. Ingresos del trabajador no dependiente (Patrón/empleador/cuenta propia: negocios propios)
gen retiro_gastoshogar=G142    //Retiro para gastos del hogar de negocios que tiene o tenía
gen utilidades=G143/12            //Distribución de utilidades por negocio que tiene o tenía **Preguntar

*Retriro de productos para consumo propio (trabajador no agropecuario)
gen consumo_propio=G144_1      //Monto que habría tenido que pagar por esos bienes

*Retriro de productos para consumo propio (trabajador agropecuario)
gen ing_carnes=G144_2_1        //Valor de lo consumido en carnes o chacinados
gen ing_lacteos=G144_2_2       //Valor de lo consumido en lácteos
gen ing_huevos=G144_2_3        //Valor de lo consumido en huevos y aves
gen ing_huerta=G144_2_4        //Valor de lo consumido en productos de la huerta
gen ing_otrosali=G144_2_5      //Valor consumido en otros alimentos

gen ing_medianeria=G145/12       //Ingreso por Medianería o aparcería
gen ing_pastoreo=G146/12          //Ingreso por Pastoreo
gen ing_ganado=G147/12           //Ingreso por Ganado a Capitalización

egen ing_indep= rowtotal(retiro_gastoshogar utilidades consumo_propio ing_carnes ing_lacteos ing_huevos ing_huerta ing_otrosali ing_medianeria ing_pastoreo ing_ganado), m
replace ing_indep = . if ing_indep ==0 & ocupado!=1

egen ing_ocuprin = rowtotal(sueldo comisiones viaticos propinas aguinaldo salario_vacacional pagos_atrasados transporte alimentos tiques_alimentacion vivienda otro_especie complemento der_cultivo1 der_cultivo2), m
replace ing_ocuprin = . if ing_ocuprin ==0 & ocupado!=1

egen salario = rowtotal (sueldo sueldo_ocu2 ), m
egen i_laboral = rowtotal(der_cultivo1 der_cultivo2 der_cultivoocu1 der_cultivoocu2 retiro_gastoshogar consumo_propio ing_carnes ing_lacteos ing_huevos ing_huerta ing_otrosali ing_medianeria ing_pastoreo ing_ganado), m
egen ing_especie = rowtotal( alimentos tiques_alimentacion vivienda otro_especie complemento alimentos_ocu2 tiques_alimentacionocu2 vivienda_ocu2 otro_especieocu2 complemento_ocu2), m

egen primas = rowtotal(comisiones viaticos propinas aguinaldo salario_vacacional pagos_atrasados comisiones_ocu2 viaticos_ocu2 propinas_ocu2 aguinaldo_ocu2 salario_vacacionalocu2 pagos_atrasadosocu2 transporte transporte_ocu2), m

egen ing_lab_0 =rowtotal(salario i_laboral ing_especie utilidades primas), m
egen ing_labp_0= rowtotal(ing_ocuprin ing_indep), m

* 6.8 Ingreso personal comparable con WID (incluye salario, ganancia, vivienda, alimentos, salario/ganancia segunda ocupacion)
egen ing_pers_wid = rowtotal(sueldo sueldo_ocu2 retiro_gastoshogar ing_medianeria ing_pastoreo ing_ganado alimentos tiques_alimentacion vivienda), m
label var ing_pers_wid "Definición de ingreso personal comparable con WID"

*** Save database with variables of interest
keep fac_exp_yr hogar edad hombre urbano yr_edu educ_nivel asiste ocupado ocupacion hr_trabajadas trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab_0 ing_pers_wid ing_labp_0 ordering
save "$processeddata\Uruguay_2019.dta", replace

****************************************************
* VARIABLES CREATED THE SAME WAY FOR ALL COUNTRIES *
****************************************************

/*
1. Sexo
2. Educacion: continua y categorica
3. Edad: continua y categorica
4. Ocupacion de cada pais
5. Rural y urbano

DECIRLE A MARCELA QUE HORAS TRABAJADAS ES EN LA OCUP PRINCIPAL. Horas trabajadas cero las pongo en la primer cat?

*/

clear 
tempfile temp
gen pais = ""
save `temp', replace

global paises Argentina_2019 Bolivia_2019 Brazil_2019 Chile_2017 Colombia_2019 CostaRica_2019 RepDom_2019 Mexico_2018 Paraguay_2019 Peru_2019 Uruguay_2019

foreach file of global paises{
	
	use "${processeddata}\\`file'.dta" , clear
	
	gen pais = "`file'"
	append using `temp'
	save `temp', replace
}

** EN LA BASE APPENDED ***************************************************************************
use `temp', clear 

** Variables creadas igual para todos los paises a partir de variables armonizadas

* Grupo de edad
gen edad_groups=1 if edad>=0 & edad<=14
replace edad_groups=2 if edad>=15 & edad<=25
replace edad_groups=3 if edad>=26 & edad<=45
replace edad_groups=4 if edad>=46 & edad<=65
replace edad_groups=5 if edad>65
label define edades 1"Entre 0 y 14 años" 2"Entre 15 y 25 años" 3"Entre 26 y 45 años" 4 "Entre 46 y 65 años" 5"Mayores de 65 años"
label value edad_groups edades

* Tiempo de trabajo
gen hrs_cat = .
replace hrs_cat = 1 if hr_trabajadas < 20
replace hrs_cat = 2 if hr_trabajadas >= 20 & hr_trabajadas < 40
replace hrs_cat = 3 if hr_trabajadas >= 40 & hr_trabajadas != .
label define hrs_cat 1 "0 - <20 hours" 2 "20 - <40" 3 "40+"
label val hrs_cat hrs_cat

* Trabajo agropecuario 
gen agro = 1 if sector_rev4 == 1
replace agro = 0 if sector_rev4 != 1 & sector_rev4 != .	 

***** Imputacion de ingresos missing, cero o negativos
gen income_censurado = ing_lab_0
replace income_censurado = . if ing_lab_0 <= 0

drop if ordering==.
StableQuantiles income_censurado [iw=fac_exp_yr] , bins(100) seed(9) idvars( pais ordering) genvar(pctiles) by(pais) 
replace income_censurado = . if inlist(pctiles,1,100)

global covs hombre educ_nivel edad_groups ocupacion urbano hrs_cat agro

foreach var of global covs{
	replace income_censurado = . if `var' == .
}

* ybar con factor de expansion
bys pais $covs: egen ing_i_mean_wt=wtmean(income_censurado) if trabajador_rem==1, weight(fac_exp_yr)

gen ing_lab = ing_lab_0
replace ing_lab = ing_i_mean_wt if trabajador_rem == 1 & (ing_lab_0==. | ing_lab_0 <= 0)

replace yr_edu = . if asiste == 1 // For analysis in the paper

keep pais fac_exp_yr edad hombre yr_edu educ_nivel asiste ocupado ocupacion trabajador_rem informal empleada_domestica independiente cuenta_propia size_50_100 publico_educ sector_rev4 sector_desagregado_p informal ing_lab ing_pers_wid ordering // Keep only variables used for the project

save "${processeddata}\latam_11_inisghts.dta", replace