********************************************************************************
**																			  **
**		1.1 LATAM Employment dataset        								  **
**																			  **
********************************************************************************

cap log close
log using "${results}/Logs/Log 1.1 LATAM Employment dataset `c(current_date)'.txt", replace text

use "${processeddata}\latam_11_inisghts.dta" , clear

keep if ing_lab >0 
keep if ing_lab != .
keep if edad >= 20 & edad != .
keep if ocupado == 1
drop if ocupacion == .

* Drop public administration and education sector workers
drop if publico_educ == 1

* Adjust some household workers
replace size_50_100 = 1 if empleada_domestica == 1 & size_50_100 == .
replace size_50_100 = . if cuenta_propia == 1
drop if size_50_100 == . & cuenta_propia != 1 & ocupado == 1

* Create employment size categories 
* Different variables for some countries that have different size bins
gen firmselfemployed = (cuenta_propia==1)
gen firm1to4 = (size_50_100==1)
gen firm5to9 = (size_50_100==2)
gen firm10to49 = (size_50_100==3) if !inlist(pais,"Argentina_2019","CostaRica_2019")
gen firm50to99 = (size_50_100==4) if !inlist(pais,"Argentina_2019","Chile_2017","Brazil_2019","Uruguay_2019","CostaRica_2019")
gen firm100plus = (size_50_100==5) if !inlist(pais,"Chile_2017","Brazil_2019","Uruguay_2019")

gen firm10to40 = (size_50_100==3) if pais=="Argentina_2019"
gen firm41to99 = (size_50_100==4) if pais=="Argentina_2019"
gen firm50plus = (size_50_100==4) if inlist(pais,"Chile_2017","Brazil_2019","Uruguay_2019")
gen firm10to30 = (size_50_100==3) if pais=="CostaRica_2019"
gen firm31to99 = (size_50_100==4) if pais=="CostaRica_2019"

drop if size_50_100 == . & cuenta_propia!=1

set seed 1234
by pais: quantiles ing_lab [iw=fac_exp_yr], gencatvar(deciles) n(10) stable
drop if deciles == .

collapse (mean) firmselfemployed firm1to4 firm5to9 firm10to49 firm50to99 firm100plus firm10to40 firm41to99 firm50plus firm10to30 firm31to99  (sum) persons_decile=fac_exp_yr [aw=fac_exp_yr], by(decile pais)

// create country variable as pais before _ in string
gen country = substr(pais,1,index(pais,"_")-1)
gen year = substr(pais,index(pais,"_")+1,.)

drop pais

sort country decile

egen sum = rowtotal(firm*)

sum sum,d // All values should be 1 or almost exactly 1
drop sum

export excel using "$results\Results LATAM.xlsx", sheet("Dataset",modify) cell(A1)  firstrow(variables) 
