*** DO FILE PARA FIGURE ANEXO CON INFORMALIDAD ***
		/*******************************************************************
	
	Este do-file crea la base de datos para la Figure 2 del paper de Eslava, Melendez y Urdaneta.
	
	Divide a la población entre cuenta propia, trabajadores 1-4, 5-10, 11-100, 101 or more
	
	Last modified:  Marzo 1 2023
	
	* Se dejan personas de 20 años o más, ocupadas, y que tengan ing_lab >0 & !=. 
	
	* Se escogio la V3 que excluye trabajadores del sector publico y de educación
	
	* NOTA: Si sale un error en empleo_publico se debe correr primero el do file empleo publico
	
	* Se hacen dos versiones. Una en que se divide en las cateogorias 10-50, 50-100, 100+. Para esta version se imputan datos para Brazil, Chile and Uruguay. La segunda muestra como ultima categoria 50+. Importante tener en cuenta que Argentina es 40+ y Costa Rica 30+.
	
	* Esta version excluye Argentina y Costa Rica porque no podemos definir bien informalidad (ARG: solo se le pregunta a trabajadores asalariados - CRI: no esta nuestra definicion de informalidad)
	
		*******************************************************************/
	
/* 
-------------------------------------------------------------------------------
- P
-------------------------------------------------------------------------------
last change:
    14 Jun 2023
-------------------------------------------------------------------------------
Notes:
- 
-------------------------------------------------------------------------------
Author:
    Laura Tenjo (lauratenjo@worldbank.org)
-------------------------------------------------------------------------------
*/

cap log close
log using "${results}/Logs/Log 1.1 LATAM Figure A1 `c(current_date)'.txt", replace text

global paises Bolivia_2019 Brazil_2019 Chile_2017 Colombia_2019 RepDom_2019 Paraguay_2019 Peru_2019 Uruguay_2019

cls


* Create a temporary file to gradually add statistics
clear
tempfile temporal

* Create the variables used for merging as keys
gen pais = ""
gen year = ""
gen status_laboral = .
gen informal = .
save `temporal', replace

* Run everything for each country
foreach file of global paises {
	
	dis in red " ############ `file' ########### "

	use "${processeddata}\latam_11_inisghts.dta" , clear
	keep if pais == "`file'"

	* Only keep population of interest
	keep if edad >= 20 & edad != .
	keep if ocupado == 1
	drop if ocupacion == .
	gen Q=1

	* Exclude workers from the public sector and the education sector
	drop if publico_educ == 1

	* Assign the smallest category to domestic workers without business size
	replace size_50_100 = 1 if empleada_domestica == 1 & size_50_100 == .
	replace size_50_100 = . if cuenta_propia == 1
	recode size_50_100 (5=4)
	
	* Create divisions, which is the employment status, all categories are mutually exclusive
	gen status_laboral = size_50_100
	replace status_laboral = -1 if cuenta_propia == 1
	replace status_laboral = 99 if size_50_100 == . & cuenta_propia != 1 & ocupado == 1

	* Drop workers who are not self-employed and do not report business size
	drop if status_laboral == 99

	* Individual earnings Quintiles
	replace ing_lab = . if ing_lab <= 0
	quantiles ing_lab [iw=fac_exp_yr], gencatvar(quintiles) n(5) stable

	* Drop workers who do not report individual earnings
	drop if quintiles == .

	* Save the letters from the database name as the country and the numbers as the year
	cap drop pais
	gen pais = regexs(1) if regexm("`file'", "([A-Za-z]+)[_]")
	gen year = regexs(1) if regexm("`file'", "[_]([0-9]+)")

	* Calculate total share informality
	egen informalshare = wtmean(informal), weight(fac_exp_yr)

	* Collapse and merge with aggregate database
	collapse (mean) informalshare (sum) Q [iw=fac_exp_yr], by(pais year status_laboral informal)
	merge 1:1 pais year status informal using `temporal', nogen
	save `temporal', replace

}

	use `temporal', replace
	
	drop if informal == .
	bys pais: egen total = sum(Q) 
	gen share = Q/total*100

	collapse (sum) share (mean) total, by(status informal pais year)

	sum share if informal==1 [w=total]
	dis "Mean informalidad: " r(mean)

	collapse (mean) share [w=total] , by(status informal)
	sort status_laboral informal 
	format share %12.0fc

	export excel using "$results\Results LATAM.xlsx", sheet("FA1 - Size + informality", modify) cell(A1) first(variables)

	collapse (sum)	share, by(informal)

	export excel using "$results\Results LATAM.xlsx", sheet("FA1 - Size + informality total", modify) cell(A1) first(variables)
	

	

	