
cap log close
log using "${results}/Logs/Log 1.1 LATAM Table 1 `c(current_date)'.txt", replace text

***** REGRESIONES ******


global paises Argentina_2019 Bolivia_2019 Brazil_2019 Chile_2017 Colombia_2019 CostaRica_2019 RepDom_2019 Mexico_2018 Paraguay_2019 Peru_2019 Uruguay_2019

cls
clear

tempfile temp
gen pais = ""
save `temp', replace

foreach file of global paises{
    
dis in red "************ `file' ************"

use "${processeddata}\latam_11_inisghts.dta" , clear
keep if pais == "`file'"

cap gen empleada_domestica=.
keep if ing_lab >0 
keep if ing_lab != .
keep if edad >= 20 & edad != .
keep if ocupado == 1
drop if ocupacion == .
gen Q=1

* Se eliminan trabajadores del sector publico y del sector educativo
drop if publico_educ == 1

* Se estandariza al maximo size posible para todos los paises
recode size_50_100 (5=4)
rename size_50_100 size_50more

* Se pone en la categoría más pequeña a empleada doméstica que no tenga tamaño
replace size_50more = 1 if empleada_domestica == 1 & size_50more == .
replace size_50more = . if cuenta_propia == 1

* Acá creamos uno de los cortes que es el estatus laboral, todas las categorias son excluyentes
gen status_laboral = size_50more
replace status_laboral = -1 if cuenta_propia == 1
replace status_laboral = 5 if size_50more == . & cuenta_propia != 1 & ocupado == 1 
replace status_laboral = 6 if status_laboral == .

drop if inlist(status_lab,5,6)

label define status_laboral -1 "Self-employed without employees" 1 "1-4" 2 "5-10" 3 "11-50" 4 "51+"
label val status_laboral status_laboral

tempfile mainfile
save `mainfile', replace

* Quintiles

cap drop quintile
replace ing_lab = . if ing_lab <= 0
*replace ing_lab_0 = . if ing_lab_0 <= 0
sort *

if "`file'" == "Argentina_2019"{  
	gen ing_ppp2019 = ing_lab/20.753
	*gen ing2 = ing_lab_0/20.753
}

if "`file'" == "Bolivia_2019"{  
	gen ing_ppp2019 = ing_lab/2.6082863
	*gen ing2 = ing_lab_0/2.6082863
}

if "`file'" == "Brazil_2019"{  
	gen ing_ppp2019 = ing_lab/2.3995772
	*gen ing2 = ing_lab_0/2.3995772
}

if "`file'" == "Chile_2017"{  
	replace ing_lab = ing_lab/95.554*100
	gen ing_ppp2019 = ing_lab/443.72347
	
	*replace ing_lab_0 = ing_lab_0/95.554*100
	*gen ing2 = ing_lab_0/443.72347
}

if "`file'" == "Colombia_2019"{  
	gen ing_ppp2019 = ing_lab/1429.4924
	*gen ing2 = ing_lab_0/1429.4924
}

if "`file'" == "CostaRica_2019"{  
	gen ing_ppp2019 = ing_lab/342.78903
	*gen ing2 = ing_lab_0/342.78903
}

if "`file'" == "RepDom_2019"{  
	gen ing_ppp2019 = ing_lab/24.65729
	*gen ing2 = ing_lab_0/24.65729
}

if "`file'" == "Mexico_2018"{  
	replace ing_lab = ing_lab/96.5251*100
	gen ing_ppp2019 = ing_lab/10.362794
	*replace ing_lab_0 = ing_lab_0/96.5251*100
	*gen ing2 = ing_lab_0/10.362794
}

if "`file'" == "Paraguay_2019"{  
	gen ing_ppp2019 = ing_lab/2601.9206
	*gen ing2 = ing_lab_0/2601.9206
}

if "`file'" == "Peru_2019"{  
	gen ing_ppp2019 = ing_lab/1.8787662
	*gen ing2 = ing_lab_0/1.8787662
}

if "`file'" == "Uruguay_2019"{  
	gen ing_ppp2019 = ing_lab/27.663621
	*gen ing2 = ing_lab_0/27.663621
}

quantiles ing_ppp2019 [iw=fac_exp_yr], gencatvar(quintile) n(5) stable
drop if quintile == .
*quantiles ing2 [iw=fac_exp_yr], gencatvar(quintile_0) n(5) stable

** Aca hago el rename y cambios para tener los mimsos nombres del do file de regresiones
tab status_laboral, gen(statusd)

rename(fac_exp_yr statusd1 statusd2 statusd3 statusd4 statusd5 ing_ppp2019 sector_rev4) (_fep self_emp firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus income rama2d) 
destring rama2d, replace

gen mujer = 1 if hombre == 0
replace mujer = 0 if hombre == 1

gen edad2=edad^2
gen yr_edu2=yr_edu^2

global caracteristicas mujer edad edad2
keep firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus yr_edu yr_edu2 $caracteristicas _fep income  status_laboral rama2d educ_nivel sector_desagregado_p
gen pais = "`file'"
append using `temp'
save `temp', replace

}

/*
    Este do file corre la regresión para los países y el promedio ponderado de LATAM 
	con ingreso: con imputación (income) 
-------------------------------------------------------------------------------
created on:
    21 Dec 2022
-------------------------------------------------------------------------------
last change:
    26 Jul 2023 (categoria de 50+ y agregar efecto de sector lo mas desagregado para cada pais)
-------------------------------------------------------------------------------
Notas: 
	   
	   Para America Latina se decidio por la version de promedio agregado en lugar
	   de la versión pooled.
	   
		Se decidio usar la variable con ingreso imputado "income". 
-------------------------------------------------------------------------------
Autor:
    Laura Tenjo (lauratenjo@worldbank.org)
-------------------------------------------------------------------------------
*/

clear
tempfile temp2
gen pais = ""
save `temp2', replace

local obs_unw = 0

foreach file of global paises{
	
local Argentina_2019 AR
local Bolivia_2019 BO
local Brazil_2019 BR
local Chile_2017 CL
local Colombia_2019 CO 
local CostaRica_2019 CR
local RepDom_2019 DO
local Mexico_2018 MX
local Paraguay_2019 PY
local Peru_2019 PE
local Uruguay_2019 UY	

use `temp', clear

preserve

* Conteo de observaciones de la reg
global all $caracteristicas yr_edu yr_edu2 firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus rama2d sector_desagregado_p

foreach var in income $all {
	drop if `var' == . 
}
tab pais

restore

keep if pais == "`file'"
dis in red "************ `file' ************"

/*

3: Ingreso vs dummies firm size
6: Ingreso vs caracteristicas y size 
11: Ingreso vs caracteristicas, educ y size
13: Ingreso vs caracteristicas, size y sector
15: Ingreso vs caracteristicas, educ, size y sector
16: Ingreso vs caracteristicas, educ, size y sector lo mas desagregado de cada pais

*/

** Ajustar estos locals segun el numero de coeficientes a mostrar en las regresiones con FE de sector
local cols13 7
local cols15 9
local cols16 9

// Nota: las que tienen sector FE no se agregan en el global sino en la reg para poder hacer el keep de los coeficientes sin los coeficientes de sector
global indep3 firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus
global indep6 $caracteristicas firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus
global indep11 $caracteristicas yr_edu yr_edu2 firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus
global indep13 $caracteristicas firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus //FE
global indep15 $caracteristicas yr_edu yr_edu2 firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus //FE
global indep16 $caracteristicas yr_edu yr_edu2 firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus //FE(D)

* Se eliminan los missing de las que se vayan a usar en la regresión para tener igual número de observaciones. Ajustrar si se agregan o quitan variables.
global all $caracteristicas yr_edu yr_edu2 firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus rama2d sector_desagregado_p

foreach var in $all {
	drop if `var' == . 
	
	* Se guarda escalar con el promedio de cada variable 
	sum `var' [iw=_fep]
	scalar m_`var'_``file''=r(mean)
}

foreach j in 3 6 11 13 15 16{
dis in red `j'

/*Regresiones sin FE sector*/

if inlist(`j',1,2,3,5,6,8,11){
reg income ${indep`j'} [iw=_fep]

	local n e(N)
	local r2 e(r2)
	
	* Guardar matriz
	matrix A = r(table)
	
	* Locals de datos extra
	local names : colfullnames A
	local newnames : subinstr local names "_cons" "cons", word
	matrix colnames A = `newnames'
	
	* Convertir a dta y append 
	preserve
	clear
	svmat A, names(col)
	keep ${indep`j'} cons
	gen n = `n'
	gen r2 = `r2'
	keep if inlist(_n,1,2)
	gen stat = _n
	gen pais = "`file'"
	ge col = `j'
	append using `temp2'
	save `temp2', replace
	restore
	
}
else{
/*Regresiones con FE sector*/

if `j' == 16{
	qui reg income ${indep`j'} i.sector_desagregado_p // No factor weights to track observations used
	local obs_unw = `obs_unw' + e(N)
	reg income ${indep`j'} i.sector_desagregado_p [iw=_fep]
}
else{
	reg income ${indep`j'} i.rama2d [iw=_fep]
}
	local n e(N)
	local r2 e(r2)
	
	* Guardar matriz
	matrix A = r(table)
	local cols e(rank)+1
	
	* Locals de datos extra
	local names : colfullnames A
	local newnames : subinstr local names "_cons" "cons", word
	matrix colnames A = `newnames'
	
	if `j' == 4{
	matrix A = A["b"...,`cols']
	}
	else{
	matrix A = A[1...,1..`cols`j''],A[1...,`cols']
	}
	qui count if e(sample)
	local n_unweighted = r(N)
	
	* Convertir a dta y append 
	preserve
	clear
	svmat A, names(col)
	keep ${indep`j'} cons
	gen n = `n'
	gen n_unw = `n_unweighted'
	gen r2 = `r2'
	keep if inlist(_n,1,2)
	gen stat = _n
	gen pais = "`file'"
	gen col = `j'
	append using `temp2'
	save `temp2', replace
	restore
}
	
}	

} // cierra file

********************************************************************************
****************************** EXPORTAR RESULTADOS *****************************
********************************************************************************

global coefs firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus yr_edu yr_edu2 $caracteristicas cons

** 1. LATAM - promedio ponderado **********************************************
use `temp2', replace

*The standard error of the average then will be the square root from the average of the squares of the standard errors.
foreach var in $coefs{
    replace `var' = `var'^2 if stat == 2
}

bys pais: gen obs = _n
replace obs = cond(obs==1,n,.)
egen obs2 = total(obs)

collapse (mean) $coefs r2 n=obs2 [w=n], by(col stat)

gen n_unw = `obs_unw'

foreach var in $coefs{
    replace `var' = sqrt(`var') if stat == 2
}

ren ($coefs r2 n n_unw) (v1 v2 v3 v4 v5 v6 v7 v8 v9 v10 v11 v12 v13)

gen v14 = cond(inlist(col,1,2,3,5,6,8,11),0,1) // dummy de si tiene efecto fijo

reshape long v, i(col stat) j(var)
reshape wide v, i(stat var) j(col)

sort var stat

label define var 1 "1 to 4" 2 "5 to 10" 3 "11 to 50" 4 "51 or more" 5 "Years of schooling" 6 "Years of schooling$^2$" 7 "Sex (woman=1)" 8 "Age" 9 "Age$^2$" 10 "Constant" 11 "R$^2$" 12 "Obs with factor weights" 13 "Obs in dataset" 14 "Sector FE"
label val var var

drop if inrange(var,11,14) & stat == 2
replace stat = . if inrange(var,11,14)

label define stat 1 "Coef" 2 "Std. Err", modify
label val stat stat

replace var = . if stat == 2
drop stat

tostring v3 v6 v11 v13 v15 v16, format(%14.2fc) gen(v3_s v6_s v11_s v13_s v15_s v16_s) force

foreach var in v3_s v6_s v11_s v13_s v15_s v16_s{
	replace `var' = subinstr(`var',".00","",.) if inrange(var,12,13)
	replace `var' = "("+`var'+")" if var==.
	replace `var' = "NO" if var==14 & `var'=="0.00"
	replace `var' = "YES" if var==14 & `var'=="1.00"
	replace `var' = "" if `var'=="." | `var'=="(.)"
}

replace v16_s = "YES*" if var==14
keep var *_s

* Export excel and latex
export excel using "$results\Tables.xlsx", sheet("Table1", modify) firstrow(variables) cell(A1) keepcellfmt

replace v16_s = v16_s + " \\"
replace v16_s = v16_s + " \midrule" if _n==20

outsheet var v3_s v6_s v11_s v13_s v15_s v16_s using "$results\Table 1.tex",  replace nonames delim("&") noquote

********************************************************************************
************************************* GRAFICAS *********************************
********************************************************************************

** Para regresiones sin efecto fijo de sector	*******************************
* Se evalúa el intercepto para el valor promedio de las caracteristicas personales (para graficar). Se hace para las regresiones que incluyen las variables de tamaño

clear
tempfile temp3
gen col = .
save `temp3', replace
	
foreach reg in 3 6 11{
	
	global controles3
	global controles6 $caracteristicas
	global controles8 yr_edu yr_edu2
	global controles11 $caracteristicas yr_edu yr_edu2
	
	use `temp2', replace
	
	*Dejar solo coeficientes y regresion de interes
	keep if stat == 1
	keep if col == `reg'

	* Recuperar intercepto original
	rename cons cuenta_propia
	
	*Recuperar diferencias que vienen por pertenencia a categorias de tamaño de firma vs cuentapropismo
	foreach var in firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus{
		replace `var' = `var' + cuenta_propia
	}
	
	if "`reg'" != "3"{
	
	*Evaluar efecto promedio de controles
	
	foreach var in ${controles`reg'}{
		
	cap gen m_`var' = .
		
		* Crear variable de promedio de caracteristicas personales
		foreach file in $paises{
		
		local Argentina_2019 AR
		local Bolivia_2019 BO
		local Brasil_2019 BR
		local Chile_2017 CL
		local Colombia_2019 CO 
		local CostaRica_2019 CR
		local RepDom_2019 DO
		local Mexico_2018 MX
		local Paraguay_2019 PY
		local Peru_2019 PE
		local Uruguay_2019 UY

		replace m_`var' = m_`var'_``file'' if pais == "`file'"
		
	} // cierra paises
	
	* Evaluar efecto de las caracteristicas segun el promedio de controles
	
	gen control_`var' = m_`var'*`var'
		
	} // cierra var
	
	foreach var in cuenta_propia firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus{
		egen `var'_2 = rowtotal(`var' control*)
		drop `var'
		ren `var'_2 `var'
	}
	}
	
	keep pais col cuenta_propia firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus
	order pais col cuenta_propia firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus
	
	append using `temp3'
	save `temp3', replace
	
} // cierra reg

** Para regresiones con efecto fijo de sector ********************************
clear
tempfile temp4
gen col = .
save `temp4'

foreach file of global paises{

foreach reg in 13 15 16{

use `temp', clear
keep if pais == "`file'"

if "`reg'" == "16"{
	local sector sector_desagregado_p
}
else{
	local sector rama2d
}

tab `sector', gen(sector)
*Creamos categoria de referencia para rama economica a 4 digitos
rename sector1 ref_sector

global controles10 sector*
global controles13 $caracteristicas sector*
global controles14 yr_edu yr_edu2 sector*
global controles15 $caracteristicas yr_edu yr_edu2 sector*
global controles16 $caracteristicas yr_edu yr_edu2 sector*

gen cuenta_propia = (status_laboral == -1)

reg income firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus ${controles`reg'} [iw=_fep]


matrix betas==e(b)
matrix list betas
local cols e(rank) // guarda local con ultima columna de la matriz
dis `cols'

matrix table_reg=r(table) 
matrix list table_reg
matrix promedios=J(5,1,.)
*Recuperar intercepto original
matrix promedios[1,1]=betas[1,`cols']
matrix list promedios
*Recuperar diferencias que vienen por pertenencia a categorias de tamaño de firma vs cuentapropismo
forvalues a=2(1)5 {
	matrix promedios[`a', 1]=betas[1,`a'-1]+betas[1,`cols']
}
matrix list promedios

*Evaluar efecto promedio de controles
local position=5
foreach var of varlist ${controles`reg'} {
	qui sum `var' [iw=_fep] 
	scalar meadian_fe = r(mean) * betas[1,`position']
	forvalues a = 1(1)5 {
		matrix promedios[`a', 1] = promedios[`a', 1] + meadian_fe
	}
	local position = `position' + 1
}
matrix list promedios

** Preparar para exportar
clear
svmat promedios 
gen categoria = _n
gen col = `reg'
gen pais = "`file'"

append using `temp4'
save `temp4', replace



} // cierra reg

} // cierra paises

*** Preparar para exportar ****************************************************

** Guardar base con ponderadores de pais
use `temp2', replace
collapse (mean) n, by(pais)
tempfile ponderadores
save `ponderadores', replace

** 1. A nivel de país

* Regresiones con efectos fijos de sector
use `temp4', clear
reshape wide promedios1, i(pais col) j(categoria)
rename (promedios11 promedios12 promedios13 promedios14 promedios15) (cuenta_propia firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus)

* Unir con regresiones sin efectos fijos de sector
append using `temp3'
sort pais col
order pais col

label define col 3 "Simple average" 6 "Equating personal characteristics" 8 "Equating education" 10 "Equating sectors" 11 "Equating characteristics and education" 13 "Equating characteristics and sector" 14 "Equating education and sector" 15 "Equating characteristics, education, and sector" 16 "Equating characteristics, education, and disaggregated sector", modify
label val col col

label var cuenta_propia "Cuenta propia"
label var firm_size_1_5 "1 a 4"
label var firm_size_6_10 "5 a 10"
label var firm_size_11_50 "11 a 50"
label var firm_size_51plus "Más de 50"

** 2. Promedio ponderado LATAM

merge m:1 pais using `ponderadores', nogen
collapse (mean) cuenta_propia firm_size_1_5 firm_size_6_10 firm_size_11_50 firm_size_51plus [w=n], by(col)

label var cuenta_propia "Self-employed"
label var firm_size_1_5 "1 tp 4"
label var firm_size_6_10 "5 to 10"
label var firm_size_11_50 "11 to 50"
label var firm_size_51plus "More than 50"

gen ratio_50_to_self = firm_size_51plus/cuenta_propia

// Display results shown in text
list ratio_50_to_self if col == 3
list ratio_50_to_self if col == 11

export excel using "$results\Tables.xlsx", sheet("Table 1B", modify) firstrow(varl)

