*** DO FILE PARA TABLA A4 ***
		/*******************************************************************
	
	Este do-file crea la base de datos para la Table A4 del paper de Eslava, Melendez y Urdaneta.
	
	Divide a la población entre self employed, micro employee, micro owner, nonmicro employee, nonmicro owner
	
	Last modified:  Agosto 23 2021
	
	* Se dejan personas de 20 años o más, ocupadas, y que tengan ing_lab >0 & !=. 
	
	* Se escogio la V3 que excluye trabajadores del sector publico y de educación
	
	* NOTA: Si sale un error en empleo_publico se debe correr primero el do file empleo publico
		*******************************************************************/
	
	** SE QUITAN ARG, BOL, Y DOM PARA COMPARABILIDAD CON WID

cap log close
log using "${results}/Logs/Log 1.1 LATAM Table A4 `c(current_date)'.txt", replace text
	
global paises Brazil_2019 Chile_2017 Colombia_2019 CostaRica_2019 Mexico_2018 Paraguay_2019 Peru_2019 Uruguay_2019

cls


* Create a temporary file to gradually add statistics
clear
tempfile temporal
	
	* creo las variables que usamos en el merge como llave
	gen pais = ""
	gen year = ""
	gen quintiles = .
	gen status_laboral = .
	save `temporal', replace 
	
	* Empiezo a correr todo para cada una de las bases
	foreach file of global paises {
	dis in red " ############ `file' ########### "
	
		use "${processeddata}\latam_11_inisghts.dta" , clear
		keep if pais == "`file'"
		
		keep if edad >= 20 & edad != .
		keep if ocupado == 1
		drop if ocupacion == .
		gen Q=1
		
		gen size_emp_5 = size_50_100
		recode size_emp_5 (3=2) (4=2) (5=2)
		* Se pone en la categoría más pequeña a empleada doméstica que no tenga tamaño
		replace size_emp_5 = 1 if empleada_domestica == 1 & size_emp_5 == .
		replace size_emp_5 = . if cuenta_propia == 1
		
		* Acá creamos uno de los cortes que es el estatus laboral, todas las categorias son excluyentes
		gen status_laboral = size_emp_5 if independiente == 0 
		replace status_laboral = size_emp_5+2 if independiente == 1 & cuenta_propia != 1
		replace status_lab = -1 if cuenta_propia == 1
		replace status_lab = 5 if size_emp_5 == . & cuenta_propia != 1 & ocupado == 1 
		replace status_lab = 6 if status_lab == .
		
		drop if inlist(status_lab,5,6)
		
		* Quintiles
		replace ing_pers_wid = . if ing_pers_wid <= 0
		quantiles ing_pers_wid [iw=fac_exp_yr], gencatvar(quintiles) n(5) stable

		drop if quintiles == .
		
		* Acá guardo las letras del nombre de la base y ese es el país y los números en el nombre y ese es el año
		cap drop pais
		gen pais = regexs(1) if regexm("`file'", "([A-Za-z]+)[_]")
		gen year = regexs(1) if regexm("`file'", "[_]([0-9]+)")
	
		local list Q
		
		* Doble local para el collapse mas tarde que saque estadisticas distintas para cada variable
		local Q sum
		tab quintiles
		
		* primer loop que va para cada una de las variables de arriba, hace collapse y mergea con la base
		foreach var of varlist `list' {
		dis in red "`sheet' ############ `file' ########### `var' Q"
		
		preserve
			collapse (``var'') `var' [iw=fac_exp_yr], by(pais year status_laboral quintiles)
			
			merge 1:1 pais year quin status using `temporal', nogen
			save `temporal', replace
			
		restore
			
		}
		
		* Corcehete loop por cada base
		}
	
/******************************************************************
	
	Arreglos finales para ya exportar la base en orden, con nombres y sorteada
	*******************************************************************/
	
	use `temporal', replace
	
	bys pais quintiles: egen total = sum(Q) 
	gen share = Q/total*100
	bys pais: egen total_pais = sum(Q)
	
	label define status -1 "Self-employed without employees" 1 "Worker in less than 5 employee business" 2 "Worker in 6+ employee business" 3 "Owner of less than 5 employee business" 4 "Owner of 6+ employee business"
label val status status
	
	* Promedio ponderado por trabajadores de LAC por quintiles
	preserve

	fillin status_labor pais quintiles
	replace share = 0 if _fillin == 1
	bys pais: egen total2 = min(total_pais)
	collapse (mean) share [w=total2], by(status quintiles)
	reshape wide share, i(status_laboral) j(quintiles)
	format share* %12.0fc
	
	rename (share1 share2 share3 share4 share5 status) (Q1 Q2 Q3 Q4 Q5 Category)
	
	export excel using "$results\Results LATAM.xlsx", sheet("TA4- Size-Quint distr",modify) cell(A1) keepcellfmt first(variables)
	
	restore
	
	* Promedio ponderado por trabajadores de LAC
	
	preserve

	collapse (sum) Q, by(status pais)
	bys pais: egen total = sum(Q)
	gen share = Q/total*100
	fillin status_labor pais 
	replace share = 0 if _fillin == 1
	bys pais: egen total2 = min(total)
	collapse (mean) share [w=total2], by(status)
	format share %12.0fc
	sort status
	keep share
	rename share Total
	
	export excel using "$results\Results LATAM.xlsx", sheet("TA4- Size-Quint distr",modify) cell(H1) keepcellfmt first(variables)
	
	restore
		
** P95 **
	    
	* Creo un file temporal para ir añadiendo a esta las estadisticas poco a poco
	clear
	tempfile temporal
	
	* creo las variables que usamos en el merge como llave
	gen pais = ""
	gen year = ""
	gen pctiles = .
	gen status_laboral = .
	save `temporal', replace 
	
	* Empiezo a correr todo para cada una de las bases
	foreach file of global paises {
	dis in red " ############ `file' ########### "
	
		use "${processeddata}\\`file'.dta" , replace
		
		keep if edad >= 20 & edad != .
		keep if ocupado == 1
		drop if ocupacion == .
		gen Q=1
		
		gen size_emp_5 = size_50_100
		recode size_emp_5 (3=2) (4=2) (5=2)
		* Se pone en la categoría más pequeña a empleada doméstica que no tenga tamaño
		replace size_emp_5 = 1 if empleada_domestica == 1 & size_emp_5 == .
		replace size_emp_5 = . if cuenta_propia == 1
		
		* Acá creamos uno de los cortes que es el estatus laboral, todas las categorias son excluyentes
		gen status_laboral = size_emp_5 if independiente == 0 
		replace status_laboral = size_emp_5+2 if independiente == 1 & cuenta_propia != 1
		replace status_lab = -1 if cuenta_propia == 1
		replace status_lab = 5 if size_emp_5 == . & cuenta_propia != 1 & ocupado == 1 
		replace status_lab = 6 if status_lab == .
		
		drop if inlist(status_lab,5,6)
		
		* Quintiles
		replace ing_pers_wid = . if ing_pers_wid <= 0
		quantiles ing_pers_wid [iw=fac_exp_yr], gencatvar(pctiles) n(100) stable

		drop if pctiles == .
		
		* Acá guardo las letras del nombre de la base y ese es el país y los números en el nombre y ese es el año
		cap drop year
		gen pais = regexs(1) if regexm("`file'", "([A-Za-z]+)[_]")
		gen year = regexs(1) if regexm("`file'", "[_]([0-9]+)")
	
		local list Q
		
		* Doble local para el collapse mas tarde que saque estadisticas distintas para cada variable
		local Q sum
		
		* primer loop que va para cada una de las variables de arriba, hace collapse y mergea con la base
		foreach var of varlist `list' {
		dis in red "`sheet' ############ `file' ########### `var' Q"
		
		preserve
			collapse (``var'') `var' [iw=fac_exp_yr], by(pais year status_laboral pctiles)
			
			merge 1:1 pais year pctiles status using `temporal', nogen
			save `temporal', replace
			
		restore
			
		}
		
		* Corcehete loop por cada base
		}
	
/******************************************************************
	
	Arreglos finales para ya exportar la base en orden, con nombres y sorteada
	*******************************************************************/
	
	use `temporal', replace
	
	bys pais pctiles: egen total = sum(Q) 
	gen share = Q/total*100
	bys pais: egen total_pais = sum(Q)
	keep if pctiles == 95
	
	* Promedio ponderado por trabajadores de LAC por quintiles
	preserve

	fillin status_labor pais pctiles
	replace share = 0 if _fillin == 1
	bys pais: egen total2 = min(total_pais)
	collapse (mean) share [w=total2], by(status pctiles)
	format share %12.0fc
	rename share P95
	
	export excel P95 using "$results\Results LATAM.xlsx", sheet("TA4- Size-Quint distr",modify) cell(G1) keepcellfmt first(variables)
	
	restore

	