********************************************************************************
**
**							Export South Asian Results
**
********************************************************************************
**
**		This dofile departs from the results of 1. India, 1. Pakistan, and 
**		1. Nepal to aggregate results into the weighted average of the three
**		 countries. These results are used in Figures 1, 2, and A2.
**		Author: Nicolas Urdaneta 
**
********************************************************************************

cap log close
log using "${results}/Logs/Log 2 Aggregate South Asia `c(current_date)'.txt", replace text

// Combine the matrices: 

* 1. Aggregate results for Figure 1

clear 
svmat India 
svmat Pakistan
svmat Nepal

rename (India1 India2 Pakistan1 Pakistan2 Nepal1 Nepal2) (India_share India_pop Pakistan_share Pakistan_pop Nepal_share Nepal_pop) 

egen SouthAsia_pop = rowtotal(*pop) 
gen SouthAsia_share = (India_share*India_pop + Pakistan_share*Pakistan_pop + Nepal_share*Nepal_pop)/SouthAsia_pop

gen size = 1 if _n==1 
replace size = 2 if _n==2 | _n==3 
replace size =3 if _n>3 

collapse (sum) SouthAsia_pop SouthAsia_share, by(size) 

cap label drop sizes
label define sizes 1 "Self employed" 2 "1-9 workers" 3 "10+ workers"
label values size sizes
export excel using "${results}/Results South Asia.xlsx", sheet("Fig1_SA A") sheetreplace firstrow(variables)

* 2. Results by sectors for figure A2
 
use "${results}/Temporary files/pakistan_temp.dta", replace
append using "${results}/Temporary files/india_temp.dta"
append using "${results}/Temporary files/nepal_temp.dta"

sleep 2

erase "${results}/Temporary files/pakistan_temp.dta"
erase "${results}/Temporary files/india_temp.dta"
erase "${results}/Temporary files/nepal_temp.dta"
drop pop

reshape long emp pop , i(size country) j(sector) string

collapse (mean) emp (sum) pop [aw=pop], by(size sector)

bys sector: egen pop_sector = total(pop)
drop pop

reshape wide emp pop_sector, i(size) j(sector) string

replace size = 4 if size>=4

collapse (sum) emp* (mean) pop*, by(size) 

egen pop = rowtotal(pop*) 

foreach var of varlist pop_*{
	replace `var' = `var'/pop * 100
}

drop pop

cap label drop sizes
label define sizes 1 "Self employed" 2 "1-4 workers" 3 "5-9 workers" 4 "10+ workers"
label values size sizes

export excel using "${results}/Results South Asia.xlsx", sheet("Fig1_SA by sectors") sheetreplace firstrow(variables)

* 3. Size distribution in categories for correlograms in Figure 2

clear 
svmat India 
svmat Pakistan_det
svmat Nepal

gen sizes = _n 
gen sizes_det = _n 
cap label drop sizes
cap label drop sizesdet
label define sizes 1 "Self-employed" 2 "1-4 workers" 3 "5-9 workers" 4 "10-19 workers" 5 "20+ workers"
label define sizesdet 1 "Self-employed" 2 "1-4 workers" 3 "5-9 workers" 4 "10-49 workers" 5 "50-100 workers" 6 "100+ workers"
label values sizes_det sizesdet
label values sizes sizes

export excel using "${results}/Results South Asia.xlsx", sheet("Fig2_SA") sheetreplace firstrow(variables)
