********************************************************************************
**
**						3. Produce tables and figures
**
********************************************************************************
**
**		This dofile departs from the results of all country programs "1." and **      "2." to merge the data and then produce the figures and tables
**      as seen in the paper. 
**		Author: Nicolás Urdaneta
**		Date: 05/07/2023 
**
********************************************************************************

cap log close
log using "${results}/Logs/Log 3 Produce tables and figures `c(current_date)'.txt", replace text

********************************************************************************
**
**		Figure 1, all panels
**
********************************************************************************

// LATAM

import excel using "${results}/Results LATAM.xlsx", firstrow clear sheet("F1 - Size distribution") cellrange(A13:B19)

xpose, clear varname

drop if _varname == "Category"	
rename (v1 - v6) (self_emp s1_4 s5_10 s11_50 s51_100 s101plus)

rename _varname country
gen Region = "Latin America - 11"

tempfile LATAM
save `LATAM'

// USA 

import excel using "${results}/Results US.xlsx", firstrow clear sheet("Fig1_US C")

rename (self_emp firm1_4 firm5_9 firm10_49 firm50_99 firm100plus) (self_emp s1_4 s5_10 s11_50 s51_100 s101plus)

gen country = "United States"
gen Region = "United States"


tempfile US 
save `US'

// India, Pakistan, Nepal
import excel using "${results}/Results South Asia.xlsx", firstrow clear sheet("Fig1_SA A")

xpose, clear varname 

keep if _varname == "SouthAsia_share"	
rename _varname country
rename (v1 - v3) (self_emp s1_10 s11_plus)

gen Region = "India, Pakistan, Nepal (Urban)"


tempfile SouthAsia
save `SouthAsia'

// Australia, Korea, and Japan for Panel A

import excel using "${results}/Results Asia.xlsx", firstrow clear sheet("F1_Asia")

rename (selfemployed workplace_1_9 workplace_10plus) (self_emp s1_10 s11_plus)
foreach var in self_emp s1_10 s11_plus {
    replace `var'=`var'*100
}
gen Region = "Asia: Higher Income"


tempfile Asia
save `Asia'

// Europe 

import excel using "${results}/Results EU.xlsx", firstrow clear sheet("F1_Pb")

drop if advanced == ""

rename (selfemployed workers_1_4 workers_5_10 workers_11_49 workers_50plus) (self_emp s1_4 s5_10 s11_50 s51_100) // Note that for EU 51_100 is actually 51+

foreach var in self_emp s1_4 s5_10 s11_50 s51_100 {
	replace `var'=`var'*100
}

rename advanced Region

tempfile Europe
save `Europe'

// Australia for Panels B and C

import excel using "${results}/Results AUS.xlsx", firstrow clear sheet("F1_Pc")

drop region persons_q

rename (selfemployed workplace_1_4 workplace_5_9 workplace_10_49 workplace_50_99 workplace_100plus) (self_emp s1_4 s5_10 s11_50 s51_100 s101plus)

foreach var in self_emp s1_4 s5_10 s11_50 s51_100 s101plus{
	replace `var'=`var'*100
}
gen Region = "Australia"

tempfile AUS
save `AUS'


// Korea for Panels B and C

import excel using "${results}/Results KR.xlsx", firstrow clear sheet("F1_Pc")

drop region persons_q

rename (selfemployed workplace_1_4 workplace_5_9 workplace_10_49 workplace_50_99 workplace_100plus) (self_emp s1_4 s5_10 s11_50 s51_100 s101plus)

foreach var in self_emp s1_4 s5_10 s11_50 s51_100 s101plus{
	replace `var'=`var'*100
}
gen Region = "Korea"

tempfile KR
save `KR'


/// APPEND ALL COUNTRIES 

use `LATAM', clear
append using `US'
append using `SouthAsia'
append using `Asia'

append using `Europe'
append using `AUS'
append using `KR'

tempfile AllF1
save `AllF1' // we need this tempfile data for Table A2 below

/// Create variables for the three panels

replace s1_10 = s1_4 + s5_10 if s1_10 == .
replace s11_plus = s11_50 + s51_100 + s101plus if s11_plus == .
replace s11_plus = s11_50 + s51_100 if s11_plus == .
gen s51_plus = s51_100 + s101plus
replace s51_plus = s51_100 if s51_plus == .

gen PanelA = (country!="Australia" & country!="Korea")
gen PanelB = (Region!="Asia: Higher Income" & Region!="India, Pakistan, Nepal (Urban)")
gen PanelC = (Region!="Asia: Higher Income" & Region!="India, Pakistan, Nepal (Urban)" & Region!="EU: Lower Income" & Region!="EU: Higher Income")

gen order = 1*(Region=="Latin America - 11") + 2*(Region=="United States") + 3*(Region=="EU: Higher Income") + 4*(Region=="EU: Lower Income") + 5*(Region=="Asia: Higher Income") + 6*(Region=="India, Pakistan, Nepal (Urban)") + 7*(Region=="Australia") + 8*(Region=="Korea")

cap label drop regions
label define regions 1 `""Latin" "America""' 2 `""United" "States" " ""' 3 `""EU: Higher" "Income""' 4 `""EU: Lower" "Income""' 5 `""Asia: Higher" "Income""' 6 `""India, Pakistan" "Nepal (Urban)""' 7 "Australia" 8 "Korea"
label values order regions

/// Create figures with values in each bar
graph bar self_emp s1_10 s11_plus if PanelA==1, over(order) asyvars bar(1, color("1 30 65")) bar(2, color("1 73 124")) bar(3, color("97 165 194")) scheme(tufte) legend(label(1 "Self-employed without employees") label(2 "{&le}10 workers") label(3 "11+ workers") position(6) row(2) symxsize(*0.7) colgap(*0.5) keygap(*0.3) size(*1.05)) scale(*0.98) blabel(total, format(%4.0fc) size(medlarge))  graphregion(margin(0 0 2 2)) plotregion(margin(0 1 0 0))  name(Fig1A, replace) ytitle("% of all workers", size(medlarge)) ylabel(,labsize(vlarge))  //aspect(1)
gr export "${results}/Fig1A.pdf", replace

graph bar self_emp s1_4 s5_10 s11_50 s51_plus if PanelB==1, over(order) asyvars bar(1, color("1 30 65")) bar(2, color("1 73 124")) bar(3, color("42 111 151")) bar(4, color("97 165 194")) bar(5, color("137 194 217")) scheme(tufte) legend(label(1 "Self-emp. without employees") label(2 "1-4") label(3 "5-10") label(4 "11-50") label(5 "51 or more") position(6) row(2) symxsize(*0.7) colgap(*0.5) keygap(*0.3) size(*1.05)) scale(*.98) blabel(total, format(%4.0fc) size(medlarge))  graphregion(margin(0 0 2 2)) plotregion(margin(0 0 0 0))  name(Fig1B, replace) yscale(range(0 80)) ylabel(0 20 40 60 80, labsize(vlarge)) ytitle("% of all workers", size(medlarge)) //aspect(1)
gr export "${results}/Fig1B.pdf", replace

graph bar self_emp s1_4 s5_10 s11_50 s51_100 s101plus if PanelC==1, over(order) asyvars bar(1, color("1 30 65")) bar(2, color("1 73 124")) bar(3, color("42 111 151")) bar(4, color("97 165 194")) bar(5, color("137 194 217")) bar(6, color("169 214 229")) scheme(tufte) legend(label(1 "Self-emp. without employees") label(2 "1-4") label(3 "5-10") label(4 "11-50") label(5 "51-100") label(6 "101 or more") position(6) row(2) symxsize(*0.7) colgap(*0.5) keygap(*0.3) size(*1.05)) scale(*.98) blabel(total, format(%4.0fc) size(medlarge)) name(Fig1C, replace)  graphregion(margin(0 0 2 2)) plotregion(margin(0 1 0 0)) yscale(range(0 80)) ylabel(0 20 40 60 80, labsize(vlarge))
 /*ytitle("% of all workers")*/ //aspect(1)
gr export "${results}/Fig1C.pdf", replace

*gr combine Fig1A Fig1B, row(1) ysize(6) xsize(12) name(Fig1AB, replace) sch(tufte)
*gr combine Fig1AB Fig1C, col(1) ysize(12) xsize(12) name(Fig1, replace) sch(tufte)

********************************************************************************
**
**		Figure 2
**
********************************************************************************

// LATAM

import excel using "${results}/Results LATAM.xlsx", firstrow clear sheet("T A2 - Size by country")

xpose, clear varname

drop if _varname == "Category"	
rename (v1 - v6) (self_emp s1_4 s5_10 s11_50 s51_100 s101plus)

rename _varname country

replace country = "Costa Rica" if country=="CostaRica"
replace country = "Dominican Republic" if country=="RepDom"
gen Region = "Latin America"

tempfile LATAM
save `LATAM'

// USA 

import excel using "${results}/Results US.xlsx", firstrow clear sheet("Fig1_US C")

rename (self_emp firm1_4 firm5_9 firm10_49 firm50_99 firm100plus) (self_emp s1_4 s5_10 s11_50 s51_100 s101plus)

gen country = "United States"
gen Region = "United States"

tempfile US 
save `US'

// India, Pakistan, Nepal
	* Note that India and Nepal only have 20+ as category, so S51_100 for these
	* countries is actually S20_more
import excel using "${results}/Results South Asia.xlsx", firstrow clear sheet("Fig2_SA")

keep *1 sizes_det 
rename (India1 Pakistan_det1 Nepal1) (India Pakistan Nepal)
xpose, clear varname 

drop if _varname == "sizes_det"	
rename (v1 - v6) (self_emp s1_4 s5_10 s11_50 s51_100 s101plus)

rename _varname country
gen Region = "Asia and Australia"


tempfile SouthAsia
save `SouthAsia'

// Japan 

import excel using "${results}/Results Japan.xlsx", firstrow clear sheet("F2")

keep selfemployed firm1to4 firm5to9 firm10to49 firm50to99 firm100plus
rename (selfemployed firm1to4 firm5to9 firm10to49 firm50to99 firm100plus) (self_emp s1_4 s5_10 s11_50 s51_100 s101plus)

foreach var in self_emp s1_4 s5_10 s11_50 s51_100 s101plus{
	replace `var' = `var'*100
}
** Note that Japan also has a different category, so we join 11-100.

gen country = "Japan"
gen Region = "Asia and Australia"


tempfile Japan
save `Japan'

// Europe 

import excel using "${results}/Results EU.xlsx", firstrow clear sheet("Appendix_TA2")

drop if country==""

keep country selfemployed workers_1_4 workers_5_10 workers_11_49 workers_50plus

rename (selfemployed workers_1_4 workers_5_10 workers_11_49 workers_50plus) (self_emp s1_4 s5_10 s11_50 s51_100) // Note that for EU 51_100 is actually 51+

// Replace country names for abbreviations in europe country: AT BE BG CH CY CZ DE DK EE EL ES FI FR HR IE IT LT LU LV PL PT RO RS SE SI SK

replace country = "Austria" if country=="AT"
replace country = "Belgium" if country=="BE"
replace country = "Bulgaria" if country=="BG"
replace country = "Switzerland" if country=="CH"
replace country = "Cyprus" if country=="CY"
replace country = "Czech Republic" if country=="CZ"
replace country = "Germany" if country=="DE"
replace country = "Denmark" if country=="DK"
replace country = "Estonia" if country=="EE"
replace country = "Greece" if country=="EL"
replace country = "Spain" if country=="ES"
replace country = "Finland" if country=="FI"
replace country = "France" if country=="FR"
replace country = "Croatia" if country=="HR"
replace country = "Ireland" if country=="IE"
replace country = "Italy" if country=="IT"
replace country = "Lithuania" if country=="LT"
replace country = "Luxembourg" if country=="LU"
replace country = "Latvia" if country=="LV"
replace country = "Malta" if country =="MT"
replace country = "Poland" if country=="PL"
replace country = "Portugal" if country=="PT"
replace country = "Romania" if country=="RO"
replace country = "Serbia" if country=="RS"
replace country = "Sweden" if country=="SE"
replace country = "Slovenia" if country=="SI"
replace country = "Slovakia" if country=="SK"

foreach var in self_emp s1_4 s5_10 s11_50 s51_100 {
	replace `var'=`var'*100
}

gen Region = "EU: Higher Income" if inlist(country,"Austria","Belgium","Cyprus","Denmark","Finland","France","Germany","Ireland","Italy")
replace Region = "EU: Higher Income" if inlist(country,"Sweden","Switzerland", "Malta","Luxembourg")
replace Region = "EU: Lower Income" if inlist(country,"Bulgaria","Croatia","Czech Republic","Estonia","Greece","Latvia","Lithuania")
replace Region = "EU: Lower Income" if inlist(country,"Poland","Romania","Serbia","Slovakia","Slovenia","Spain", "Portugal")

tempfile Europe
save `Europe'

// Australia

import excel using "${results}/Results AUS.xlsx", firstrow clear sheet("F1_Pc")

drop region persons_q

rename (selfemployed workplace_1_4 workplace_5_9 workplace_10_49 workplace_50_99 workplace_100plus) (self_emp s1_4 s5_10 s11_50 s51_100 s101plus)

foreach var in self_emp s1_4 s5_10 s11_50 s51_100 s101plus{
	replace `var'=`var'*100
}
gen Region = "Asia and Australia"


tempfile AUS
save `AUS'


// Korea 

import excel using "${results}/Results KR.xlsx", firstrow clear sheet("F1_Pc")

drop region persons_q

rename (selfemployed workplace_1_4 workplace_5_9 workplace_10_49 workplace_50_99 workplace_100plus) (self_emp s1_4 s5_10 s11_50 s51_100 s101plus)

foreach var in self_emp s1_4 s5_10 s11_50 s51_100 s101plus{
	replace `var'=`var'*100
}

gen Region = "Asia and Australia"
tempfile KR
save `KR'


/// APPEND ALL COUNTRIES 


use `LATAM', clear
append using `US'
append using `SouthAsia'
append using `Japan'
append using `Europe'
append using `AUS'
append using `KR'

tempfile allcountries
save `allcountries' // This dataset will be used to create Table A2

// Import WDI data

import excel using "${publicdata}/WDI data.xlsx", firstrow clear

drop self_emp s1_4 s5_10 s11_50 s51_100 s101plus Region

merge 1:1 country using `allcountries', nogen

// Produce figure 2

**# Tests that in all countries shares add up to 100 
egen test100 = rowtotal(self_emp s1_4 s5_10 s11_50 s51_100 s101plus)
sum test100
drop test100

**# Cleaning of database 
{
* Business unit size cut off points are not consistent with the analysis of 
* businesses with more than 10 workers for the following countries: Argentina, 
* Costa Rica, Japan, India, and Nepal. We thus only plot these countries for 
* self-employment and 1-10 workers 
		
	foreach var of varlist s11_50 s51_100 s101plus {
		replace `var' =. if inlist(country, "Costa Rica", "Argentina", "Japan", "Nepal", "India")
	}

}


**# Prepare and create variables of interest 
{
	
rename GDPpercapitaPPPconstant201 GDPpc2017 
gen s1_10 = s1_4 + s5_10 // Generate variable of 1-10 workers
egen s51_plus_all = rowtotal(s51_100 s101plus) // Generate variable of more than 50 workers
replace GDPpc2017 = ln(GDPpc2017) // Generate variable of log GDP per capita constant 2017 US dolars

label var GDPpc2017 "Log GDP per capita, PPP (constant 2017)"
label var Gini "Gini index"
label var self_emp "self-employed"
label var s51_plus_all "51 or more workers"


***** Standardizing variables *******

* Replace zeros with .
foreach var of varlist * {
	local vartype: type `var'
	if substr("`vartype'",1,3) != "str" {
		replace `var' =. if `var' == 0
	}
}
	


foreach var of varlist GDPpc2017 Gini self_emp s1_10 s11_50 s51_plus_all {
	sum `var', d
	gen normi_`var' = (`var'-r(mean))/r(sd)
}
label var normi_GDPpc2017 "Log GDP per capita, PPP (constant 2017)"
label var normi_Gini "Gini index"
label var normi_self_emp "Share of workers who are self-employed without employees"
label var normi_s1_10 "Share of workers who are in business with up to 10 workers"
label var normi_s11_50 "Share of workers who are in businesses between 11 and 50 workers"
label var normi_s51_plus_all "Share of workers who are in businesss with 51 or more workers"

}


{
	preserve
	local j = 1
	foreach y of varlist normi_self_emp normi_s1_10 normi_s11_50 normi_s51_plus_all {
		if "`y'" == "normi_self_emp"{
			local title = "self-employed without employees"
		}
		else if "`y'" == "normi_s1_10" {
			local title = "in businesses with up to 10 workers"
		}
		else if "`y'" == "normi_s11_50"{
			local title = "in businesses between 11-50 workers"
		}
		else if "`y'" == "normi_s51_plus_all" {
			local title = "in businesses with more than 50 workers"
		}
		
		dis "`title'"

		foreach x of varlist normi_GDPpc2017 normi_Gini {
			pwcorr `y' `x'
			matrix correlacion = r(C)
			local pw = correlacion[2,1]
			local pw : di %5.2f `pw'
			reg `y' `x' 
			local coef: dis %05.3f _b[`x']

			if "`x'" == "normi_GDPpc2017"{
				local ytitle ytitle("Share of workers who are"`"`title'"', size(*1.7))
			}
			else{
				local ytitle
			}


			qui twoway (scatter `y' `x' if Region == "Latin America", mc("1 30 65") m(O)) (scatter `y' `x' if Region == "EU: Higher Income", mc("137 194 217"%80) m(D)) (scatter `y' `x' if Region == "EU: Lower Income", mc("137 194 217"%80) m(D)) (scatter `y' `x' if Region == "United States", mc("137 194 217"%80) m(D)) (scatter `y' `x' if Region == "Asia and Australia", mc("42 111 151"%80) m(S)) (lfit `y' `x', lcolor(black) lp(solid)), graphregion(fcolor(white)) `ytitle' xtitle(, size(*1.7)) saving("$results\Temporary files\fig`j'", replace)  caption(`"β: `coef'"', size(*1.8) position(2) ring(0) fcolor(white)) legend(span order(1 2 5 6) label(1 "Latin America") label(2 "Europe and U.S.") label(5 "Asia and Australia") label(6 "Linear fit") size(small) r(1) ) ysize(6) xsize(5) scheme(tufte) ylabel(, labsize(vlarge)) xlabel(, labsize(vlarge))
		local j = `j'+1
		}
	}


	grc1leg "$results\Temporary files\fig1" "$results\Temporary files\fig2" "$results\Temporary files\fig3" "$results\Temporary files\fig4" "$results\Temporary files\fig5" "$results\Temporary files\fig6" "$results\Temporary files\fig7" "$results\Temporary files\fig8", ycommon rows(4) iscale(0.3) graphregion(color(white)) legendfrom("$results\Temporary files\fig1") ysize(6) xsize(5)
	gr_edit legend.Edit, style(rows(1)) style(cols(0)) style(key_ysize(2))  style(row_gap(minuscule)) style(key_xsize(10)) keepstyles 
	gr_edit style.editstyle declared_ysize(7) editcopy
	gr_edit style.editstyle declared_xsize(7) editcopy
	gr_edit Edit , cmd(.set_rows = 4) cmd(.set_cols =0 ) 
	forvalues j = 1(1)8 {
		gr_edit plotregion1.graph`j'.yaxis1.title.style.editstyle size(medlarge) editcopy
		gr_edit plotregion1.graph`j'.style.editstyle boxstyle(linestyle(color(white))) editcopy
	}

	forvalues x=1/8{
		erase "$results\Temporary files\fig`x'.gph"
	} 
	
	
	graph export "$results\F2.pdf", as(pdf) name("Graph") replace
	restore
	
}

********************************************************************************
**
**		Table A2
**
********************************************************************************

// To create this table we need to have run the sections for Figure 1 and Figure 2
use `allcountries', clear 
append using `AllF1'

replace country = Region if country==""
replace country = "LA11" if country=="ofworkers"
replace country = "EU_Higher" if country=="EU: Higher Income"
replace country = "EU_Lower" if country=="EU: Lower Income"
replace country = "Asia_Higher" if country=="Asia: Higher Income"
replace country = subinstr(country," ","",.)

duplicates drop country, force


forvalues row=1/50{
    local c`row' = country[`row']
}

xpose , clear varname
local j = 1
foreach var of varlist v*{
    rename `var' `c`j''
    local j = `j'+1
}

drop if inlist(_varname,"country","Region")

drop SouthAsia_share Asia_Higher
drop if inlist(_varname,"s1_10","s11_plus")

replace _varname = "Self-employed without employees" if _varname=="self_emp"
replace _varname = "1-4" if _varname=="s1_4"
replace _varname = "5-10" if _varname=="s5_10"
replace _varname = "11-50" if _varname=="s11_50"
replace _varname = "51-100" if _varname=="s51_100"
replace _varname = "101 or more" if _varname=="s101plus"

tostring Argentina Bolivia Brazil Chile Colombia CostaRica DominicanRepublic Mexico Paraguay Peru Uruguay UnitedStates India Pakistan Nepal Japan Austria Belgium Bulgaria Switzerland Cyprus CzechRepublic Germany Denmark Estonia Greece Spain Finland France Croatia Ireland Italy Lithuania Luxembourg Latvia Malta Poland Portugal Romania Serbia Sweden Slovenia Slovakia Australia Korea LA11 EU_Lower EU_Higher, replace force format(%4.0fc)

foreach var of varlist _all{
    replace `var' = "-" if `var'=="."
}

gen order = _n 
set obs 7 
replace order = 0 if order==.
foreach var of varlist _all{
    if !inlist("`var'","_varname","order"){
        replace `var' = "`var'" if order==0 & `var'=="" 
    }
}
replace CostaRica = "Costa Rica" if CostaRica=="CostaRica"
replace DominicanRepublic = "Dominican Republic" if DominicanRepublic=="DominicanRepublic"
replace UnitedStates = "United States" if UnitedStates=="UnitedStates"
replace CzechRepublic = "Czech Republic" if CzechRepublic=="CzechRepublic"
replace LA11 = "Latin America" if LA11=="LA11"
replace EU_Lower = "EU: Lower Income" if EU_Lower=="EU_Lower"
replace EU_Higher = "EU: Higher Income" if EU_Higher=="EU_Higher"

sort order

rename (Argentina DominicanRepublic Austria France Sweden Greece Serbia Australia) (Col1_row1 Col1_row2 Col1_row3 Col1_row4 Col1_row5 Col1_row6 Col1_row7 Col1_row8)
rename (Bolivia Mexico Belgium Ireland EU_Higher Latvia Slovakia Korea) (Col2_row1 Col2_row2 Col2_row3 Col2_row4 Col2_row5 Col2_row6 Col2_row7 Col2_row8)
rename (Brazil Paraguay Cyprus Italy Bulgaria Lithuania Slovenia Japan) (Col3_row1 Col3_row2 Col3_row3 Col3_row4 Col3_row5 Col3_row6 Col3_row7 Col3_row8)
rename (Chile Peru Denmark Luxembourg Croatia Poland Spain India) (Col4_row1 Col4_row2 Col4_row3 Col4_row4 Col4_row5 Col4_row6 Col4_row7 Col4_row8)
rename (Colombia Uruguay Germany Malta CzechRepublic Portugal EU_Lower Pakistan) (Col5_row1 Col5_row2 Col5_row3 Col5_row4 Col5_row5 Col5_row6 Col5_row7 Col5_row8)
rename (CostaRica LA11 Finland Switzerland Estonia Romania UnitedStates Nepal) (Col6_row1 Col6_row2 Col6_row3 Col6_row4 Col6_row5 Col6_row6 Col6_row7 Col6_row8)

reshape long Col1_row Col2_row Col3_row Col4_row Col5_row Col6_row, i(_varname order) j(row)

replace _varname="" if _varname=="_varname"

replace _varname = "51 or more" if order==5 & inlist(row,3,4,5,6)
drop if order==6  & inlist(row,3,4,5,6)
replace _varname="51-100 / 51+ (Brazil, Chile)" if order==5 & row==1
replace _varname="51-100 / 51+ (Uruguay)" if order==5 & row==2
replace _varname="51 or more (EU) / 51-100 (US)" if order==5 & row==7
replace _varname = "11-50 / 11-19 (India, Nepal)" if order==4 & row==8
replace _varname = "51-100 / 20+ (India, Nepal)" if order==5 & row==8

sort row order 
order order row _varname Col1_row Col2_row Col3_row Col4_row Col5_row Col6_row

export excel _varname Col1_row Col2_row Col3_row Col4_row Col5_row Col6_row using "${results}/Tables.xlsx", firstrow(variables)  sheet("Table A2") sheetreplace 

bys row: egen last_order = max(order)

replace Col6_row =Col6_row + " \\"
replace Col6_row = Col6_row + " \midrule \midrule" if order==last_order & row!=8 
replace Col6_row = Col6_row + " \cline{2-7}" if order==0  
replace Col6_row = Col6_row + " \bottomrule \bottomrule" if order==6 & row==8

outsheet _varname Col1_row Col2_row Col3_row Col4_row Col5_row Col6_row using "$results\Table A2.tex",  replace nonames delim("&") noquote





********************************************************************************
**
**		Figure 3, all panels
**
********************************************************************************

// LATAM

import excel using "${results}/Results LATAM.xlsx", firstrow clear sheet("F3 - Distribution by decile")

rename (Incomedecile Selfemployedwithoutemployees Employees110 Businessowners110 Employees11 Businessowners11) (Decile self_emp Emp1_10 Own1_10 Emp11_plus Own11_plus)

gen Region = "Latin America - 11"

tempfile LATAM
save `LATAM'

// USA 

import excel using "${results}/Results US.xlsx", firstrow clear sheet("Fig3_US")

rename (decile self_emp employee_micro owner_micro employee_nonmicro owner_nonmicro) (Decile self_emp Emp1_10 Own1_10 Emp11_plus Own11_plus)

gen country = "United States"
gen Region = "United States"


tempfile US 
save `US'

// India. We can't add Pakistan or Nepal since we do not have self-employment income for them

import excel using "${results}/Results India.xlsx", firstrow clear sheet("Fig3")

gen Region = "India"

tempfile India
save `India'


// Australia and Korea

import excel using "${results}/Results Asia.xlsx", firstrow clear sheet("F3_KR_AUS")

rename (qtiles selfemployed employee1_9 employer1_9 employee10_more employer10_more) (Decile self_emp Emp1_10 Own1_10 Emp11_plus Own11_plus)
foreach var in self_emp Emp1_10 Own1_10 Emp11_plus Own11_plus {
    replace `var'=`var'*100
}
gen Region = "Asia: Higher Income"

tempfile Asia
save `Asia'

// Europe 

import excel using "${results}/Results EU.xlsx", firstrow clear sheet("F3")

drop if advanced == ""

rename (decile selfemployed employee_micro employer_micro employee_nonmicro employer_nonmicro) (Decile self_emp Emp1_10 Own1_10 Emp11_plus Own11_plus)
foreach var in self_emp Emp1_10 Own1_10 Emp11_plus Own11_plus {
	replace `var'=`var'*100
}

rename advanced Region

tempfile Europe
save `Europe'

/// APPEND ALL COUNTRIES 

use `LATAM', clear
append using `US'
append using `India'
append using `Asia'
append using `Europe'

encode Region, gen(Region_groups)
levelsof Region_groups, local(regions)
// `"Asia: Higher Income"' `"EU: Higher Income"' `"EU: Lower Income"' `"India"' `"Latin America - 11"' `"United States"'
foreach reg of local regions{

    // extract label of variable
    local reg_label: label(Region_groups) `reg'
    dis "`reg_label'"

    gr bar self_emp Emp1_10 Own1_10 Emp11_plus Own11_plus if Region_groups == `reg', over(Decile, label(labsize(large))) stack asyvars bar(1, color("1 30 65")) bar(2, color("1 73 124")) bar(3, color("42 111 151")) bar(4, color("97 165 194")) bar(5, color("137 194 217")) scheme(tufte) legend(off) scale(*.95) blabel(bar, position(center) format(%4.0fc) size(medlarge)) ylabel(, labsize(large)) name(Fig3_`reg', replace) ytitle("% of all workers", size(large)) /*title("`reg_label'")*/ b1title("Individual earnings decile", size(large)) // ) //aspect(1)

    forvalues x = 1(5)46{
        gr_edit plotregion1.barlabels[`x'].EditCustomStyle , j(-1) style(color(white))
    }
    forvalues x = 2(5)47{
        gr_edit plotregion1.barlabels[`x'].EditCustomStyle , j(-1) style(color(white))
    }
    forvalues x = 3(5)48{
        gr_edit plotregion1.barlabels[`x'].EditCustomStyle , j(-1) style(color(white))
    }
	forvalues x = 5(5)45{
		gr_edit plotregion1.barlabels[`x'].style.editstyle box_alignment(north) 
	}

	if `reg' == 1 {
		foreach x in 13 23{
			gr_edit plotregion1.barlabels[`x'].style.editstyle box_alignment(north)
		}
	}
	else if `reg'==2{
		foreach x in 8 23 33{
			gr_edit plotregion1.barlabels[`x'].style.editstyle box_alignment(north)
		}
	}
	else if `reg' == 4 {
		foreach x in 3 8 13 18 23 28{
			gr_edit plotregion1.barlabels[`x'].style.editstyle box_alignment(south)
		}
		gr_edit plotregion1.barlabels[4].EditCustomStyle , j(-1) style(box_alignment(center))
	}
	else if `reg' == 5 {
		gr_edit plotregion1.barlabels[4].EditCustomStyle , j(-1) style(box_alignment(center))
		gr_edit plotregion1.barlabels[9].EditCustomStyle , j(-1) style(box_alignment(center))
	}
	else if `reg' == 6 {
		foreach x in 3 8{
			gr_edit plotregion1.barlabels[`x'].style.editstyle box_alignment(north)
		}
	}
	gr_edit plotregion1.barlabels[50].EditCustomStyle , j(-1) style(box_alignment(center))

    gr export "${results}/Fig3_`reg'.pdf", replace

}

gr bar self_emp Emp1_10 Own1_10 Emp11_plus Own11_plus if Region_groups == 1, stack asyvars bar(1, color("1 30 65")) bar(2, color("1 73 124")) bar(3, color("42 111 151")) bar(4, color("97 165 194")) bar(5, color("137 194 217")) sch(tufte) name(Legend, replace) legend(label(1 "Self-employed without employees") label(2 "Employees 1-10") label(3 "Business owners 1-10") label(4 "Employees 11+") label(5 "Business owners 11+") label(6 "101 or more") position(6) row(2) size(*10) symxsize(*8) symysize(*8) colgap(*10) keygap(*10) ) yscale(off)
gr_edit plotregion1.draw_view.setstyle, style(no)
gr display , xsize(16) ysize(1)
gr export "${results}/Fig3_legend.pdf", replace


*grc1leg Fig3_5 Fig3_6 Fig3_2 Fig3_3 Fig3_1 Fig3_4, col(2) ysize(12) xsize(6) name(Fig3, replace) sch(tufte)
*gr export "${results}/Fig3.pdf", replace

********************************************************************************
**
**		Figure A1
**
********************************************************************************

import excel using "${results}/Results LATAM.xlsx", firstrow clear sheet("FA1 - Size + informality")

reshape wide share , i(status_laboral) j(informal)

label define statuslabs -1 `""Self-employed" "without employees""' 1 "1-4" 2 "5-10" 3 "11-50" 4 "51+"
label values status_laboral statuslabs

graph bar share0 share1 , over(status_laboral, relabel(1 `""Self-employed" "without employees""')) stack  bar(1, color("1 30 65")) bar(2, color("97 165 194")) legend(label(1 "Formal") label(2 "Informal") position(6) row(1) ) blabel(bar, position(center)  format(%4.0fc) color(white)) name(FigA3, replace) ytitle("% of all workers") sch(tufte) bargap(50)
forvalues x = 1(2)10{
    gr_edit plotregion1.barlabels[`x'].EditCustomStyle , j(-1) style(color(white))
}
gr export "${results}/FigA1.pdf", replace

********************************************************************************
**
**		Figure A2, distributions by sectors
**
********************************************************************************

// LATAM

import excel using "${results}/Results LATAM.xlsx", firstrow clear sheet("FA2-3 - Size distr by sector") cellrange(A1:D5)

drop pais year

replace sector = "agriculture" if sector== "Agriculture"
replace sector = "industry" if sector== "Industry"
replace sector = "other_services" if sector== "Other services"
replace sector = "commerce_hotels" if sector== "Wholesale, retail and hospitality"

tempfile LATAM
save `LATAM'

import excel using "${results}/Results LATAM.xlsx", firstrow clear sheet("FA2-3 - Size distr by sector") cellrange(G6:K11)

xpose, clear varname
drop if _varname=="status_laboral"

rename (v1 v2 v3 v4 v5) (self_emp s1_4 s5_10 s11_50 s51_plus)
rename _varname sector
gen Region = "Latin America"

merge 1:1 sector using `LATAM', nogen 
rename share fracpop

tempfile LATAM
save `LATAM'

// USA 

import excel using "${results}/Results US.xlsx", firstrow clear sheet("Fig1_US B by sectors")

rename (firm1_4 firm5_9 firm10_49 firm50plus economic_sector) (s1_4 s5_10 s11_50 s51_plus sector)

gen country = "United States"
gen Region = "United States"

tempfile US 
save `US'

// India, Pakistan, Nepal.

import excel using "${results}/Results South Asia.xlsx", firstrow clear sheet("Fig1_SA by sectors")

reshape long emp_ pop_sector_, i(size) j(sector) string
encode size, gen(size_)
drop size
reshape wide emp_ pop_sector_, i(sector) j(size_)

rename pop_sector_1 fracpop
rename (emp_1 emp_2 emp_3 emp_4) (s1_4 s11_plus s5_10 self_emp)
drop pop_sector_2 pop_sector_3 pop_sector_4
gen Region = "India, Pakistan, Nepal (Urban)"
drop if sector=="others"

tempfile SouthAsia
save `SouthAsia'


// Europe 

import excel using "${results}/Results EU.xlsx", firstrow clear sheet("Sector Shares")

keep if _n==1 
xpose, clear

gen sector = "Industry" if _n==1 
replace sector = "Wholesale retail, acommodation and food services" if _n==2
replace sector = "Other services" if _n==3
replace sector = "Others" if _n==4
replace sector = "Agriculture" if _n==5

rename v1 fracpop
replace fracpop = fracpop*100

tempfile Europe 
save `Europe'

import excel using "${results}/Results EU.xlsx", firstrow clear sheet("Appendix_Pb")

drop if induscode == ""

rename (induscode selfemployed workers_1_4 workers_5_10 workers_11_49 workers_50plus) (sector self_emp s1_4 s5_10 s11_50 s51_plus)
gen Region="Europe"

foreach var in self_emp s1_4 s5_10 s11_50 s51_plus {
    replace `var' = `var'*100
}

merge 1:1 sector using `Europe', nogen
drop if sector=="Others"


tempfile Europe
save `Europe'

/// APPEND ALL COUNTRIES 

use `LATAM', clear
append using `US'
append using `SouthAsia'
append using `Europe'

// Data for figures 

gen s1_10 = s1_4 + s5_10 
replace s11_plus = s11_50 + s51_plus if s11_plus == .

** Although we do not have data breaking 11-50 and 50+ for India and Nepal (we do for Pakistan but we deal with all 3 together) we plot one single figure and have one less bar for these countries.
replace s11_50 = s11_plus if Region=="India, Pakistan, Nepal (Urban)"

cap label drop regions
label define regions 1 "Latin America" 2 "United States" 3 "Europe" 4 `""India, Pakistan" "Nepal (Urban)""'

// replace sector for first letter in caps
replace sector = upper(substr(sector, 1, 1)) + lower(substr(sector, 2, .))
replace sector = "Agriculture" if sector=="Agri"
replace sector = `""Wholesale, retail," "accomodation and food services""' if substr(sector,1,1)=="W" | sector=="Commerce_hotels"
replace sector = "Other services" if substr(sector,1,1)=="O"

// Create axis variables for each region with %s of employment in sector 
tostring fracpop, gen(round_fracpop) format(%4.0fc) force
*gen Region_lab = Region + " (" + round_fracpop + "%)"
gen Region_lab = Region
gen substr_lab = substr(Region_lab, 17, .) if Region=="India, Pakistan, Nepal (Urban)"

replace Region_lab = `""India, Pakistan," "Nepal (Urban)""' if Region_lab=="India, Pakistan, Nepal (Urban)"

/*
replace Region_lab = `""India, Pakistan," "Nepal (Urban) (4%)""' if Region_lab=="India, Pakistan, Nepal (Urban) (4%)"
replace Region_lab = `""India, Pakistan," "Nepal (Urban) (26%)""' if Region_lab=="India, Pakistan, Nepal (Urban) (26%)"
replace Region_lab = `""India, Pakistan," "Nepal (Urban) (23%)""' if Region_lab=="India, Pakistan, Nepal (Urban) (23%)"
replace Region_lab = `""India, Pakistan," "Nepal (Urban) (24%)""' if Region_lab=="India, Pakistan, Nepal (Urban) (24%)"
*/

encode sector, gen(sectorgroups)
labmask sectorgroups , values(sector)

gen order = 10*(Region=="Latin America") + 20*(Region=="United States") + 30*(Region=="Europe") + 40*(Region=="India, Pakistan, Nepal (Urban)") 
replace order = order+1 if sector=="Agriculture"
replace order = order+2 if sector=="Industry"
replace order = order+3 if sectorgroups==1
replace order = order+4 if sector=="Other services"
labmask order , values(Region_lab)


// Need to adjust a local in an ado file to easily show the whole label for the country regions. The code will run without making this adjustment but some labels will be cut off. To make this adjustment go to "C:\Program Files\Stata17\ado\base\_\_ggroup.ado" and change local truncate to a higher number in lines 78-80. There is no option to change this in graph bar.
levelsof sectorgroups, local(sectors)
foreach sec of local sectors{

   * graph bar self_emp s1_10 s11_plus if sectorgroups==`sec', over(order) name(FA2_`sec', replace) asyvars bar(1, color("1 30 65")) bar(2, color("97 165 194")) bar(3, color("137 194 217")) legend(label(1 "Self-emp. without employees") label(2 "Employees 1-10") label(3 "Employees 11+") position(6) row(2) ) blabel(bar,  format(%4.0fc) size(large)) ytitle("% of all workers", size(large)) scheme(tufte) scale(*.95) ylabel(, labsize(large))
   *gr export "${results}/FigA2_`sec'.pdf", replace

    graph bar self_emp s1_4 s5_10 s11_50 s51_plus if sectorgroups==`sec' /*& Region!="India, Pakistan, Nepal (Urban)"*/, over(order) name(FA3_`sec', replace) asyvars bar(1, color("1 30 65")) bar(2, color("1 73 124")) bar(3, color("42 111 151")) bar(4, color("97 165 194")) bar(5, color("137 194 217")) scheme(tufte) legend(label(1 "Self-emp. without employees") label(2 "1-4") label(3 "5-10") label(4 "11-50") label(5 "51+") position(6) row(2) symxsize(*0.7) colgap(*0.5) keygap(*0.3)) scale(*.95) blabel(total, format(%4.0fc) size(large)) ytitle("% of all workers", size(large)) ylabel(, labsize(large)) 
    gr export "${results}/FigA2_`sec'.pdf", replace

}


********************************************************************************
**
**		                        Table 2 
**
********************************************************************************
 
// Panel LATAM

import excel using "${results}/Results LATAM.xlsx", firstrow clear sheet("T2 - decomposition") 

gen order = _n

replace Category = "Worker in $\leq$ 10 employee business" if Category=="Worker in less than 10 employee business"
replace Category = "Owner of $\leq$ 10 employee business" if Category=="Owner of less than 10 employee business"
rename (ShareD1 P50D1 ShareP50D1 ShareD10 D10P50 ShareD10P50) (ShareD1_LA P50D1_LA ShareP50D1_LA ShareD10_LA D10P50_LA ShareD10P50_LA)

tempfile LA
save `LA'

// Panel US

import excel using "${results}/Results US.xlsx", firstrow clear sheet("Table2_US") 

gen order = _n 
rename (population_share1 relative_income1 category_term1 population_share10 relative_income10 category_term10) (ShareD1_US P50D1_US ShareP50D1_US ShareD10_US D10P50_US ShareD10P50_US)
merge 1:1 order using `LA', nogen

drop order categ

// Create difference panel: 

foreach var in ShareD1 P50D1 ShareP50D1 ShareD10 D10P50 ShareD10P50{

    gen `var'_Dif = `var'_LA - `var'_US

}

// Add row for total

set obs 7
replace Category = "Total" if _n==7

foreach var of varlist Share*{
    qui sum `var'
    replace `var' = r(sum) if Category=="Total"
}
foreach var of varlist P* D*{
    qui sum `var'
    replace `var' = r(mean) if Category=="Total"
}

gen order = _n

reshape long ShareD1 P50D1 ShareP50D1 ShareD10 D10P50 ShareD10P50 , i(Category order) j(Region) string


replace ShareD1 = ShareD1*100 if Category=="Total"
replace ShareD10 = ShareD10*100 if Category=="Total"

tostring ShareD1  ShareD10 , gen(ShareD1_s  ShareD10_s) format(%6.3fc) force
tostring P50D1 ShareP50D1 D10P50 ShareD10P50, gen(P50D1_s ShareP50D1_s D10P50_s ShareD10P50_s) format(%6.2fc) force

foreach var in ShareD1_s P50D1_s ShareP50D1_s{
	replace `var' = "--" if Category=="Owner of 11+ employee business"
}

drop ShareD1 P50D1 ShareP50D1 ShareD10 D10P50 ShareD10P50
ren (ShareD1_s P50D1_s ShareP50D1_s ShareD10_s D10P50_s ShareD10P50_s) (ShareD1 P50D1 ShareP50D1 ShareD10 D10P50 ShareD10P50)

replace ShareD1 = "--" if Category=="Total" & Region=="_Dif"
replace ShareD10 = "--" if Category=="Total" & Region=="_Dif"
replace ShareD1 = subinstr(ShareD1,".000","",.) if Category=="Total" & Region!="_Dif"
replace ShareD10 = subinstr(ShareD10,".000","",.) if Category=="Total" & Region!="_Dif"
replace ShareD1 = ShareD1 + "\%" if Category=="Total" & Region!="_Dif"
replace ShareD10 = ShareD10 + "\%" if Category=="Total" & Region!="_Dif"

gen order_Reg = 1 if Region=="_LA"
replace order_Reg = 2 if Region=="_US"
replace order_Reg = 3 if Region=="_Dif"

sort order_Reg order

foreach var of varlist Category ShareD1 P50D1 ShareP50D1 ShareD10 D10P50 ShareD10P50{

    replace `var' = "" if order==6
}

// Export to excel and latex 

export excel Regio Category ShareD1 P50D1 ShareP50D1 ShareD10 D10P50 ShareD10P50 using "${results}/Tables.xlsx", firstrow(variables) sheetreplace sheet("Table2")

foreach var of varlist Category ShareD1 P50D1 ShareP50D1 ShareD10 D10P50 ShareD10P50{
    replace `var' = "\textbf{" + `var' + "}" if Category=="Total" | Category=="\textbf{Total}"
}

replace ShareD10P50 = ShareD10P50 + "\\"

gen blank = ""


outsheet Category ShareD1 P50D1 ShareP50D1 blank ShareD10 D10P50 ShareD10P50 if Region=="_LA" using "$results\Table 2 Panel A.tex",  replace nonames delim("&") noquote
outsheet Category ShareD1 P50D1 ShareP50D1 blank ShareD10 D10P50 ShareD10P50 if Region=="_US" using "$results\Table 2 Panel B.tex",  replace nonames delim("&") noquote
outsheet Category ShareD1 P50D1 ShareP50D1 blank ShareD10 D10P50 ShareD10P50 if Region=="_Dif" using "$results\Table 2 Panel C.tex",  replace nonames delim("&") noquote



