********************************************************************************
**
**					Create Dataset with employment shares by deciles
**
**			This dataset includes the employment share in each firm-size 
**						by income deciles in each country	
**				Rows: countries, deciles, and firm-size categories
**         We partially homogenize cateogories here: i.e. some countries have 
**          a category for 1-5 employees while others have 1-4. We homogenize
**          the two categories to 1-5. 
**				
********************************************************************************


// Since each country (or sets of countries) are processed separately, we have 
// to join datasets

cap log close
log using "${results}/Logs/Log 4 Employment shares dataset `c(current_date)'.txt", replace text

********************************************************************************
**								LATAM
********************************************************************************

import excel using "${results}\Results LATAM.xlsx", clear sheet("Dataset") firstrow

rename (firm10to40 firm41to99 firm10to30 firm31to99) (firm10to39 firm40to99 firm10to29 firm30to99)

reshape long firm, i(decile persons_decile) j(Prod_Unit_Size) string

rename firm Employment_Share
destring year, replace
rename deciles decile

gen region = "LATAM"

tempfile LATAM
save `LATAM', replace

********************************************************************************
**								United States
********************************************************************************

import excel using "${results}\Results US.xlsx", clear sheet("Database") firstrow

reshape long firm, i(decile decile) j(Prod_Unit_Size) string 
gen country="USA" 
gen region="USA"
gen year = 2018

rename firm Employment_Share

tempfile US 
save `US', replace

********************************************************************************
**								    Europe
********************************************************************************

import excel using "${results}\Results EU.xlsx", clear sheet("Database") firstrow

drop w_1 - w_10

rename (selfemployed) (w_selfemployed)
rename (w_1_5 w_6_10 w_11_19 w_20_49 w_50more) (w_1to4 w_5to9 w_10to19 w_20to49 w_50plus)

gen region = "EU: Higher Income" if inlist(country,"Austria","Belgium","Cyprus","Denmark","Finland","France","Germany","Ireland","Italy")
replace region = "EU: Higher Income" if inlist(country,"Sweden","Switzerland", "Malta","Luxembourg")
replace region = "EU: Lower Income" if inlist(country,"Bulgaria","Croatia","Czech Republic","Estonia","Greece","Latvia","Lithuania")
replace region = "EU: Lower Income" if inlist(country,"Poland","Romania","Serbia","Slovakia","Slovenia","Spain", "Portugal")

reshape long w_, i(decile country region) j(Prod_Unit_Size) string

rename w_ Employment_Share
gen year = 2019

tempfile EU
save `EU', replace


********************************************************************************
**								Australia and Korea
********************************************************************************

import excel using "${results}\Results AUS.xlsx", clear sheet("Database") firstrow
rename qtiles decile
*rename persons_q persons_decile
rename selfemployed w_selfemployed
rename w_500ormore w_500plus
egen w_1to4 = rowtotal(w_one w_2to4)
drop w_one w_2to4


reshape long w_, i(decile country region) j(Prod_Unit_Size) string
rename w_ Employment_Share

gen year = 2019

tempfile Aus
save `Aus', replace 


import excel using "${results}\Results KR.xlsx", clear sheet("Database") firstrow
rename qtiles decile
*rename persons_q persons_decile
rename selfemployed w_selfemployed
rename w_1000ormore w_1000plus

reshape long w_, i(decile  country region) j(Prod_Unit_Size) string
rename w_ Employment_Share

gen year = 2019

tempfile KR
save `KR', replace 

********************************************************************************
**								India
********************************************************************************

import excel using "${results}\Results India.xlsx", clear sheet("Database") firstrow

rename Decile, lower

rename firm6to9 firm5to9
rename firm1to5 firm1to4

reshape long firm, i(decile persons_decile) j(Prod_Unit_Size) string

rename firm Employment_Share
gen country="India"
gen region="India"
gen year = 2019

replace Employment_Share = Employment_Share/100

tempfile India
save `India', replace

********************************************************************************
**								Append all datasets
********************************************************************************

use `LATAM'
append using `US' 
append using `EU'
append using `KR'
append using `Aus'
append using `India'

tab Prod_Unit_Size region

save "${results}\Employment Shares By Income Decile.dta", replace